@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+  Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
   
   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to
@@ -21,8 +21,7 @@
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
   */
 
-
-#include "econfig.h"
+#include "dox.h"
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -38,15 +37,13 @@
 #endif
 
 #include <Imlib.h>
+#if USE_FNLIB
 #include <Fnlib.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "econfig.h"
-
-#include "dox.h"
-
 #if defined(__alpha__) && defined(__GNUC__) && ((__GNUC__ == 2) && (__GNUC_MINOR__ < 96)) /* gets rid of some misalignment in GCC */
 #pragma 2
 #endif
@@ -92,8 +89,10 @@ typedef struct _mwmhints {
 #include "exit2.xpm"
 
 Display *disp;
-ImlibData *id;
-FnlibData *fd;
+ImlibData *pImlibData;
+#if USE_FNLIB
+FnlibData *pFnlibData;
+#endif
 Window win_main, win_title, win_exit, win_next, win_prev, win_text, win_cover;
 int w, h, t;
 ImlibImage *im_text;
@@ -118,7 +117,7 @@ Window CreateWindow(Window parent, int x, int y, int ww, int hh)
 
 	attr.backing_store = NotUseful;
 	attr.override_redirect = False;
-	attr.colormap = Imlib_get_colormap(id);
+	attr.colormap = Imlib_get_colormap(pImlibData);
 	attr.border_pixel = 0;
 	attr.background_pixel = 0;
 	attr.save_under = False;
@@ -127,8 +126,8 @@ Window CreateWindow(Window parent, int x, int y, int ww, int hh)
 	mwm.decorations = 0;
 	mwm.inputMode = 0;
 /*   a = XInternAtom(disp, "_MOTIF_WM_HINTS", False); */
-	win = XCreateWindow(disp, parent, x, y, ww, hh, 0, id->x.depth,
-						InputOutput, Imlib_get_visual(id),
+	win = XCreateWindow(disp, parent, x, y, ww, hh, 0, pImlibData->x.depth,
+						InputOutput, Imlib_get_visual(pImlibData),
 						CWOverrideRedirect | CWSaveUnder | CWBackingStore |
 						CWColormap | CWBackPixel | CWBorderPixel, &attr);
 	XSetWindowBackground(disp, win, 0);
@@ -201,7 +200,10 @@ int main(int argc, char **argv)
 	y = 0;
 	pagenum = 0;
 
-	disp = XOpenDisplay(NULL);
+        if((int)(disp = XOpenDisplay(NULL)) < 1) {
+                printf("%s: Cannot open X display.\n",argv[0]);
+                exit(0);
+        }
 
 	/* now we'll set the locale */
 	setlocale(LC_ALL, "");
@@ -216,22 +218,24 @@ int main(int argc, char **argv)
 	params.flags = PARAMS_IMAGECACHESIZE | PARAMS_PIXMAPCACHESIZE;
 	params.imagecachesize = (w * h * 3 * 2);
 	params.pixmapcachesize = (w * h * 3 * 2 * 8);
-	id = Imlib_init_with_params(disp, &params);
-	Imlib_set_render_type(id, RT_DITHER_TRUECOL);
-	fd = Fnlib_init(id);
+	pImlibData = Imlib_init_with_params(disp, &params);
+	Imlib_set_render_type(pImlibData, RT_DITHER_TRUECOL);
+#if USE_FNLIB
+	pFnlibData = Fnlib_init(pImlibData);
+#endif
 
-	im_title = Imlib_create_image_from_xpm_data(id, title_xpm);
+	im_title = Imlib_create_image_from_xpm_data(pImlibData, title_xpm);
 	ibd.left = 50;
 	ibd.right = 2;
 	ibd.top = 2;
 	ibd.bottom = 2;
-	Imlib_set_image_border(id, im_title, &ibd);
-	im_prev1 = Imlib_create_image_from_xpm_data(id, prev1_xpm);
-	im_prev2 = Imlib_create_image_from_xpm_data(id, prev2_xpm);
-	im_next1 = Imlib_create_image_from_xpm_data(id, next1_xpm);
-	im_next2 = Imlib_create_image_from_xpm_data(id, next2_xpm);
-	im_exit1 = Imlib_create_image_from_xpm_data(id, exit1_xpm);
-	im_exit2 = Imlib_create_image_from_xpm_data(id, exit2_xpm);
+	Imlib_set_image_border(pImlibData, im_title, &ibd);
+	im_prev1 = Imlib_create_image_from_xpm_data(pImlibData, prev1_xpm);
+	im_prev2 = Imlib_create_image_from_xpm_data(pImlibData, prev2_xpm);
+	im_next1 = Imlib_create_image_from_xpm_data(pImlibData, next1_xpm);
+	im_next2 = Imlib_create_image_from_xpm_data(pImlibData, next2_xpm);
+	im_exit1 = Imlib_create_image_from_xpm_data(pImlibData, exit1_xpm);
+	im_exit2 = Imlib_create_image_from_xpm_data(pImlibData, exit2_xpm);
 
 	if (argc < 2) {
 		printf("usage:\n"
@@ -282,7 +286,9 @@ int main(int argc, char **argv)
 	t = 16;
 	GetObjects(f);
 	fclose(f);
-	Fnlib_add_dir(fd, docdir);
+#if USE_FNLIB
+	Fnlib_add_dir(pFnlibData, docdir);
+#endif
 	wx = (DisplayWidth(disp, DefaultScreen(disp)) - w) / 2;
 	wy = (DisplayHeight(disp, DefaultScreen(disp)) - (h + t)) / 2;
 #ifdef HAS_XINERAMA
@@ -295,7 +301,7 @@ int main(int argc, char **argv)
 			int num;
 			XineramaScreenInfo *screens;
 
-			XQueryPointer(disp, id->x.root, &rt, &ch, &pointer_x, &pointer_y,
+			XQueryPointer(disp, pImlibData->x.root, &rt, &ch, &pointer_x, &pointer_y,
 						  &d, &d, &ud);
 
 			screens = XineramaQueryScreens(disp, &num);
@@ -320,7 +326,7 @@ int main(int argc, char **argv)
 
 	}
 #endif
-	win_main = CreateWindow(id->x.root, wx, wy, w, h + t);
+	win_main = CreateWindow(pImlibData->x.root, wx, wy, w, h + t);
 	win_title = CreateWindow(win_main, 0, 0, (w - 64 - 64 - t), t);
 	win_prev = CreateWindow(win_main, (w - 64 - 64 - t), 0, 64, t);
 	XSelectInput(disp, win_prev, ButtonPressMask | ButtonReleaseMask);
@@ -331,12 +337,12 @@ int main(int argc, char **argv)
 	win_text = CreateWindow(win_main, 0, t, w, h);
 	XSelectInput(disp, win_text, ButtonPressMask | ButtonReleaseMask |
 				 KeyPressMask | KeyReleaseMask | PointerMotionMask);
-	draw = XCreatePixmap(disp, win_text, w, h, id->x.depth);
+	draw = XCreatePixmap(disp, win_text, w, h, pImlibData->x.depth);
 	XSetWindowBackgroundPixmap(disp, win_text, draw);
-	Imlib_apply_image(id, im_title, win_title);
-	Imlib_apply_image(id, im_exit1, win_exit);
-	Imlib_apply_image(id, im_next1, win_next);
-	Imlib_apply_image(id, im_prev1, win_prev);
+	Imlib_apply_image(pImlibData, im_title, win_title);
+	Imlib_apply_image(pImlibData, im_exit1, win_exit);
+	Imlib_apply_image(pImlibData, im_next1, win_next);
+	Imlib_apply_image(pImlibData, im_prev1, win_prev);
 
 	l = RenderPage(draw, pagenum, w, h);
 
@@ -403,11 +409,11 @@ int main(int argc, char **argv)
 			break;
 			case ButtonPress:
 			if (ev.xbutton.window == win_prev)
-				Imlib_apply_image(id, im_prev2, win_prev);
+				Imlib_apply_image(pImlibData, im_prev2, win_prev);
 			else if (ev.xbutton.window == win_next)
-				Imlib_apply_image(id, im_next2, win_next);
+				Imlib_apply_image(pImlibData, im_next2, win_next);
 			else if (ev.xbutton.window == win_exit)
-				Imlib_apply_image(id, im_exit2, win_exit);
+				Imlib_apply_image(pImlibData, im_exit2, win_exit);
 			else {
 				int x, y;
 
@@ -493,7 +499,7 @@ int main(int argc, char **argv)
 			break;
 			case ButtonRelease:
 			if (ev.xbutton.window == win_prev) {
-				Imlib_apply_image(id, im_prev1, win_prev);
+				Imlib_apply_image(pImlibData, im_prev1, win_prev);
 				FREE_LINKS;
 				page_hist_pos--;
 				if (page_hist_pos < 0)
@@ -504,7 +510,7 @@ int main(int argc, char **argv)
 			} else if (ev.xbutton.window == win_next) {
 				int prev_pagenum;
 
-				Imlib_apply_image(id, im_next1, win_next);
+				Imlib_apply_image(pImlibData, im_next1, win_next);
 				prev_pagenum = pagenum;
 				pagenum++;
 				pagenum = FixPage(pagenum);
@@ -523,7 +529,7 @@ int main(int argc, char **argv)
 					UPDATE;
 				}
 			} else if (ev.xbutton.window == win_exit) {
-				Imlib_apply_image(id, im_exit1, win_exit);
+				Imlib_apply_image(pImlibData, im_exit1, win_exit);
 				exit(0);
 			}
 			break;
@@ -554,9 +560,7 @@ int main(int argc, char **argv)
 							}
 							GetLinkColors(pagenum, &r, &g, &b);
 							gc = XCreateGC(disp, win_text, 0, &gcv);
-							XSetForeground(disp, gc,
-										   Imlib_best_color_match(id, &r, &g,
-																  &b));
+							XSetForeground(disp, gc, Imlib_best_color_match(pImlibData, &r, &g, &b));
 							XDrawRectangle(disp, win_text, gc, ll->x, ll->y,
 										   ll->w, ll->h);
 							XFreeGC(disp, gc);
