@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
@@ -519,11 +519,13 @@ RenderPage(Window win, int page_num, int w, int h)
    int                 wastext = 0;
 
    ts.fontname = NULL;
+#if USE_FNLIB
    ts.style.orientation = FONT_TO_RIGHT;
    ts.style.mode = MODE_WRAP_WORD;
    ts.style.justification = 0;
    ts.style.spacing = 0;
    ts.font = NULL;
+#endif
    ts.fg_col.r = 0;
    ts.fg_col.g = 0;
    ts.fg_col.b = 0;
@@ -547,11 +549,11 @@ RenderPage(Window win, int page_num, int w, int h)
 
 	sprintf(tmp, "%s/%s", docdir, pg->background);
 	findLocalizedFile(tmp);
-	im = Imlib_load_image(id, tmp);
+	im = Imlib_load_image(pImlibData, tmp);
 	if (im)
 	  {
-	     Imlib_paste_image(id, im, win, 0, 0, w, h);
-	     Imlib_destroy_image(id, im);
+	     Imlib_paste_image(pImlibData, im, win, 0, 0, w, h);
+	     Imlib_destroy_image(pImlibData, im);
 	  }
      }
    for (i = 0; i < pg->count; i++)
@@ -572,14 +574,14 @@ RenderPage(Window win, int page_num, int w, int h)
 		  char                tmp[4096];
 
 		  sprintf(tmp, "%s/%s", docdir, img->src);
-		  im = Imlib_load_image(id, tmp);
+		  im = Imlib_load_image(pImlibData, tmp);
 		  if (im)
 		    {
 		       img->w = im->rgb_width;
 		       img->h = im->rgb_height;
-		       Imlib_paste_image(id, im, win, img->x, img->y,
+		       Imlib_paste_image(pImlibData, im, win, img->x, img->y,
 					 im->rgb_width, im->rgb_height);
-		       Imlib_destroy_image(id, im);
+		       Imlib_destroy_image(pImlibData, im);
 		    }
 		  if (img->link)
 		    {
@@ -604,13 +606,15 @@ RenderPage(Window win, int page_num, int w, int h)
 	  case FONT:
 	     fn = pg->obj[i].object;
 	     ts.fontname = NULL;
+#if USE_FNLIB
 	     ts.style.orientation = FONT_TO_RIGHT;
 	     ts.style.mode = MODE_WRAP_WORD;
 	     ts.style.justification = 0;
 	     ts.style.spacing = 0;
 	     if (ts.font)
-		Fnlib_free_font(fd, ts.font);
+		Fnlib_free_font(pFnlibData, ts.font);
 	     ts.font = NULL;
+#endif
 	     ts.fg_col.r = 0;
 	     ts.fg_col.g = 0;
 	     ts.fg_col.b = 0;
@@ -924,7 +928,7 @@ RenderPage(Window win, int page_num, int w, int h)
 				 g = ts.fg_col.g = pg->linkg;
 				 b = ts.fg_col.b = pg->linkb;
 				 XSetForeground(disp, gc,
-				      Imlib_best_color_match(id, &r, &g, &b));
+				      Imlib_best_color_match(pImlibData, &r, &g, &b));
 				 TextSize(&ts, txt_disp, &tw, &th, 17);
 				 extra = ((xspace - tw) * justification) >> 10;
 				 TextDraw(&ts, win, link_txt, x + off + lx + extra, y,
@@ -980,8 +984,10 @@ RenderPage(Window win, int page_num, int w, int h)
 	  }
      }
 
+#if USE_FNLIB
    if (ts.font)
-      Fnlib_free_font(fd, ts.font);
+      Fnlib_free_font(pFnlibData, ts.font);
+#endif
    if (ts.efont)
       Efont_free(ts.efont);
    if (ts.xfont)
