@@ -2,7 +2,7 @@
 /* Enlightenment - The Window Manager that dares to do what others don't     */
 /*****************************************************************************/
 /*
- *  Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ *  Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a copy
  *  of this software and associated documentation files (the "Software"), to
@@ -24,7 +24,7 @@
  *  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *  */
 
-#include "econfig.h"
+#include "config.h"
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -48,14 +48,9 @@
 #include <sys/ipc.h>
 #include <sys/shm.h>
 
-#include "econfig.h"
-
 #ifndef ENLIGHTENMENT_ROOT
 #define ENLIGHTENMENT_ROOT           "/usr/local/enlightenment"
 #endif
-#define ENLIGHTENMENT_SYSTEM_CONFIG  ENLIGHTENMENT_ROOT"/system_config"
-#define ENLIGHTENMENT_SYSTEM_THEMES  ENLIGHTENMENT_ROOT"/themes"
-#define ENLIGHTENMENT_SYSTEM_BGS     ENLIGHTENMENT_ROOT"/backgrounds"
 
 #define LIST_FINDBY_NAME        0
 #define LIST_FINDBY_ID          1
