@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -71,9 +71,8 @@ GrabButtonGrabs(EWin * ewin)
    int                 j;
    Action             *a;
 
-   ac =
-      (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_ACLASS);
+   ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+				 LIST_TYPE_ACLASS);
 
    if (ac)
      {
@@ -135,9 +134,8 @@ UnGrabButtonGrabs(EWin * ewin)
    int                 j;
    Action             *a;
 
-   ac =
-      (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_ACLASS);
+   ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+				 LIST_TYPE_ACLASS);
 
    if (ac)
      {
@@ -626,6 +624,7 @@ runApp(char *exe, char *params)
    char               *sh;
    char               *path;
    char               *real_exec;
+   int                 fd;
 
    EDBUG(6, "runApp");
 
@@ -633,6 +632,11 @@ runApp(char *exe, char *params)
    if (fork())
       EDBUG_RETURN(0);
    setsid();
+   /* Close all file descriptors except the std 3 */
+   for (fd = 3; fd < 1024; fd++)
+     {
+	close(fd);
+     }
 #endif
    sh = usershell(getuid());
    if (exe)
@@ -667,7 +671,7 @@ runApp(char *exe, char *params)
 				    "%s\n"
 				    "This program could not be executed.\n"
 				    "This is because the file does not exist.\n"),
-(char *)exe);
+				   (char *)exe);
 		  /* relative path */
 		  else
 		     DialogAlertOK(_
@@ -710,7 +714,7 @@ runApp(char *exe, char *params)
 					 "to execute it because you do not "
 					 "have execute "
 					 "access to this file.\n"),
-(char *)path);
+					(char *)path);
 		    }
 		  /* it's not a file */
 		  else
@@ -788,16 +792,19 @@ execApplication(void *params)
      {
 	int                 n;
 
-	n = fread(s, 1, FILEPATH_LEN_MAX, f);
+	n = fread(s, 1, FILEPATH_LEN_MAX - 1, f);
 	/* True64 bug workaround */
 	if (n == 0)
-	   fread(s, 1, FILEPATH_LEN_MAX, f);
-	s[FILEPATH_LEN_MAX - 1] = 0;
-	l = strlen(s);
-	s[l - 1] = 0;
-	sscanf(s, "%4000s", exe);
+	   n = fread(s, 1, FILEPATH_LEN_MAX - 1, f);
+	if (n > 1)
+	  {
+	     s[n] = 0;
+	     l = strlen(s);
+	     s[l - 1] = 0;
+	     sscanf(s, "%4000s", exe);
+	     runApp(exe, s);
+	  }
 	pclose(f);
-	runApp(exe, s);
      }
    EDBUG_RETURN(0);
 }
@@ -1018,7 +1025,7 @@ doResizeEnd(void *params)
 	ForceUpdatePagersForDesktop(desks.current);
 	EDBUG_RETURN(0);
      }
-   queue_up = 1;
+   queue_up = DRAW_QUEUE_ENABLE;
    mode.mode = MODE_NONE;
    if (mode.noewin)
       mode.ewin = NULL;
@@ -1427,41 +1434,44 @@ doCleanup(void *params)
 	     ret = Erealloc(ret, sizeof(RectBox) * ((num + j) + 1 + k));
 	     for (i = 0; i < num; i++)
 	       {
-		  if (((blst[i]->desktop == desks.current)
-		       || ((blst[i]->desktop == 0) && (blst[i]->sticky)))
-		      && (blst[i]->visible))
+		  Button             *b = blst[i];
+
+		  if (!b->visible || b->internal)
+		     continue;
+		  if (!b->sticky && (b->desktop != desks.current))
+		     continue;
+
+		  fixed[k].data = NULL;
+		  fixed[k].x = blst[i]->x;
+		  fixed[k].y = blst[i]->y;
+		  fixed[k].w = blst[i]->w;
+		  fixed[k].h = blst[i]->h;
+		  if (fixed[k].x < 0)
 		    {
-		       fixed[k].data = NULL;
-		       fixed[k].x = blst[i]->x;
-		       fixed[k].y = blst[i]->y;
-		       fixed[k].w = blst[i]->w;
-		       fixed[k].h = blst[i]->h;
-		       if (fixed[k].x < 0)
-			 {
-			    fixed[k].x += fixed[k].w;
-			    fixed[k].x = 0;
-			 }
-		       if ((fixed[k].x + fixed[k].w) > root.w)
-			  fixed[k].w = root.w - fixed[k].x;
-		       if (fixed[k].y < 0)
-			 {
-			    fixed[k].y += fixed[k].h;
-			    fixed[k].y = 0;
-			 }
-		       if ((fixed[k].y + fixed[k].h) > root.h)
-			  fixed[k].h = root.h - fixed[k].y;
-		       if ((fixed[k].w > 0) && (fixed[k].h > 0))
-			 {
-			    if (blst[i]->sticky)
-			       fixed[k].p = 50;
-			    else
-			       fixed[k].p = 0;
-			    k++;
-			 }
+		       fixed[k].x += fixed[k].w;
+		       fixed[k].x = 0;
 		    }
+		  if ((fixed[k].x + fixed[k].w) > root.w)
+		     fixed[k].w = root.w - fixed[k].x;
+		  if (fixed[k].y < 0)
+		    {
+		       fixed[k].y += fixed[k].h;
+		       fixed[k].y = 0;
+		    }
+		  if ((fixed[k].y + fixed[k].h) > root.h)
+		     fixed[k].h = root.h - fixed[k].y;
+		  if ((fixed[k].w <= 0) || (fixed[k].h <= 0))
+		     continue;
+
+		  if (blst[i]->sticky)
+		     fixed[k].p = 50;
+		  else
+		     fixed[k].p = 0;
+		  k++;
 	       }
 	     Efree(blst);
 	  }
+#if ENABLE_KDE
 	if (mode.kde_support)
 	  {
 	     fixed = Erealloc(fixed, sizeof(RectBox) * (k + 2));
@@ -1509,6 +1519,7 @@ doCleanup(void *params)
 	     k++;
 
 	  }
+#endif
 	ArrangeRects(fixed, k, floating, j, ret, 0, 0, root.w, root.h, method,
 		     0);
 	for (i = 0; i < (j + k); i++)
@@ -1745,7 +1756,6 @@ doStick(void *params)
 		 && ((curr_group && !curr_group->cfg.mirror) || !sticky))
 	   MakeWindowSticky(gwins[i]);
 	params = NULL;
-	GNOME_SetHint(gwins[i]);
 	RememberImportantInfoForEwin(gwins[i]);
      }
    Efree(gwins);
@@ -1787,8 +1797,8 @@ doSkipLists(void *params)
    ewin->skipwinlist = !(skip);
    ewin->skipfocus = !(skip);
    params = NULL;
-   GNOME_SetHint(ewin);
-   GNOME_SetClientList();
+   HintsSetWindowState(ewin);
+   HintsSetClientList();
    RememberImportantInfoForEwin(ewin);
 
    EDBUG_RETURN(0);
@@ -1816,8 +1826,8 @@ doSkipTask(void *params)
 
    ewin->skiptask = !(skiptask);
    params = NULL;
-   GNOME_SetHint(ewin);
-   GNOME_SetClientList();
+   HintsSetWindowState(ewin);
+   HintsSetClientList();
    RememberImportantInfoForEwin(ewin);
 
    EDBUG_RETURN(0);
@@ -1846,7 +1856,7 @@ doSkipFocus(void *params)
    ewin->skipfocus = !(skipfocus);
 
    params = NULL;
-   GNOME_SetHint(ewin);
+   HintsSetWindowState(ewin);
    RememberImportantInfoForEwin(ewin);
    EDBUG_RETURN(0);
 }
@@ -1873,7 +1883,7 @@ doSkipWinList(void *params)
 
    ewin->skipwinlist = !(skipwinlist);
    params = NULL;
-   GNOME_SetHint(ewin);
+   HintsSetWindowState(ewin);
    RememberImportantInfoForEwin(ewin);
    EDBUG_RETURN(0);
 }
@@ -1900,7 +1910,7 @@ doNeverFocus(void *params)
 
    ewin->neverfocus = !(neverfocus);
    params = NULL;
-   GNOME_SetHint(ewin);
+   HintsSetWindowState(ewin);
    RememberImportantInfoForEwin(ewin);
    EDBUG_RETURN(0);
 }
@@ -2037,7 +2047,7 @@ doMoveModeSet(void *params)
 	if (mode.movemode > 5)
 	   mode.movemode = 0;
      }
-   if ((ird) && (mode.movemode == 5))
+   if ((prImlibData) && (mode.movemode == 5))
       mode.movemode = 3;
    autosave();
    EDBUG_RETURN(0);
@@ -2225,14 +2235,14 @@ doDragdirSet(void *params)
 	GotoDesktop(desks.current);
 	for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
 	   MoveDesktop(i, 0, 0);
-	while (
-	       (b =
+	while ((b =
 		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_BUTTON))) DestroyButton(b);
-	while (
-	       (b =
+			   LIST_TYPE_BUTTON)))
+	   DestroyButton(b);
+	while ((b =
 		RemoveItem("_DESKTOP_DESKRAY_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_BUTTON))) DestroyButton(b);
+			   LIST_TYPE_BUTTON)))
+	   DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2258,10 +2268,10 @@ doDragbarOrderSet(void *params)
      }
    if (pd != desks.dragbar_ordering)
      {
-	while (
-	       (b =
+	while ((b =
 		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_BUTTON))) DestroyButton(b);
+			   LIST_TYPE_BUTTON)))
+	   DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2281,10 +2291,10 @@ doDragbarWidthSet(void *params)
       desks.dragbar_width = atoi((char *)params);
    if (pd != desks.dragbar_width)
      {
-	while (
-	       (b =
+	while ((b =
 		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_BUTTON))) DestroyButton(b);
+			   LIST_TYPE_BUTTON)))
+	   DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2304,10 +2314,10 @@ doDragbarLengthSet(void *params)
       desks.dragbar_length = atoi((char *)params);
    if (pd != desks.dragbar_length)
      {
-	while (
-	       (b =
+	while ((b =
 		RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-			   LIST_TYPE_BUTTON))) DestroyButton(b);
+			   LIST_TYPE_BUTTON)))
+	   DestroyButton(b);
 	InitDesktopControls();
 	ShowDesktopControls();
      }
@@ -2454,9 +2464,11 @@ doHideShowButton(void *params)
    /* This is unused - where did this come from? -Mandrake */
    /* static char         lasthide = 0; */
 
-   EDBUG(6, "doHideButtons");
+   EDBUG(6, "doHideShowButton");
+
    if (InZoom())
       EDBUG_RETURN(0);
+
    if ((mode.mode == MODE_MOVE) || (mode.mode == MODE_RESIZE_H)
        || (mode.mode == MODE_RESIZE_V) || (mode.mode == MODE_RESIZE))
       EDBUG_RETURN(0);
@@ -2469,16 +2481,7 @@ doHideShowButton(void *params)
 	     sscanf((char *)params, "%*s %1000s", s);
 	     b = (Button *) FindItem(s, 0, LIST_FINDBY_NAME, LIST_TYPE_BUTTON);
 	     if ((b) && (!b->used))
-	       {
-		  if (b->visible)
-		    {
-		       HideButton(b);
-		    }
-		  else
-		    {
-		       ShowButton(b);
-		    }
-	       }
+		ToggleButton(b);
 	  }
 	else if (!strcmp(s, "buttons"))
 	  {
@@ -2492,21 +2495,10 @@ doHideShowButton(void *params)
 			 {
 			    if (matchregexp(ss, lst[i]->name))
 			      {
-				 if (
-				     (strcmp
-				      (lst[i]->name,
-				       "_DESKTOP_DESKRAY_DRAG_CONTROL")
+				 if ((strcmp(lst[i]->name,
+					     "_DESKTOP_DESKRAY_DRAG_CONTROL")
 				      && (!lst[i]->used)))
-				   {
-				      if (!(lst[i]->visible))
-					{
-					   ShowButton(lst[i]);
-					}
-				      else
-					{
-					   HideButton(lst[i]);
-					}
-				   }
+				    ToggleButton(lst[i]);
 			      }
 			 }
 		    }
@@ -2524,21 +2516,10 @@ doHideShowButton(void *params)
 			 {
 			    if (!matchregexp(ss, lst[i]->name))
 			      {
-				 if (
-				     (strcmp
-				      (lst[i]->name,
-				       "_DESKTOP_DESKRAY_DRAG_CONTROL")
+				 if ((strcmp(lst[i]->name,
+					     "_DESKTOP_DESKRAY_DRAG_CONTROL")
 				      && (!lst[i]->used)))
-				   {
-				      if (!(lst[i]->visible))
-					{
-					   ShowButton(lst[i]);
-					}
-				      else
-					{
-					   HideButton(lst[i]);
-					}
-				   }
+				    ToggleButton(lst[i]);
 			      }
 			 }
 		    }
@@ -2551,20 +2532,10 @@ doHideShowButton(void *params)
 	       {
 		  for (i = 0; i < num; i++)
 		    {
-		       if (
-			   (strcmp
+		       if ((strcmp
 			    (lst[i]->name, "_DESKTOP_DESKRAY_DRAG_CONTROL")
 			    && (!lst[i]->used)))
-			 {
-			    if (!(lst[i]->visible))
-			      {
-				 ShowButton(lst[i]);
-			      }
-			    else
-			      {
-				 HideButton(lst[i]);
-			      }
-			 }
+			  ToggleButton(lst[i]);
 		    }
 	       }
 	  }
@@ -2577,19 +2548,11 @@ doHideShowButton(void *params)
 	     for (i = 0; i < num; i++)
 	       {
 		  if (!lst[i]->used)
-		    {
-		       if (!(lst[i]->visible))
-			 {
-			    ShowButton(lst[i]);
-			 }
-		       else
-			 {
-			    HideButton(lst[i]);
-			 }
-		    }
+		     ToggleButton(lst[i]);
 	       }
 	  }
      }
+   StackDesktops();
    autosave();
 
    EDBUG_RETURN(0);
@@ -2837,7 +2800,6 @@ doSendToNextDesk(void *params)
    if (!ewin)
       EDBUG_RETURN(0);
 
-   DesktopRemoveEwin(ewin);
    MoveEwinToDesktop(ewin, ewin->desktop + 1);
    RaiseEwin(ewin);
    ICCCM_Configure(ewin);
@@ -2859,7 +2821,6 @@ doSendToPrevDesk(void *params)
    if (!ewin)
       EDBUG_RETURN(0);
 
-   DesktopRemoveEwin(ewin);
    MoveEwinToDesktop(ewin, ewin->desktop - 1);
    RaiseEwin(ewin);
    ICCCM_Configure(ewin);
@@ -2971,10 +2932,15 @@ doFocusSet(void *params)
    ewin = (EWin *) FindItem(NULL, win, LIST_FINDBY_ID, LIST_TYPE_EWIN);
    if (ewin)
      {
+	if (!ewin->sticky)
+	  {
+	     GotoDesktop(ewin->desktop);
+	     SetCurrentArea(ewin->area_x, ewin->area_y);
+	  }
 	if (ewin->iconified)
 	   DeIconifyEwin(ewin);
-	GotoDesktop(ewin->desktop);
-	SetCurrentArea(ewin->area_x, ewin->area_y);
+	if (ewin->shaded)
+	   UnShadeEwin(ewin);
 	if (mode.raise_on_next_focus || mode.raise_after_next_focus)
 	   RaiseEwin(ewin);
 	if (mode.warp_on_next_focus)
@@ -3107,6 +3073,7 @@ doSetLayer(void *params)
      }
    ewin->layer = l;
    RaiseEwin(ewin);
+   HintsSetWindowState(ewin);
    RememberImportantInfoForEwin(ewin);
    EDBUG_RETURN(0);
 }
@@ -3291,8 +3258,7 @@ doAbout(void *params)
    EDBUG(6, "doAbout");
    if (InZoom())
       EDBUG_RETURN(0);
-   if (
-       (d =
+   if ((d =
 	FindItem("ABOUT_ENLIGHTENMENT", 0, LIST_FINDBY_NAME, LIST_TYPE_DIALOG)))
      {
 	ShowDialog(d);
@@ -3347,7 +3313,7 @@ doFX(void *params)
    if (InZoom())
       EDBUG_RETURN(0);
    if (params)
-      FX_Start((char *)params);
+      FX_Op((const char *)params, FX_OP_TOGGLE);
    autosave();
    EDBUG_RETURN(0);
 }
@@ -3453,8 +3419,10 @@ doConfigure(void *params)
 	   SettingsAutoRaise();
 	else if (!strcmp(s, "tooltips"))
 	   SettingsTooltips();
+#if ENABLE_KDE
 	else if (!strcmp(s, "kde"))
 	   SettingsKDE();
+#endif
 	else if (!strcmp(s, "audio"))
 	   SettingsAudio();
 	else if (!strcmp(s, "fx"))
@@ -3637,7 +3605,6 @@ doInsertKeys(void *params)
 		  ev.x_root = mode.x;
 		  ev.y_root = mode.y;
 		  for (j = 0; j < (int)(sizeof(ks) / sizeof(struct _keyset));
-
 		       j++)
 		    {
 		       if (!strncmp(ks[j].ch, &(s[i]), strlen(ks[j].ch)))
