@@ -1,6 +1,6 @@
 
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -38,10 +38,6 @@ static char        *ExitText = NULL;
 
 static char        *TitleText = NULL;
 
-int                 call_level;
-int                 debug_level;
-char               *call_stack[1024];
-
 void
 Alert(char *fmt, ...)
 {
@@ -49,20 +45,13 @@ Alert(char *fmt, ...)
    va_list             ap;
 
    EDBUG(7, "Alert");
-   SC_Kill();
+
    va_start(ap, fmt);
-/*
- * #ifdef __USE_GNU
- */
    Evsnprintf(text, 10240, fmt, ap);
-/*
- * #else
- * vsprintf(text, fmt, ap);
- * #endif
- */
    va_end(ap);
    AUDIO_PLAY("SOUND_ALERT");
    ShowAlert(text);
+
    EDBUG_RETURN_;
 }
 
@@ -70,10 +59,11 @@ void
 AssignTitleText(char *text)
 {
    EDBUG(7, "AssignTitleText");
+
    if (TitleText)
       Efree(TitleText);
-   TitleText = NULL;
    TitleText = duplicate(text);
+
    EDBUG_RETURN_;
 }
 
@@ -81,11 +71,12 @@ void
 AssignIgnoreText(char *text)
 {
    EDBUG(7, "AssignIgnoreText");
+
    if (IgnoreText)
       Efree(IgnoreText);
-   IgnoreText = NULL;
    IgnoreText = Emalloc(strlen(text) + 6);
    sprintf(IgnoreText, "(F1) %s", text);
+
    EDBUG_RETURN_;
 }
 
@@ -93,11 +84,12 @@ void
 AssignRestartText(char *text)
 {
    EDBUG(7, "AssignRestartText");
+
    if (RestartText)
       Efree(RestartText);
-   RestartText = NULL;
    RestartText = Emalloc(strlen(text) + 6);
    sprintf(RestartText, "(F2) %s", text);
+
    EDBUG_RETURN_;
 }
 
@@ -105,11 +97,12 @@ void
 AssignExitText(char *text)
 {
    EDBUG(7, "AssignExitText");
+
    if (ExitText)
       Efree(ExitText);
-   ExitText = NULL;
    ExitText = Emalloc(strlen(text) + 6);
    sprintf(ExitText, "(F3) %s", text);
+
    EDBUG_RETURN_;
 }
 
@@ -330,26 +323,23 @@ goto CN; \
 
    if (sscanf(str1, "%s", line) > 0)
      {
-	b1 =
-	   XCreateWindow(dd, win, -100, -100, 1, 1, 0,
-			 DefaultDepth(dd, DefaultScreen(dd)), InputOutput,
-			 DefaultVisual(dd, DefaultScreen(dd)), mask, &att);
+	b1 = XCreateWindow(dd, win, -100, -100, 1, 1, 0,
+			   DefaultDepth(dd, DefaultScreen(dd)), InputOutput,
+			   DefaultVisual(dd, DefaultScreen(dd)), mask, &att);
 	EMapWindow(dd, b1);
      }
    if (sscanf(str2, "%s", line) > 0)
      {
-	b2 =
-	   XCreateWindow(dd, win, -100, -100, 1, 1, 0,
-			 DefaultDepth(dd, DefaultScreen(dd)), InputOutput,
-			 DefaultVisual(dd, DefaultScreen(dd)), mask, &att);
+	b2 = XCreateWindow(dd, win, -100, -100, 1, 1, 0,
+			   DefaultDepth(dd, DefaultScreen(dd)), InputOutput,
+			   DefaultVisual(dd, DefaultScreen(dd)), mask, &att);
 	EMapWindow(dd, b2);
      }
    if (sscanf(str3, "%s", line) > 0)
      {
-	b3 =
-	   XCreateWindow(dd, win, -100, -100, 1, 1, 0,
-			 DefaultDepth(dd, DefaultScreen(dd)), InputOutput,
-			 DefaultVisual(dd, DefaultScreen(dd)), mask, &att);
+	b3 = XCreateWindow(dd, win, -100, -100, 1, 1, 0,
+			   DefaultDepth(dd, DefaultScreen(dd)), InputOutput,
+			   DefaultVisual(dd, DefaultScreen(dd)), mask, &att);
 	EMapWindow(dd, b3);
      }
 
