@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -115,7 +115,7 @@ SetAreaSize(int aw, int ah)
       ah = 1;
    area_w = aw;
    area_h = ah;
-   GNOME_SetAreaCount();
+   HintsSetViewportConfig();
    PagerReArea();
    EDBUG_RETURN_;
 }
@@ -290,7 +290,9 @@ SetCurrentArea(int ax, int ay)
      }
    /* remove lots of event masks from windows.. we dont want to bother */
    /* handling events as a result of our playing wiht windows */
+#if 0				/* Clean up if not causing trouble */
    FocusToEWin(NULL);
+#endif
    BeginNewDeskFocus();
    /* move all the windows around */
    lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
@@ -338,7 +340,7 @@ SetCurrentArea(int ax, int ay)
 	     for (i = 0; i < num; i++)
 	       {
 		  if ((lst[i]->desktop == desks.current) && (!lst[i]->sticky)
-		      && (!lst[i]->fixedpos) && (!lst[i]->iconified))
+		      && (!lst[i]->fixedpos))
 		    {
 		       if (!lst[i]->floating)
 			 {
@@ -366,7 +368,7 @@ SetCurrentArea(int ax, int ay)
 			       mode.flipp = 0;
 			    lst[i]->area_x = a1;
 			    lst[i]->area_y = a2;
-			    GNOME_SetEwinArea(lst[i]);
+			    HintsSetWindowArea(lst[i]);
 			 }
 		    }
 	       }
@@ -377,7 +379,7 @@ SetCurrentArea(int ax, int ay)
 	     for (i = 0; i < num; i++)
 	       {
 		  if ((lst[i]->desktop == desks.current) && (!lst[i]->sticky)
-		      && (!lst[i]->fixedpos) && (!lst[i]->iconified))
+		      && (!lst[i]->fixedpos))
 		    {
 		       /* if we're moving this window and its not opaque move */
 		       /* warp it across withotu remebering the xy stuff */
@@ -392,12 +394,13 @@ SetCurrentArea(int ax, int ay)
 					     (root.w *
 					      (ax -
 					       desks.desk[desks.
-							  current].current_area_x)),
+							  current].
+					       current_area_x)),
 					     y -
 					     (root.h *
 					      (ay -
-					       desks.desk[desks.
-							  current].current_area_y)));
+					       desks.desk[desks.current].
+					       current_area_y)));
 			      }
 			 }
 		       /* if we're not moving it... move it across */
@@ -427,7 +430,7 @@ SetCurrentArea(int ax, int ay)
 			       mode.flipp = 0;
 			    lst[i]->area_x = a1;
 			    lst[i]->area_y = a2;
-			    GNOME_SetEwinArea(lst[i]);
+			    HintsSetWindowArea(lst[i]);
 			 }
 		    }
 	       }
@@ -437,8 +440,8 @@ SetCurrentArea(int ax, int ay)
    /* set the current area up in out data structs */
    desks.desk[desks.current].current_area_x = ax;
    desks.desk[desks.current].current_area_y = ay;
-   /* set gnome hints up for it */
-   GNOME_SetCurrentArea();
+   /* set hints up for it */
+   HintsSetDesktopViewport();
    XSync(disp, False);
    /* redraw any windows that were in "move mode" */
    mode.moveresize_pending_ewin = NULL;
@@ -515,6 +518,7 @@ SetCurrentArea(int ax, int ay)
    ShowEdgeWindows();
    /* update our pager */
    UpdatePagerSel();
+   RedrawPagersForDesktop(desks.current, 3);
    ForceUpdatePagersForDesktop(desks.current);
    EDBUG_RETURN_;
 }
@@ -528,7 +532,7 @@ MoveEwinToArea(EWin * ewin, int ax, int ay)
 	    ewin->y + (root.h * (ay - ewin->area_y)));
    ewin->area_x = ax;
    ewin->area_y = ay;
-   GNOME_SetEwinArea(ewin);
+   HintsSetWindowArea(ewin);
    EDBUG_RETURN_;
 }
 
@@ -538,7 +542,7 @@ SetEwinToCurrentArea(EWin * ewin)
    EDBUG(4, "SetEwinToCurrentArea");
    ewin->area_x = desks.desk[ewin->desktop].current_area_x;
    ewin->area_y = desks.desk[ewin->desktop].current_area_y;
-   GNOME_SetEwinArea(ewin);
+   HintsSetWindowArea(ewin);
    EDBUG_RETURN_;
 }
 
