@@ -1,6 +1,5 @@
-
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -91,58 +90,24 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 
    EDBUG(7, "ArrangeRects");
 
-#ifdef HAS_XINERAMA
+#define Filled(x,y) (filled[(y * (xsize - 1)) + x])
+
    if (initial_window)
      {
-	if (xinerama_active)
-	  {
-	     Window              rt, ch;
-	     int                 d;
-	     unsigned int        ud;
-	     int                 pointer_x, pointer_y;
-	     int                 num;
-	     XineramaScreenInfo *screens;
+	int                 xx1, yy1, xx2, yy2;
 
-	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y, &d,
-			   &d, &ud);
-
-	     screens = XineramaQueryScreens(disp, &num);
-	     for (i = 0; i < num; i++)
-	       {
-		  if (pointer_x >= screens[i].x_org)
-		    {
-		       if (pointer_x <= (screens[i].width + screens[i].x_org))
-			 {
-			    if (pointer_y >= screens[i].y_org)
-			      {
-				 if (pointer_y <=
-				     (screens[i].height + screens[i].y_org))
-				   {
-				      if (screens[i].x_org > startx)
-					 startx = screens[i].x_org;
-				      if ((screens[i].x_org + screens[i].width)
-					  < width)
-					 width =
-					    screens[i].x_org + screens[i].width;
-				      if (screens[i].y_org > starty)
-					 starty = screens[i].y_org;
-				      if ((screens[i].y_org + screens[i].height)
-					  < height)
-					 height =
-					    screens[i].y_org +
-					    screens[i].height;
-				   }
-			      }
-			 }
-		    }
-	       }
-
-	     XFree(screens);
-	  }
+	GetPointerScreenGeometry(&xx1, &yy1, &xx2, &yy2);
+	xx2 += xx1;
+	yy2 += yy1;
+	if (startx < xx1)
+	   startx = xx1;
+	if (width > xx2)
+	   width = xx2;
+	if (starty < yy1)
+	   starty = yy1;
+	if (height > yy2)
+	   height = yy2;
      }
-#else
-   initial_window = 0;
-#endif
 
    switch (policy)
      {
@@ -173,8 +138,7 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     for (i = 0; i < floating_count - 1; i++)
 	       {
 		  a1 = floating[i].x + floating[i].y;
-		  a2 =
-		     (floating[i + 1].x + (floating[i + 1].w >> 1)) +
+		  a2 = (floating[i + 1].x + (floating[i + 1].w >> 1)) +
 		     (floating[i + 1].y + (floating[i + 1].h >> 1));
 		  if (a2 < a1)
 		    {
@@ -197,48 +161,9 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
    if (floating_count)
       leftover = Emalloc(floating_count * sizeof(int));
 
-   if (!xarray)
-     {
-	if (yarray)
-	   Efree(yarray);
-	if (filled)
-	   Efree(filled);
-	if (spaces)
-	   Efree(spaces);
-	if (leftover)
-	   Efree(leftover);
-	EDBUG_RETURN_;
-     }
-   if (!yarray)
-     {
-	Efree(xarray);
-	if (filled)
-	   Efree(filled);
-	if (spaces)
-	   Efree(spaces);
-	if (leftover)
-	   Efree(leftover);
-	EDBUG_RETURN_;
-     }
-   if (!filled)
-     {
-	Efree(xarray);
-	Efree(yarray);
-	if (spaces)
-	   Efree(spaces);
-	if (leftover)
-	   Efree(leftover);
-	EDBUG_RETURN_;
-     }
-   if (!spaces)
-     {
-	Efree(xarray);
-	Efree(yarray);
-	Efree(filled);
-	if (leftover)
-	   Efree(leftover);
-	EDBUG_RETURN_;
-     }
+   if (!xarray || !yarray || !filled || !spaces)
+      goto exit;
+
 /* copy "fixed" rects into the sorted list */
    for (i = 0; i < fixed_count; i++)
      {
@@ -307,9 +232,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		    {
 		       for (x = x1; x <= x2; x++)
 			 {
-			    if (filled[(y * (xsize - 1)) + x] <
-				(sorted[j].p + 1))
-			       filled[(y * (xsize - 1)) + x] = sorted[j].p + 1;
+			    if (Filled(x, y) <= sorted[j].p)
+			       Filled(x, y) = sorted[j].p + 1;
 			 }
 		    }
 	       }
@@ -321,14 +245,14 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     for (x = 0; x < xsize - 1; x++)
 	       {
 /* if the square is empty (lowe prioiryt suares filled) "grow" the space */
-		  if (filled[(y * (xsize - 1)) + x] < (floating[i].p + 1))
+		  if (Filled(x, y) <= floating[i].p)
 		    {
 		       int                 can_expand_x = 1;
 		       int                 can_expand_y = 1;
 
 		       x1 = x + 1;
 		       y1 = y + 1;
-		       filled[(y * (xsize - 1)) + x] = 100;
+		       Filled(x, y) = 100;
 		       if (x >= xsize - 2)
 			  can_expand_x = 0;
 		       if (y >= ysize - 2)
@@ -343,8 +267,7 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 			      {
 				 for (j = y; j < y1; j++)
 				   {
-				      if (filled[(j * (xsize - 1)) + x1] >=
-					  (floating[i].p + 1))
+				      if (Filled(x1, j) >= floating[i].p + 1)
 					 can_expand_x = 0;
 				   }
 			      }
@@ -354,8 +277,7 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 			      {
 				 for (j = x; j < x1; j++)
 				   {
-				      if (filled[(y1 * (xsize - 1)) + j] >=
-					  (floating[i].p + 1))
+				      if (Filled(j, y1) >= floating[i].p + 1)
 					 can_expand_y = 0;
 				   }
 			      }
@@ -389,14 +311,12 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 				   {
 				      if (policy == ARRANGE_BY_POSITION)
 					{
-					   a1 =
-					      (spaces[j].x +
-					       (spaces[j].w >> 1)) -
+					   a1 = (spaces[j].x +
+						 (spaces[j].w >> 1)) -
 					      (floating[i].x +
 					       (floating[i].w >> 1));
-					   a2 =
-					      (spaces[j].y +
-					       (spaces[j].h >> 1)) -
+					   a2 = (spaces[j].y +
+						 (spaces[j].h >> 1)) -
 					      (floating[i].y +
 					       (floating[i].h >> 1));
 					   if (a1 < 0)
@@ -424,14 +344,12 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	  {
 	     if (policy == ARRANGE_BY_POSITION)
 	       {
-		  a1 =
-		     (spaces[k].x + (spaces[k].w >> 1)) - (floating[i].x +
-							   (floating[i].w >>
-							    1));
-		  a2 =
-		     (spaces[k].y + (spaces[k].h >> 1)) - (floating[i].y +
-							   (floating[i].h >>
-							    1));
+		  a1 = (spaces[k].x + (spaces[k].w >> 1)) - (floating[i].x +
+							     (floating[i].w >>
+							      1));
+		  a2 = (spaces[k].y + (spaces[k].h >> 1)) - (floating[i].y +
+							     (floating[i].h >>
+							      1));
 		  if (a1 >= 0)
 		    {
 		       sorted[num_sorted].x = spaces[k].x;
@@ -466,8 +384,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	   leftover[num_leftover++] = i;
      }
 
-   /* ok we cant fit everything in this baby.... time fit */
-   /*the leftovers into the leftover space */
+   /* ok we cant fit everything in this baby.... time to fit */
+   /* the leftovers into the leftover space */
    for (i = 0; i < num_leftover; i++)
      {
 	xsize = 0;
@@ -524,9 +442,8 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		    {
 		       for (x = x1; x <= x2; x++)
 			 {
-			    if (filled[(y * (xsize - 1)) + x] <
-				(sorted[j].p + 1))
-			       filled[(y * (xsize - 1)) + x] = sorted[j].p + 1;
+			    if (Filled(x, y) <= sorted[j].p)
+			       Filled(x, y) = sorted[j].p + 1;
 			 }
 		    }
 	       }
@@ -538,7 +455,7 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     for (x = 0; x < xsize - 1; x++)
 	       {
 		  /* if the square is empty "grow" the space */
-		  if (!filled[(y * (xsize - 1)) + x])
+		  if (Filled(x, y) <= floating[leftover[i]].p)
 		    {
 		       int                 can_expand_x = 1;
 		       int                 can_expand_y = 1;
@@ -560,14 +477,9 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 			      {
 				 for (j = y; j < y1; j++)
 				   {
-				      if (filled[(j * (xsize - 1)) + x1] >=
-					  (floating[leftover[i]].p + 1))
-					{
-					   if (filled[(j * (xsize - 1)) + x1] >
-					       (floating[leftover[i]].p + 1))
-					      fitswin = 0;
-					   can_expand_x = 0;
-					}
+				      if (Filled(x1, j) >
+					  floating[leftover[i]].p + 1)
+					 can_expand_x = 0;
 				   }
 			      }
 			    if (can_expand_x)
@@ -576,14 +488,9 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 			      {
 				 for (j = x; j < x1; j++)
 				   {
-				      if (filled[(y1 * (xsize - 1)) + j] >=
-					  (floating[leftover[i]].p + 1))
-					{
-					   if (filled[(y1 * (xsize - 1)) + j] >
-					       (floating[leftover[i]].p + 1))
-					      fitswin = 0;
-					   can_expand_y = 0;
-					}
+				      if (Filled(j, y1) >
+					  floating[leftover[i]].p + 1)
+					 can_expand_y = 0;
 				   }
 			      }
 			    if (can_expand_y)
@@ -593,6 +500,9 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 		       spaces[num_spaces].y = yarray[y];
 		       spaces[num_spaces].w = xarray[x1] - xarray[x];
 		       spaces[num_spaces].h = yarray[y1] - yarray[y];
+		       if (spaces[num_spaces].w < floating[leftover[i]].w ||
+			   spaces[num_spaces].h < floating[leftover[i]].h)
+			  fitswin = 0;
 		       spaces[num_spaces].p = fitswin;
 		       num_spaces++;
 		    }
@@ -646,13 +556,6 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	     num_sorted++;
 	  }
      }
-   /* free up memory */
-   Efree(xarray);
-   Efree(yarray);
-   Efree(filled);
-   Efree(spaces);
-   if (leftover)
-      Efree(leftover);
    for (i = 0; i < num_sorted; i++)
      {
 	if ((sorted[i].x + sorted[i].w) > width)
@@ -664,6 +567,20 @@ ArrangeRects(RectBox * fixed, int fixed_count, RectBox * floating,
 	if (sorted[i].y < starty)
 	   sorted[i].y = starty;
      }
+
+ exit:
+   /* free up memory */
+   if (xarray)
+      Efree(xarray);
+   if (yarray)
+      Efree(yarray);
+   if (filled)
+      Efree(filled);
+   if (spaces)
+      Efree(spaces);
+   if (leftover)
+      Efree(leftover);
+
    EDBUG_RETURN_;
 }
 
@@ -673,13 +590,7 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
    EWin              **lst, **gwins;
    int                 gnum, num, i, j, screen_snap_dist, odx, ody;
    static char         last_res = 0;
-
-#ifdef HAS_XINERAMA
-   static XineramaScreenInfo *screens = NULL;
-
-#endif
-   static int          num_screens = 0;
-   int                 top_bound, bottom_bound, left_bound, right_bound;
+   int                 top_bound, bottom_bound, left_bound, right_bound, w, h;
 
    EDBUG(5, "SnapEwin");
    if (!ewin)
@@ -692,49 +603,10 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	EDBUG_RETURN_;
      }
 
-   left_bound = 0;
-   right_bound = root.w;
-   top_bound = 0;
-   bottom_bound = root.h;
-
-   screen_snap_dist =
-      mode.constrained ? (root.w + root.h) : mode.screen_snap_dist;
-
-#ifdef HAS_XINERAMA
-
-   if (xinerama_active)
-     {
-	if (!screens)
-	   screens = XineramaQueryScreens(disp, &num_screens);
-	for (i = 0; i < num_screens; i++)
-	  {
-	     if (ewin->x >= screens[i].x_org)
-	       {
-		  if (ewin->x <= (screens[i].width + screens[i].x_org))
-		    {
-		       if (ewin->y >= screens[i].y_org)
-			 {
-			    if (ewin->y <=
-				(screens[i].height + screens[i].y_org))
-			      {
-				 left_bound = screens[i].x_org;
-				 right_bound =
-				    screens[i].x_org + screens[i].width;
-				 top_bound = screens[i].y_org;
-				 bottom_bound =
-				    screens[i].y_org + screens[i].height;
-				 screen_snap_dist =
-				    mode.constrained ? (screens[i].width +
-							screens[i].height) :
-				    mode.screen_snap_dist;
-			      }
-			 }
-		    }
-	       }
-
-	  }
-     }
-#endif
+   ScreenGetGeometry(ewin->x, ewin->y, &left_bound, &top_bound, &w, &h);
+   right_bound = left_bound + w;
+   bottom_bound = top_bound + h;
+   screen_snap_dist = mode.constrained ? (w + h) : mode.screen_snap_dist;
 
    lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
    gwins = ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup
@@ -914,6 +786,46 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 
 void
 ArrangeEwin(EWin * ewin)
+{
+   EDBUG(8, "ArrangeEwin");
+
+   ewin->client.already_placed = 1;
+   ArrangeEwinXY(ewin, &ewin->x, &ewin->y);
+   MoveEwin(ewin, ewin->x, ewin->y);
+
+   EDBUG_RETURN_;
+}
+
+void
+ArrangeEwinCentered(EWin * ewin, int focus)
+{
+   EDBUG(8, "ArrangeEwinCentered");
+
+   ewin->client.already_placed = 1;
+   ArrangeEwinCenteredXY(ewin, &ewin->x, &ewin->y);
+   MoveEwin(ewin, ewin->x, ewin->y);
+   if (focus)
+      FocusToEWin(ewin);
+
+   EDBUG_RETURN_;
+}
+
+static int
+EWinIsOnViewport(EWin * ewin, int desktop)
+{
+   if (ewin->sticky)
+      return 1;
+
+   if (ewin->desktop == desktop &&
+       ewin->area_x == desks.desk[desktop].current_area_x &&
+       ewin->area_y == desks.desk[desktop].current_area_y)
+      return 1;
+
+   return 0;
+}
+
+void
+ArrangeEwinXY(EWin * ewin, int *px, int *py)
 {
    EWin              **lst;
    Button            **blst;
@@ -922,29 +834,67 @@ ArrangeEwin(EWin * ewin)
 
    fixed = NULL;
    ret = NULL;
-   ewin->client.already_placed = 1;
+
    lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
    if ((lst) && (num > 0))
      {
 	fixed = Emalloc(sizeof(RectBox) * num);
-	ret = Emalloc(sizeof(RectBox) * (num + 1));
 	j = 0;
 	for (i = 0; i < num; i++)
 	  {
-	     if ((lst[i] != ewin) && (!lst[i]->iconified)
-		 && (!lst[i]->ignorearrange) && (lst[i]->layer != 0)
-		 &&
-		 (((lst
-		    [i]->area_x == desks.desk[ewin->desktop].current_area_x)
-		   && (lst[i]->area_y ==
-		       desks.desk[ewin->desktop].current_area_y)
-		   && (lst[i]->desktop == ewin->desktop)) || (lst[i]->sticky)))
+	     EWin               *e = lst[i];
+
+	     if (e == ewin ||
+		 e->iconified || e->ignorearrange || e->layer == 0 ||
+		 !EWinIsOnViewport(e, ewin->desktop))
+		continue;
+
+	     fixed[j].data = e;
+	     fixed[j].x = e->x;
+	     fixed[j].y = e->y;
+	     fixed[j].w = e->w;
+	     fixed[j].h = e->h;
+	     if (fixed[j].x < 0)
 	       {
-		  fixed[j].data = lst[i];
-		  fixed[j].x = (lst[i])->x;
-		  fixed[j].y = (lst[i])->y;
-		  fixed[j].w = (lst[i])->w;
-		  fixed[j].h = (lst[i])->h;
+		  fixed[j].w += fixed[j].x;
+		  fixed[j].x = 0;
+	       }
+	     if ((fixed[j].x + fixed[j].w) > root.w)
+		fixed[j].w = root.w - fixed[j].x;
+	     if (fixed[j].y < 0)
+	       {
+		  fixed[j].h += fixed[j].y;
+		  fixed[j].y = 0;
+	       }
+	     if ((fixed[j].y + fixed[j].h) > root.h)
+		fixed[j].h = root.h - fixed[j].y;
+	     if ((fixed[j].w <= 0) || (fixed[j].h <= 0))
+		continue;
+
+	     if (e->never_use_area)
+		fixed[j].p = 50;
+	     else
+		fixed[j].p = e->layer;
+	     j++;
+	  }
+	blst = (Button **) ListItemType(&num, LIST_TYPE_BUTTON);
+	if (blst)
+	  {
+	     fixed = Erealloc(fixed, sizeof(RectBox) * (num + j));
+	     for (i = 0; i < num; i++)
+	       {
+		  Button             *b = blst[i];
+
+		  if (!b->visible || b->internal)
+		     continue;
+		  if (!b->sticky && (b->desktop != ewin->desktop))
+		     continue;
+
+		  fixed[j].data = NULL;
+		  fixed[j].x = b->x;
+		  fixed[j].y = b->y;
+		  fixed[j].w = b->w;
+		  fixed[j].h = b->h;
 		  if (fixed[j].x < 0)
 		    {
 		       fixed[j].w += fixed[j].x;
@@ -959,89 +909,46 @@ ArrangeEwin(EWin * ewin)
 		    }
 		  if ((fixed[j].y + fixed[j].h) > root.h)
 		     fixed[j].h = root.h - fixed[j].y;
-		  if ((fixed[j].w > 0) && (fixed[j].h > 0))
-		    {
-		       if (!(lst[i])->never_use_area)
-			 {
-			    fixed[j].p = (lst[i])->layer;
-			 }
-		       else
-			 {
-			    fixed[j].p = 50;
-			 }
-		       j++;
-		    }
-	       }
-	  }
-	blst = (Button **) ListItemType(&num, LIST_TYPE_BUTTON);
-	if (blst)
-	  {
-	     fixed = Erealloc(fixed, sizeof(RectBox) * (num + j));
-	     ret = Erealloc(ret, sizeof(RectBox) * ((num + j) + 1));
-	     for (i = 0; i < num; i++)
-	       {
-		  if (((blst[i]->desktop == ewin->desktop)
-		       || ((blst[i]->desktop == 0) && (blst[i]->sticky)))
-		      && (blst[i]->visible))
-		    {
-		       fixed[j].data = NULL;
-		       fixed[j].x = blst[i]->x;
-		       fixed[j].y = blst[i]->y;
-		       fixed[j].w = blst[i]->w;
-		       fixed[j].h = blst[i]->h;
-		       if (fixed[j].x < 0)
-			 {
-			    fixed[j].w += fixed[j].x;
-			    fixed[j].x = 0;
-			 }
-		       if ((fixed[j].x + fixed[j].w) > root.w)
-			  fixed[j].w = root.w - fixed[j].x;
-		       if (fixed[j].y < 0)
-			 {
-			    fixed[j].h += fixed[j].y;
-			    fixed[j].y = 0;
-			 }
-		       if ((fixed[j].y + fixed[j].h) > root.h)
-			  fixed[j].h = root.h - fixed[j].y;
-		       if ((fixed[j].w > 0) && (fixed[j].h > 0))
-			 {
-			    if (blst[i]->sticky)
-			      {
-				 fixed[j].p = 50;
-			      }
-			    else
-			      {
-				 fixed[j].p = 0;
-			      }
-			    j++;
-			 }
-		    }
+		  if ((fixed[j].w <= 0) || (fixed[j].h <= 0))
+		     continue;
+
+		  if (b->sticky)
+		     fixed[j].p = 1;
+		  else
+		     fixed[j].p = 0;
+		  j++;
 	       }
 	     Efree(blst);
 	  }
+	ret = Emalloc(sizeof(RectBox) * (j + 1));
 	newrect.data = ewin;
 	newrect.x = 0;
 	newrect.y = 0;
 	newrect.w = ewin->w;
 	newrect.h = ewin->h;
 	newrect.p = ewin->layer;
+#if ENABLE_KDE
 	if (mode.kde_support)
 	  {
-	     ArrangeRects(fixed, j, &newrect, 1, ret, mode.kde_x1, mode.kde_y1,
-			  mode.kde_x2, mode.kde_y2, ARRANGE_BY_SIZE, 1);
+	     ArrangeRects(fixed, j, &newrect, 1, ret,
+			  mode.kde_x1, mode.kde_y1, mode.kde_x2, mode.kde_y2,
+			  ARRANGE_BY_SIZE, 1);
+
 	  }
 	else
+#endif
 	  {
-	     ArrangeRects(fixed, j, &newrect, 1, ret, 0, 0, root.w, root.h,
-			  ARRANGE_BY_SIZE, 1);
+	     ArrangeRects(fixed, j, &newrect, 1, ret,
+			  0, 0, root.w, root.h, ARRANGE_BY_SIZE, 1);
 	  }
+
 	for (i = 0; i < j + 1; i++)
 	  {
 	     if (ret[i].data == ewin)
 	       {
-		  ewin->x = ret[i].x;
-		  ewin->y = ret[i].y;
-		  i = j + 1;
+		  *px = ret[i].x;
+		  *py = ret[i].y;
+		  break;
 	       }
 	  }
 	Efree(lst);
@@ -1052,51 +959,16 @@ ArrangeEwin(EWin * ewin)
      }
    else
      {
-#ifdef HAS_XINERAMA
-	if (xinerama_active)
-	  {
-	     Window              rt, ch;
-	     XineramaScreenInfo *screens;
-	     int                 pointer_x, pointer_y;
-	     int                 num;
-	     int                 d;
-	     unsigned int        ud;
-
-	     XQueryPointer(disp, root.win, &rt, &ch, &pointer_x, &pointer_y, &d,
-			   &d, &ud);
-	     screens = XineramaQueryScreens(disp, &num);
-	     for (i = 0; i < num; i++)
-	       {
-		  if (pointer_x >= screens[i].x_org)
-		    {
-		       if (pointer_x <= (screens[i].width + screens[i].x_org))
-			 {
-			    if (pointer_y >= screens[i].y_org)
-			      {
-				 if (pointer_y <=
-				     (screens[i].height + screens[i].y_org))
-				   {
-				      ewin->x =
-					 ((screens[i].width - ewin->w) / 2) +
-					 screens[i].x_org;
-				      ewin->y =
-					 ((screens[i].height - ewin->h) / 2) +
-					 screens[i].y_org;
-				   }
-			      }
-			 }
-		    }
-	       }
-	     XFree(screens);
-	  }
-	else
-	  {
-#endif
-	     ewin->x = (root.w - ewin->w) >> 1;
-	     ewin->y = (root.h - ewin->h) >> 1;
-#ifdef HAS_XINERAMA
-	  }
-#endif
+	ArrangeEwinCenteredXY(ewin, px, py);
      }
-   MoveEwin(ewin, ewin->x, ewin->y);
+}
+
+void
+ArrangeEwinCenteredXY(EWin * ewin, int *px, int *py)
+{
+   int                 x, y, w, h;
+
+   GetPointerScreenGeometry(&x, &y, &w, &h);
+   *px = (w - ewin->w) / 2 + x;
+   *py = (h - ewin->h) / 2 + y;
 }
