@@ -1,6 +1,5 @@
-
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -23,6 +22,14 @@
  */
 #include "E.h"
 
+#if 0
+#define DELETE_EWIN_REFERENCE(ew, ew_ref) \
+	({ if (ew_ref == ew) { printf("Stale ewin ref (" #ew_ref ")\n"); ew_ref = NULL; } })
+#else
+#define DELETE_EWIN_REFERENCE(ew, ew_ref) \
+	({ if (ew_ref == ew) { ew_ref = NULL; } })
+#endif
+
 void
 SetFrameProperty(EWin * ewin)
 {
@@ -88,7 +95,8 @@ DetermineEwinFloat(EWin * ewin, int dx, int dy)
 					  (desks.desk[ewin->desktop].x +
 					   ewin->x + dx + ewin->w - 1,
 					   desks.desk[ewin->desktop].y) !=
-					  ewin->desktop)))))) dofloat = 1;
+					  ewin->desktop))))))
+	   dofloat = 1;
 	if ((desks.dragdir == 1)
 	    && (((ewin->x + dx + ewin->w > root.w) || ((ewin->x + dx >= 0)
 						       &&
@@ -100,7 +108,7 @@ DetermineEwinFloat(EWin * ewin, int dx, int dy)
 							  desk[ewin->desktop].
 							  y) !=
 							 ewin->desktop))))))
-	      dofloat = 1;
+	   dofloat = 1;
 	if ((desks.dragdir == 2)
 	    &&
 	    (((ewin->
@@ -121,7 +129,7 @@ DetermineEwinFloat(EWin * ewin, int dx, int dy)
 							  desk[ewin->desktop].y
 							  + ewin->y + dy) !=
 							 ewin->desktop))))))
-	      dofloat = 1;
+	   dofloat = 1;
 	if (dofloat)
 	   FloatEwinAt(ewin, ewin->x + desks.desk[ewin->desktop].x,
 		       ewin->y + desks.desk[ewin->desktop].y);
@@ -371,11 +379,9 @@ AddToFamily(Window win)
 {
    EWin               *ewin, *ewin2;
    EWin              **lst;
-   Button            **blst;
-   int                 i, j, k, num, speed, fx, fy, x, y;
+   int                 i, k, num, speed, fx, fy, x, y;
    char                doslide, manplace;
    char                pq;
-   RectBox            *fixed, *ret, newrect;
    Window              winid;
    char                cangrab = 0;
 
@@ -567,190 +573,8 @@ AddToFamily(Window win)
 	  }
 	else
 	  {
-
 	     ewin->client.already_placed = 1;
-	     lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
-	     if ((lst) && (num > 0))
-	       {
-		  fixed = Emalloc(sizeof(RectBox) * num);
-		  ret = Emalloc(sizeof(RectBox) * (num + 1));
-		  j = 0;
-		  for (i = 0; i < num; i++)
-		    {
-		       if ((lst[i] != ewin) && (!lst[i]->iconified)
-			   && (!lst[i]->ignorearrange) && (lst[i]->layer != 0)
-			   &&
-			   (((lst
-			      [i]->area_x ==
-			      desks.desk[ewin->desktop].current_area_x)
-			     && (lst[i]->area_y ==
-				 desks.desk[ewin->desktop].current_area_y)
-			     && (lst[i]->desktop == ewin->desktop))
-			    || (lst[i]->sticky)))
-			 {
-			    fixed[j].data = lst[i];
-			    fixed[j].x = (lst[i])->x;
-			    fixed[j].y = (lst[i])->y;
-			    fixed[j].w = (lst[i])->w;
-			    fixed[j].h = (lst[i])->h;
-			    if (fixed[j].x < 0)
-			      {
-				 fixed[j].w += fixed[j].x;
-				 fixed[j].x = 0;
-			      }
-			    if ((fixed[j].x + fixed[j].w) > root.w)
-			       fixed[j].w = root.w - fixed[j].x;
-			    if (fixed[j].y < 0)
-			      {
-				 fixed[j].h += fixed[j].y;
-				 fixed[j].y = 0;
-			      }
-			    if ((fixed[j].y + fixed[j].h) > root.h)
-			       fixed[j].h = root.h - fixed[j].y;
-			    if ((fixed[j].w > 0) && (fixed[j].h > 0))
-			      {
-				 if (!(lst[i])->never_use_area)
-				    fixed[j].p = (lst[i])->layer;
-				 else
-				    fixed[j].p = 50;
-				 j++;
-			      }
-			 }
-		    }
-		  blst = (Button **) ListItemType(&num, LIST_TYPE_BUTTON);
-		  if (blst)
-		    {
-		       fixed = Erealloc(fixed, sizeof(RectBox) * (num + j));
-		       ret = Erealloc(ret, sizeof(RectBox) * ((num + j) + 1));
-		       for (i = 0; i < num; i++)
-			 {
-			    if (((blst[i]->desktop == ewin->desktop)
-				 || ((blst[i]->desktop == 0)
-				     && (blst[i]->sticky)))
-				&& (blst[i]->visible))
-			      {
-				 fixed[j].data = NULL;
-				 fixed[j].x = blst[i]->x;
-				 fixed[j].y = blst[i]->y;
-				 fixed[j].w = blst[i]->w;
-				 fixed[j].h = blst[i]->h;
-				 if (fixed[j].x < 0)
-				   {
-				      fixed[j].w += fixed[j].x;
-				      fixed[j].x = 0;
-				   }
-				 if ((fixed[j].x + fixed[j].w) > root.w)
-				    fixed[j].w = root.w - fixed[j].x;
-				 if (fixed[j].y < 0)
-				   {
-				      fixed[j].h += fixed[j].y;
-				      fixed[j].y = 0;
-				   }
-				 if ((fixed[j].y + fixed[j].h) > root.h)
-				    fixed[j].h = root.h - fixed[j].y;
-				 if ((fixed[j].w > 0) && (fixed[j].h > 0))
-				   {
-				      if (blst[i]->sticky)
-					 fixed[j].p = 50;
-				      else
-					 fixed[j].p = 0;
-				      j++;
-				   }
-			      }
-			 }
-		       Efree(blst);
-		    }
-		  newrect.data = ewin;
-		  newrect.x = 0;
-		  newrect.y = 0;
-		  newrect.w = ewin->w;
-		  newrect.h = ewin->h;
-		  newrect.p = ewin->layer;
-		  if (mode.kde_support)
-		    {
-		       ArrangeRects(fixed, j, &newrect, 1, ret, mode.kde_x1,
-				    mode.kde_y1, mode.kde_x2, mode.kde_y2,
-				    ARRANGE_BY_SIZE, 1);
-
-		    }
-		  else
-		    {
-		       ArrangeRects(fixed, j, &newrect, 1, ret, 0, 0, root.w,
-				    root.h, ARRANGE_BY_SIZE, 1);
-		    }
-		  for (i = 0; i < j + 1; i++)
-		    {
-		       if (ret[i].data == ewin)
-			 {
-			    x = ret[i].x;
-			    y = ret[i].y;
-			    i = j + 1;
-			 }
-		    }
-		  Efree(lst);
-		  if (ret)
-		     Efree(ret);
-		  if (fixed)
-		     Efree(fixed);
-	       }
-	     else
-	       {
-#ifdef HAS_XINERAMA
-		  if (xinerama_active)
-		    {
-		       Window              rt, ch;
-		       XineramaScreenInfo *screens;
-		       int                 pointer_x, pointer_y;
-		       int                 num;
-		       int                 d;
-		       unsigned int        ud;
-
-		       XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
-				     &pointer_y, &d, &d, &ud);
-		       screens = XineramaQueryScreens(disp, &num);
-		       for (i = 0; i < num; i++)
-			 {
-			    for (i = 0; i < num; i++)
-			      {
-				 if (pointer_x >= screens[i].x_org)
-				   {
-				      if (pointer_x <=
-					  (screens[i].width + screens[i].x_org))
-					{
-					   if (pointer_y >= screens[i].y_org)
-					     {
-						if (pointer_y <=
-						    (screens[i].height +
-						     screens[i].y_org))
-						  {
-						     ewin->x =
-							((screens
-							  [i].width -
-							  ewin->w) / 2) +
-							screens[i].x_org;
-						     ewin->y =
-							((screens
-							  [i].height -
-							  ewin->h) / 2) +
-							screens[i].y_org;
-						  }
-					     }
-					}
-				   }
-			      }
-			 }
-		       XFree(screens);
-		    }
-		  else
-		    {
-#endif
-		       ewin->x = (root.w - ewin->w) >> 1;
-		       ewin->y = (root.h - ewin->h) >> 1;
-#ifdef HAS_XINERAMA
-		    }
-#endif
-
-	       }
+	     ArrangeEwinXY(ewin, &x, &y);
 	  }			/* (mode.manual_placement_mouse_pointer) */
      }				/* ((!ewin->client.already_placed) && (!manplace)) */
    else
@@ -813,15 +637,6 @@ AddToFamily(Window win)
 	queue_up = pq;
 	MoveEwinToDesktopAt(ewin, ewin->desktop, x, y);
 	RaiseEwin(ewin);
-	if (init_win1)
-	  {
-	     XRaiseWindow(disp, init_win1);
-	     XRaiseWindow(disp, init_win2);
-	  }
-	if (init_win_ext)
-	   XRaiseWindow(disp, init_win_ext);
-	ShowEdgeWindows();
-	RaiseProgressbars();
 	ShowEwin(ewin);
 	StackDesktops();
 	UngrabX();
@@ -858,15 +673,6 @@ AddToFamily(Window win)
 	RaiseEwin(ewin);
 	MoveEwin(ewin, x, y);
 	RaiseEwin(ewin);
-	if (init_win1)
-	  {
-	     XRaiseWindow(disp, init_win1);
-	     XRaiseWindow(disp, init_win2);
-	  }
-	if (init_win_ext)
-	   XRaiseWindow(disp, init_win_ext);
-	ShowEdgeWindows();
-	RaiseProgressbars();
 	ShowEwin(ewin);
 	StackDesktops();
 	FocusToEWin(ewin);
@@ -911,15 +717,6 @@ AddToFamily(Window win)
 	MoveEwinToDesktop(ewin, ewin->desktop);
 	RaiseEwin(ewin);
 	MoveEwin(ewin, fx, fy);
-	if (init_win1)
-	  {
-	     XRaiseWindow(disp, init_win1);
-	     XRaiseWindow(disp, init_win2);
-	  }
-	if (init_win_ext)
-	   XRaiseWindow(disp, init_win_ext);
-	ShowEdgeWindows();
-	RaiseProgressbars();
 	ShowEwin(ewin);
 	SlideEwinTo(ewin, fx, fy, x, y, speed);
 	MoveEwinToDesktopAt(ewin, ewin->desktop, x, y);
@@ -934,15 +731,6 @@ AddToFamily(Window win)
 	queue_up = pq;
 	MoveEwinToDesktopAt(ewin, ewin->desktop, x, y);
 	RaiseEwin(ewin);
-	if (init_win1)
-	  {
-	     XRaiseWindow(disp, init_win1);
-	     XRaiseWindow(disp, init_win2);
-	  }
-	if (init_win_ext)
-	   XRaiseWindow(disp, init_win_ext);
-	ShowEdgeWindows();
-	RaiseProgressbars();
 	ShowEwin(ewin);
 	StackDesktops();
      }
@@ -1025,15 +813,7 @@ AddInternalToFamily(Window win, char noshow, char *bname, int type, void *ptr)
    queue_up = pq;
    MoveEwinToDesktopAt(ewin, ewin->desktop, x, y);
    RaiseEwin(ewin);
-   if (init_win1)
-     {
-	XRaiseWindow(disp, init_win1);
-	XRaiseWindow(disp, init_win2);
-     }
-   if (init_win_ext)
-      XRaiseWindow(disp, init_win_ext);
-   ShowEdgeWindows();
-   RaiseProgressbars();
+   StackDesktops();
    if (!noshow)
       ShowEwin(ewin);
    ICCCM_Configure(ewin);
@@ -1275,48 +1055,40 @@ CalcEwinWinpart(EWin * ewin, int i)
    x = y = 0;
    if (topleft == -1)
      {
-	x =
-	   ((ewin->border->part[i].geom.topleft.x.percent * ewin->w) >> 10) +
+	x = ((ewin->border->part[i].geom.topleft.x.percent * ewin->w) >> 10) +
 	   ewin->border->part[i].geom.topleft.x.absolute;
-	y =
-	   ((ewin->border->part[i].geom.topleft.y.percent * ewin->h) >> 10) +
+	y = ((ewin->border->part[i].geom.topleft.y.percent * ewin->h) >> 10) +
 	   ewin->border->part[i].geom.topleft.y.absolute;
      }
    else if (topleft >= 0)
      {
-	x =
-	   ((ewin->border->part[i].geom.topleft.x.percent *
-	     ewin->bits[topleft].w) >> 10) +
+	x = ((ewin->border->part[i].geom.topleft.x.percent *
+	      ewin->bits[topleft].w) >> 10) +
 	   ewin->border->part[i].geom.topleft.x.absolute +
 	   ewin->bits[topleft].x;
-	y =
-	   ((ewin->border->part[i].geom.topleft.y.percent *
-	     ewin->bits[topleft].h) >> 10) +
+	y = ((ewin->border->part[i].geom.topleft.y.percent *
+	      ewin->bits[topleft].h) >> 10) +
 	   ewin->border->part[i].geom.topleft.y.absolute +
 	   ewin->bits[topleft].y;
      }
    ox = oy = 0;
    if (bottomright == -1)
      {
-	ox =
-	   ((ewin->border->
-	     part[i].geom.bottomright.x.percent * ewin->w) >> 10) +
+	ox = ((ewin->border->
+	       part[i].geom.bottomright.x.percent * ewin->w) >> 10) +
 	   ewin->border->part[i].geom.bottomright.x.absolute;
-	oy =
-	   ((ewin->border->
-	     part[i].geom.bottomright.y.percent * ewin->h) >> 10) +
+	oy = ((ewin->border->
+	       part[i].geom.bottomright.y.percent * ewin->h) >> 10) +
 	   ewin->border->part[i].geom.bottomright.y.absolute;
      }
    else if (bottomright >= 0)
      {
-	ox =
-	   ((ewin->border->part[i].geom.bottomright.x.percent *
-	     ewin->bits[bottomright].w) >> 10) +
+	ox = ((ewin->border->part[i].geom.bottomright.x.percent *
+	       ewin->bits[bottomright].w) >> 10) +
 	   ewin->border->part[i].geom.bottomright.x.absolute +
 	   ewin->bits[bottomright].x;
-	oy =
-	   ((ewin->border->part[i].geom.bottomright.y.percent *
-	     ewin->bits[bottomright].h) >> 10) +
+	oy = ((ewin->border->part[i].geom.bottomright.y.percent *
+	       ewin->bits[bottomright].h) >> 10) +
 	   ewin->border->part[i].geom.bottomright.y.absolute +
 	   ewin->bits[bottomright].y;
      }
@@ -1465,6 +1237,7 @@ CalcEwinSizes(EWin * ewin)
 	 CalcEwinWinpart(ewin, i);
    for (i = 0; i < ewin->border->num_winparts; i++)
       RealiseEwinWinpart(ewin, i);
+
    reshape = 0;
    for (i = 0; i < ewin->border->num_winparts; i++)
      {
@@ -1486,6 +1259,7 @@ CalcEwinSizes(EWin * ewin)
 	   PropagateShapes(ewin->win);
 	ewin->shapedone = 1;
      }
+
    EDBUG_RETURN_;
 }
 
@@ -1499,18 +1273,19 @@ Adopt(Window win)
    GrabX();
    ewin = CreateEwin();
    ewin->client.win = win;
-   ICCCM_AdoptStart(ewin, win);
+   ICCCM_AdoptStart(ewin);
    ICCCM_GetTitle(ewin, 0);
    ICCCM_GetHints(ewin, 0);
    ICCCM_GetInfo(ewin, 0);
    ICCCM_GetColormap(ewin);
    ICCCM_GetShapeInfo(ewin);
-   GNOME_GetHints(ewin, 0);
+/* HintsGetWindowHints(ewin); */
    ICCCM_GetGeoms(ewin, 0);
    SessionGetInfo(ewin, 0);
    MatchEwinToSM(ewin);
    MatchEwinToSnapInfo(ewin);
    ICCCM_GetEInfo(ewin);
+   HintsGetWindowHints(ewin);
    if (!ewin->border)
       SetEwinBorder(ewin);
 
@@ -1520,7 +1295,8 @@ Adopt(Window win)
 
    SetEwinToBorder(ewin, b);
    ICCCM_MatchSize(ewin);
-   ICCCM_Adopt(ewin, win);
+   ICCCM_Adopt(ewin);
+   HintsSetWindowState(ewin);
    UngrabX();
    if (ewin->shaded)
      {
@@ -1539,9 +1315,30 @@ AdoptInternal(Window win, Border * border, int type, void *ptr)
    EDBUG(4, "AdoptInternal");
    GrabX();
    ewin = CreateEwin();
-   ewin->internal = 1;
    ewin->client.win = win;
-   ICCCM_AdoptStart(ewin, win);
+   ewin->internal = 1;
+   ewin->type = type;
+   switch (type)
+     {
+#if 0
+     case EWIN_TYPE_DIALOG:
+#endif
+     case EWIN_TYPE_MENU:
+	ewin->layer = 99;
+	ewin->skiptask = 1;
+	ewin->skip_ext_pager = 1;
+	break;
+     case EWIN_TYPE_ICONBOX:
+	ewin->skiptask = 1;
+	ewin->skip_ext_pager = 1;
+	break;
+     case EWIN_TYPE_PAGER:
+	ewin->skiptask = 1;
+	ewin->skip_ext_pager = 1;
+	break;
+     }
+
+   ICCCM_AdoptStart(ewin);
    ICCCM_GetTitle(ewin, 0);
    ICCCM_GetInfo(ewin, 0);
    ICCCM_GetShapeInfo(ewin);
@@ -1554,10 +1351,9 @@ AdoptInternal(Window win, Border * border, int type, void *ptr)
     * else  */
    if (!border)
      {
-	b =
-	   MatchEwinByFunction(ewin,
-			       (void
-				*(*)(EWin *, WindowMatch *))MatchEwinBorder);
+	b = MatchEwinByFunction(ewin,
+				(void
+				 *(*)(EWin *, WindowMatch *))MatchEwinBorder);
 	if (b)
 	  {
 	     ewin->border = b;
@@ -1581,7 +1377,8 @@ AdoptInternal(Window win, Border * border, int type, void *ptr)
    SetEwinToBorder(ewin, b);
 
    ICCCM_MatchSize(ewin);
-   ICCCM_Adopt(ewin, win);
+   ICCCM_Adopt(ewin);
+   HintsSetWindowState(ewin);
    UngrabX();
    if (ewin->shaded)
      {
@@ -1590,7 +1387,6 @@ AdoptInternal(Window win, Border * border, int type, void *ptr)
      }
    EDBUG_RETURN(ewin);
    ptr = NULL;
-   type = 0;
 }
 
 EWin               *
@@ -1612,6 +1408,8 @@ CreateEwin()
    ewin->ly = -1;
    ewin->lw = -1;
    ewin->lh = -1;
+   ewin->type = 0;
+   ewin->internal = 0;
    ewin->toggle = 0;
    ewin->client.win = 0;
    ewin->client.x = -1;
@@ -1643,6 +1441,7 @@ CreateEwin()
    ewin->client.aspect_max = 65535.0;
    ewin->client.w_inc = 1;
    ewin->client.h_inc = 1;
+   ewin->client.grav = 0;
    ewin->client.base_w = 0;
    ewin->client.base_h = 0;
    ewin->client.width.min = 0;
@@ -1665,7 +1464,7 @@ CreateEwin()
    ewin->border_new = 0;
    ewin->bits = NULL;
    ewin->sticky = 0;
-   ewin->desktop = -1;
+   ewin->desktop = desks.current;
    ewin->groups = NULL;
    ewin->num_groups = 0;
    ewin->visible = 0;
@@ -1681,17 +1480,21 @@ CreateEwin()
    ewin->docked = 0;
    ewin->shaded = 0;
    ewin->fixedpos = 0;
+#if 0				/* ENABLE_GNOME - Not actually used */
    ewin->expanded_x = 0;
    ewin->expanded_y = 0;
    ewin->expanded_width = -1;
    ewin->expanded_height = -1;
+#endif
    ewin->ignorearrange = 0;
    ewin->skiptask = 0;
+   ewin->skip_ext_pager = 0;
    ewin->skipwinlist = 0;
    ewin->skipfocus = 0;
    ewin->neverfocus = 0;
+   ewin->neverraise = 0;
    ewin->focusclick = 0;
-   ewin->internal = 0;
+   ewin->ewmh_flags = 0;
    ewin->menu = NULL;
    ewin->dialog = NULL;
    ewin->shownmenu = 0;
@@ -1708,7 +1511,9 @@ CreateEwin()
    ewin->snap = NULL;
    ewin->icon_pmap = 0;
    ewin->icon_mask = 0;
+#if ENABLE_KDE
    ewin->kde_hint = 0;
+#endif
 
    att.event_mask =
       StructureNotifyMask | ResizeRedirectMask | ButtonPressMask |
@@ -1741,17 +1546,22 @@ FreeEwin(EWin * ewin)
       HideSlideout(mode.slideout, 0);
    if (!ewin)
       EDBUG_RETURN_;
+
    if (GetZoomEWin() == ewin)
       Zoom(NULL);
+
    if (ewin->snap)
      {
 	ListChangeItemID(LIST_TYPE_SNAPSHOT, ewin->snap, 0);
 	ewin->snap->used = 0;
 	ewin->snap = NULL;
      }
+
    DesktopRemoveEwin(ewin);
+
    PagerEwinOutsideAreaUpdate(ewin);
    PagerHideAllHi();
+
    mode.windowdestroy = 1;
    /* hide any menus this ewin has brought up if they are still up when we */
    /* destroy this ewin */
@@ -1775,20 +1585,30 @@ FreeEwin(EWin * ewin)
 	     HideMenuMasker();
 	  }
      }
+
    if (ewin == mode.focuswin)
-      FocusToNone();
+     {
+#if 0				/* Clean up if OK -- Remove FocusToNone */
+	FocusToNone();
+#else
+	FocusToEWin(NULL);
+#endif
+     }
 
    if (ewin->pager)
       PagerKill(ewin->pager);
    if (ewin->ibox)
       FreeIconbox(ewin->ibox);
-   if (mode.context_ewin == ewin)
-      mode.context_ewin = NULL;
 
-   GNOME_DelHints(ewin);
+   /* May be an overkill but cannot hurt... */
+   DELETE_EWIN_REFERENCE(ewin, mode.ewin);
+   DELETE_EWIN_REFERENCE(ewin, mode.focuswin);
+   DELETE_EWIN_REFERENCE(ewin, mode.realfocuswin);
+   DELETE_EWIN_REFERENCE(ewin, mode.mouse_over_win);
+   DELETE_EWIN_REFERENCE(ewin, mode.context_ewin);
+   DELETE_EWIN_REFERENCE(ewin, mode.moveresize_pending_ewin);
 
-   if (mode.kde_support)
-      KDE_RemoveWindow(ewin);
+   HintsDelWindowHints(ewin);
 
    if (ewin->client.transient)
      {
@@ -1829,9 +1649,9 @@ FreeEwin(EWin * ewin)
    if (ewin->mini_mask)
       EFreePixmap(disp, ewin->mini_mask);
    if (ewin->icon_pmap)
-      Imlib_free_pixmap(id, ewin->icon_pmap);
+      Imlib_free_pixmap(pImlibData, ewin->icon_pmap);
    if (ewin->icon_mask)
-      Imlib_free_pixmap(id, ewin->icon_mask);
+      Imlib_free_pixmap(pImlibData, ewin->icon_mask);
    if (ewin->groups)
      {
 	num_groups = ewin->num_groups;
@@ -1853,18 +1673,15 @@ SetEwinBorder(EWin * ewin)
    ICCCM_GetShapeInfo(ewin);
 
    if ((!ewin->client.mwm_decor_title) && (!ewin->client.mwm_decor_border))
-      b =
-	 (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
-			     LIST_TYPE_BORDER);
+      b = (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
+			      LIST_TYPE_BORDER);
    else
-      b =
-	 MatchEwinByFunction(ewin,
-			     (void
-			      *(*)(EWin *, WindowMatch *))(MatchEwinBorder));
+      b = MatchEwinByFunction(ewin,
+			      (void
+			       *(*)(EWin *, WindowMatch *))(MatchEwinBorder));
    if (mode.dockapp_support && ewin->docked)
-      b =
-	 (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
-			     LIST_TYPE_BORDER);
+      b = (Border *) FindItem("BORDERLESS", 0, LIST_FINDBY_NAME,
+			      LIST_TYPE_BORDER);
    if (!b)
       b = (Border *) FindItem("DEFAULT", 0, LIST_FINDBY_NAME, LIST_TYPE_BORDER);
    ewin->border = b;
@@ -2063,7 +1880,7 @@ DetermineEwinArea(EWin * ewin)
        (desks.desk[ewin->desktop].current_area_y * root.h)) / root.h;
    if ((pax != ewin->area_x) || (pay != ewin->area_y))
      {
-	GNOME_SetEwinArea(ewin);
+	HintsSetWindowArea(ewin);
      }
    EDBUG_RETURN_;
 }
@@ -2199,6 +2016,7 @@ MoveResizeEwin(EWin * ewin, int x, int y, int w, int h)
    EDBUG_RETURN_;
 }
 
+#if 0				/* Unused */
 void
 FloatEwin(EWin * ewin)
 {
@@ -2229,6 +2047,7 @@ FloatEwin(EWin * ewin)
    call_depth--;
    EDBUG_RETURN_;
 }
+#endif
 
 void
 FloatEwinAt(EWin * ewin, int x, int y)
@@ -2271,138 +2090,16 @@ FloatEwinAt(EWin * ewin, int x, int y)
 void
 RestackEwin(EWin * ewin)
 {
-   Window             *wl;
-   EWin              **lst;
-   int                 num, bnum, wnum;
-   int                 i, j, tot;
-
-   Button            **blst;
-   EWin               *ewin2;
-
    EDBUG(3, "RestackEwin");
-   blst = (Button **) ListItemType(&bnum, LIST_TYPE_BUTTON);
-   num = desks.desk[ewin->desktop].num;
-   tot = 0;
-   wl = NULL;
+
    if (ewin->floating)
      {
-	if (blst)
-	   Efree(blst);
 	XRaiseWindow(disp, ewin->win);
 	EDBUG_RETURN_;
      }
-   j = -1;
-   for (i = ENLIGHTENMENT_CONF_NUM_DESKTOPS - 1; i >= 0; i--)
-     {
-	if (deskorder[i] == ewin->desktop)
-	  {
-	     j = i - 1;
-	     i = -1;
-	  }
-     }
-   if (ewin->desktop != 0)
-      j = -1;
-   if (blst)
-     {
-	for (i = 0; i < bnum; i++)
-	  {
-	     if (blst[i]->sticky)
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = blst[i]->win;
-	       }
-	  }
-     }
-   lst = (EWin **) ListItemType(&wnum, LIST_TYPE_EWIN);
-   if (lst)
-     {
-	for (i = 0; i < wnum; i++)
-	  {
-	     if ( /* (lst[i]->sticky) || */ (lst[i]->floating))
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = lst[i]->win;
-	       }
-	  }
-	Efree(lst);
-     }
-   if (j >= 0)
-     {
-	for (i = 0; i <= j; i++)
-	  {
-	     if (deskorder[i] == 0)
-		i = ENLIGHTENMENT_CONF_NUM_DESKTOPS;
-	     else
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = desks.desk[deskorder[i]].win;
-	       }
-	  }
-     }
-   if (blst)
-     {
-	for (i = 0; i < bnum; i++)
-	  {
-	     if ((blst[i]->desktop == ewin->desktop) && (blst[i]->ontop == 1)
-		 && (!blst[i]->sticky))
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = blst[i]->win;
-	       }
-	  }
-     }
-   tot += num;
-   ewin2 = NULL;
-   if (mode.menu_cover_win)
-     {
-	ewin2 = FindEwinByMenu(mode.cur_menu[0]);
-	if (ewin2)
-	   tot++;
-     }
-   wl = Erealloc(wl, tot * sizeof(Window));
-   if ((mode.menu_cover_win) && (ewin2))
-     {
-	j = tot - num - 1;
-	for (i = 0; i < num; i++)
-	  {
-	     wl[j++] = desks.desk[ewin->desktop].list[i]->win;
-	     if (desks.desk[ewin->desktop].list[i]->win == ewin2->win)
-		wl[j++] = mode.menu_cover_win;
-	  }
-     }
-   else
-     {
-	for (i = 0; i < num; i++)
-	  {
-	     wl[tot - num + i] = desks.desk[ewin->desktop].list[i]->win;
-	  }
-     }
-   if (blst)
-     {
-	for (i = 0; i < bnum; i++)
-	  {
-	     if ((blst[i]->desktop == ewin->desktop) && (blst[i]->ontop == -1)
-		 && (!blst[i]->sticky))
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = blst[i]->win;
-	       }
-	  }
-     }
-   tot++;
-   wl = Erealloc(wl, tot * sizeof(Window));
-   wl[tot - 1] = desks.desk[ewin->desktop].win;
-   XRestackWindows(disp, wl, tot);
-   if (wl)
-      Efree(wl);
-   if (blst)
-      Efree(blst);
-   ShowEdgeWindows();
+
+   StackDesktop(ewin->desktop);
+
    if (mode.mode == MODE_NONE)
      {
 	PagerEwinOutsideAreaUpdate(ewin);
@@ -2420,6 +2117,10 @@ RaiseEwin(EWin * ewin)
    call_depth++;
    if (call_depth > 256)
       EDBUG_RETURN_;
+
+   if (ewin->neverraise)
+      EDBUG_RETURN_;
+
    if (ewin->win)
      {
 	if (ewin->floating)
@@ -2492,15 +2193,6 @@ ShowEwin(EWin * ewin)
      }
    if (ewin->win)
      {
-	if (init_win1)
-	  {
-	     XRaiseWindow(disp, init_win1);
-	     XRaiseWindow(disp, init_win2);
-	  }
-	if (init_win_ext)
-	   XRaiseWindow(disp, init_win_ext);
-	ShowEdgeWindows();
-	RaiseProgressbars();
 	EMapWindow(disp, ewin->win);
      }
    ewin->visible = 1;
@@ -2838,7 +2530,7 @@ InstantShadeEwin(EWin * ewin)
      }
    PropagateShapes(ewin->win);
    queue_up = pq;
-   GNOME_SetHint(ewin);
+   HintsSetWindowState(ewin);
    if (mode.mode == MODE_NONE)
      {
 	PagerEwinOutsideAreaUpdate(ewin);
@@ -2866,8 +2558,7 @@ InstantUnShadeEwin(EWin * ewin)
      case 0:
 	att.win_gravity = EastGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
-	b =
-	   ewin->client.w + ewin->border->border.left +
+	b = ewin->client.w + ewin->border->border.left +
 	   ewin->border->border.right;
 	ewin->shaded = 0;
 	ewin->w = b;
@@ -2877,12 +2568,10 @@ InstantUnShadeEwin(EWin * ewin)
      case 1:
 	att.win_gravity = WestGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
-	b =
-	   ewin->client.w + ewin->border->border.left +
+	b = ewin->client.w + ewin->border->border.left +
 	   ewin->border->border.right;
-	d =
-	   ewin->x + ewin->w - (ewin->border->border.right + ewin->client.w +
-				ewin->border->border.left);
+	d = ewin->x + ewin->w - (ewin->border->border.right + ewin->client.w +
+				 ewin->border->border.left);
 	ewin->shaded = 0;
 	ewin->w = b;
 	ewin->x = d;
@@ -2893,8 +2582,7 @@ InstantUnShadeEwin(EWin * ewin)
      case 2:
 	att.win_gravity = SouthGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
-	b =
-	   ewin->client.h + ewin->border->border.top +
+	b = ewin->client.h + ewin->border->border.top +
 	   ewin->border->border.bottom;
 	ewin->shaded = 0;
 	ewin->h = b;
@@ -2904,12 +2592,10 @@ InstantUnShadeEwin(EWin * ewin)
      case 3:
 	att.win_gravity = SouthGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
-	b =
-	   ewin->client.h + ewin->border->border.top +
+	b = ewin->client.h + ewin->border->border.top +
 	   ewin->border->border.bottom;
-	d =
-	   ewin->y + ewin->h - (ewin->border->border.bottom + ewin->client.h +
-				ewin->border->border.top);
+	d = ewin->y + ewin->h - (ewin->border->border.bottom +
+				 ewin->client.h + ewin->border->border.top);
 	ewin->shaded = 0;
 	ewin->h = b;
 	ewin->y = d;
@@ -2922,7 +2608,7 @@ InstantUnShadeEwin(EWin * ewin)
      }
    PropagateShapes(ewin->win);
    queue_up = pq;
-   GNOME_SetHint(ewin);
+   HintsSetWindowState(ewin);
    if (mode.mode == MODE_NONE)
      {
 	PagerEwinOutsideAreaUpdate(ewin);
@@ -2974,8 +2660,7 @@ ShadeEwin(EWin * ewin)
 		ewin->w = i;
 		if (ewin->w < 1)
 		   ewin->w = 1;
-		ww =
-		   ewin->w - ewin->border->border.left -
+		ww = ewin->w - ewin->border->border.left -
 		   ewin->border->border.right;
 		if (ww < 1)
 		   ww = 1;
@@ -2987,9 +2672,9 @@ ShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
-				      -(ewin->client.w - ww), 0,
-				      ewin->client.win, ShapeBounding,
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding, -(ewin->client.w - ww),
+				      0, ewin->client.win, ShapeBounding,
 				      ShapeSet);
 		PropagateShapes(ewin->win);
 		gettimeofday(&timev2, NULL);
@@ -3030,8 +2715,7 @@ ShadeEwin(EWin * ewin)
 		ewin->reqx = j;
 		if (ewin->w < 1)
 		   ewin->w = 1;
-		ww =
-		   ewin->w - ewin->border->border.left -
+		ww = ewin->w - ewin->border->border.left -
 		   ewin->border->border.right;
 		if (ww < 1)
 		   ww = 1;
@@ -3043,9 +2727,9 @@ ShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
-				      0, 0, ewin->client.win, ShapeBounding,
-				      ShapeSet);
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding, 0, 0, ewin->client.win,
+				      ShapeBounding, ShapeSet);
 		PropagateShapes(ewin->win);
 		gettimeofday(&timev2, NULL);
 		dsec = timev2.tv_sec - timev1.tv_sec;
@@ -3083,8 +2767,7 @@ ShadeEwin(EWin * ewin)
 		ewin->h = i;
 		if (ewin->h < 1)
 		   ewin->h = 1;
-		hh =
-		   ewin->h - ewin->border->border.top -
+		hh = ewin->h - ewin->border->border.top -
 		   ewin->border->border.bottom;
 		if (hh < 1)
 		   hh = 1;
@@ -3096,8 +2779,9 @@ ShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
-				      0, -(ewin->client.h - hh),
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding, 0,
+				      -(ewin->client.h - hh),
 				      ewin->client.win, ShapeBounding,
 				      ShapeSet);
 		PropagateShapes(ewin->win);
@@ -3140,8 +2824,7 @@ ShadeEwin(EWin * ewin)
 		ewin->reqy = j;
 		if (ewin->h < 1)
 		   ewin->h = 1;
-		hh =
-		   ewin->h - ewin->border->border.top -
+		hh = ewin->h - ewin->border->border.top -
 		   ewin->border->border.bottom;
 		if (hh < 1)
 		   hh = 1;
@@ -3153,9 +2836,9 @@ ShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
-				      0, 0, ewin->client.win, ShapeBounding,
-				      ShapeSet);
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding, 0, 0, ewin->client.win,
+				      ShapeBounding, ShapeSet);
 		PropagateShapes(ewin->win);
 		gettimeofday(&timev2, NULL);
 		dsec = timev2.tv_sec - timev1.tv_sec;
@@ -3188,7 +2871,7 @@ ShadeEwin(EWin * ewin)
 			 ewin->client.win, ShapeBounding, ShapeSet);
    PropagateShapes(ewin->win);
    queue_up = pq;
-   GNOME_SetHint(ewin);
+   HintsSetWindowState(ewin);
    if (mode.mode == MODE_NONE)
      {
 	PagerEwinOutsideAreaUpdate(ewin);
@@ -3225,12 +2908,12 @@ UnShadeEwin(EWin * ewin)
 	att.win_gravity = EastGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
 	a = ewin->border->border.left;
-	b =
-	   ewin->client.w + ewin->border->border.left +
+	b = ewin->client.w + ewin->border->border.left +
 	   ewin->border->border.right;
 	ewin->shaded = 0;
-	EMoveResizeWindow(disp, ewin->win_container, ewin->border->border.left,
-			  ewin->border->border.top, 1, ewin->client.h);
+	EMoveResizeWindow(disp, ewin->win_container,
+			  ewin->border->border.left, ewin->border->border.top,
+			  1, ewin->client.h);
 	EMoveResizeWindow(disp, ewin->client.win, -ewin->client.w, 0,
 			  ewin->client.w, ewin->client.h);
 	EMapWindow(disp, ewin->client.win);
@@ -3250,7 +2933,8 @@ UnShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding,
 				      -(ewin->client.w -
 					(ewin->w - ewin->border->border.left -
 					 ewin->border->border.right)), 0,
@@ -3271,7 +2955,6 @@ UnShadeEwin(EWin * ewin)
 		   spd = min;
 	     }
 	ewin->w = b;
-	queue_up = 1;
 	MoveResizeEwin(ewin, ewin->x, ewin->y, ewin->client.w, ewin->client.h);
 	XSync(disp, False);
 	break;
@@ -3279,16 +2962,15 @@ UnShadeEwin(EWin * ewin)
 	att.win_gravity = WestGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
 	a = ewin->border->border.right;
-	b =
-	   ewin->client.w + ewin->border->border.left +
+	b = ewin->client.w + ewin->border->border.left +
 	   ewin->border->border.right;
 	c = ewin->x;
-	d =
-	   ewin->x + ewin->w - (ewin->border->border.right + ewin->client.w +
-				ewin->border->border.left);
+	d = ewin->x + ewin->w - (ewin->border->border.right + ewin->client.w +
+				 ewin->border->border.left);
 	ewin->shaded = 0;
-	EMoveResizeWindow(disp, ewin->win_container, ewin->border->border.left,
-			  ewin->border->border.top, 1, ewin->client.h);
+	EMoveResizeWindow(disp, ewin->win_container,
+			  ewin->border->border.left, ewin->border->border.top,
+			  1, ewin->client.h);
 	EMoveResizeWindow(disp, ewin->client.win, 0, 0, ewin->client.w,
 			  ewin->client.h);
 	EMapWindow(disp, ewin->client.win);
@@ -3311,9 +2993,9 @@ UnShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
-				      0, 0, ewin->client.win, ShapeBounding,
-				      ShapeSet);
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding, 0, 0, ewin->client.win,
+				      ShapeBounding, ShapeSet);
 		PropagateShapes(ewin->win);
 		gettimeofday(&timev2, NULL);
 		dsec = timev2.tv_sec - timev1.tv_sec;
@@ -3331,7 +3013,6 @@ UnShadeEwin(EWin * ewin)
 	ewin->w = b;
 	ewin->x = d;
 	ewin->reqx = d;
-	queue_up = 1;
 	MoveResizeEwin(ewin, ewin->x, ewin->y, ewin->client.w, ewin->client.h);
 	XSync(disp, False);
 	break;
@@ -3339,12 +3020,12 @@ UnShadeEwin(EWin * ewin)
 	att.win_gravity = SouthGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
 	a = ewin->border->border.top;
-	b =
-	   ewin->client.h + ewin->border->border.top +
+	b = ewin->client.h + ewin->border->border.top +
 	   ewin->border->border.bottom;
 	ewin->shaded = 0;
-	EMoveResizeWindow(disp, ewin->win_container, ewin->border->border.left,
-			  ewin->border->border.top, ewin->client.w, 1);
+	EMoveResizeWindow(disp, ewin->win_container,
+			  ewin->border->border.left, ewin->border->border.top,
+			  ewin->client.w, 1);
 	EMoveResizeWindow(disp, ewin->client.win, 0, -ewin->client.h,
 			  ewin->client.w, ewin->client.h);
 	EMapWindow(disp, ewin->client.win);
@@ -3364,8 +3045,8 @@ UnShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
-				      0,
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding, 0,
 				      -(ewin->client.h -
 					(ewin->h - ewin->border->border.top -
 					 ewin->border->border.bottom)),
@@ -3386,7 +3067,6 @@ UnShadeEwin(EWin * ewin)
 		   spd = min;
 	     }
 	ewin->h = b;
-	queue_up = 1;
 	MoveResizeEwin(ewin, ewin->x, ewin->y, ewin->client.w, ewin->client.h);
 	XSync(disp, False);
 	break;
@@ -3394,16 +3074,15 @@ UnShadeEwin(EWin * ewin)
 	att.win_gravity = SouthGravity;
 	XChangeWindowAttributes(disp, ewin->client.win, CWWinGravity, &att);
 	a = ewin->border->border.bottom;
-	b =
-	   ewin->client.h + ewin->border->border.top +
+	b = ewin->client.h + ewin->border->border.top +
 	   ewin->border->border.bottom;
 	c = ewin->y;
-	d =
-	   ewin->y + ewin->h - (ewin->border->border.bottom + ewin->client.h +
-				ewin->border->border.top);
+	d = ewin->y + ewin->h - (ewin->border->border.bottom +
+				 ewin->client.h + ewin->border->border.top);
 	ewin->shaded = 0;
-	EMoveResizeWindow(disp, ewin->win_container, ewin->border->border.left,
-			  ewin->border->border.top, ewin->client.w, 1);
+	EMoveResizeWindow(disp, ewin->win_container,
+			  ewin->border->border.left, ewin->border->border.top,
+			  ewin->client.w, 1);
 	EMoveResizeWindow(disp, ewin->client.win, 0, 0, ewin->client.w,
 			  ewin->client.h);
 	EMapWindow(disp, ewin->client.win);
@@ -3426,9 +3105,9 @@ UnShadeEwin(EWin * ewin)
 				  ewin->h);
 		CalcEwinSizes(ewin);
 		if (ewin->client.shaped)
-		   EShapeCombineShape(disp, ewin->win_container, ShapeBounding,
-				      0, 0, ewin->client.win, ShapeBounding,
-				      ShapeSet);
+		   EShapeCombineShape(disp, ewin->win_container,
+				      ShapeBounding, 0, 0, ewin->client.win,
+				      ShapeBounding, ShapeSet);
 		PropagateShapes(ewin->win);
 		gettimeofday(&timev2, NULL);
 		dsec = timev2.tv_sec - timev1.tv_sec;
@@ -3446,7 +3125,6 @@ UnShadeEwin(EWin * ewin)
 	ewin->h = b;
 	ewin->y = d;
 	ewin->reqy = d;
-	queue_up = 1;
 	MoveResizeEwin(ewin, ewin->x, ewin->y, ewin->client.w, ewin->client.h);
 	XSync(disp, False);
 	break;
@@ -3459,7 +3137,7 @@ UnShadeEwin(EWin * ewin)
 			 ewin->client.win, ShapeBounding, ShapeSet);
    PropagateShapes(ewin->win);
    queue_up = pq;
-   GNOME_SetHint(ewin);
+   HintsSetWindowState(ewin);
    if (mode.mode == MODE_NONE)
      {
 	PagerEwinOutsideAreaUpdate(ewin);
