@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -22,28 +22,32 @@
  */
 #include "E.h"
 
+static Atom         XA_ENLIGHTENMENT_COMMS = 0;
+static Atom         XA_ENL_MSG = 0;
+
 void
-CommsSetup()
+CommsSetup(void)
 {
    char                s[1024];
-   static Atom         a = 0;
 
    EDBUG(5, "CommsSetup");
+
    comms_win = XCreateSimpleWindow(disp, root.win, -100, -100, 5, 5, 0, 0, 0);
    XSelectInput(disp, comms_win, StructureNotifyMask | SubstructureNotifyMask);
    Esnprintf(s, sizeof(s), "WINID %8x", (int)comms_win);
-   a = XInternAtom(disp, "ENLIGHTENMENT_COMMS", False);
-   XChangeProperty(disp, comms_win, a, XA_STRING, 8, PropModeReplace,
-		   (unsigned char *)s, strlen(s));
-   XChangeProperty(disp, root.win, a, XA_STRING, 8, PropModeReplace,
-		   (unsigned char *)s, strlen(s));
-   if (!a)
-      a = XInternAtom(disp, "ENL_MSG", False);
+   XA_ENLIGHTENMENT_COMMS = XInternAtom(disp, "ENLIGHTENMENT_COMMS", False);
+   XChangeProperty(disp, comms_win, XA_ENLIGHTENMENT_COMMS, XA_STRING, 8,
+		   PropModeReplace, (unsigned char *)s, strlen(s));
+   XChangeProperty(disp, root.win, XA_ENLIGHTENMENT_COMMS, XA_STRING, 8,
+		   PropModeReplace, (unsigned char *)s, strlen(s));
+
+   XA_ENL_MSG = XInternAtom(disp, "ENL_MSG", False);
+
    EDBUG_RETURN_;
 }
 
 void
-CommsFindCommsWindow()
+CommsFindCommsWindow(void)
 {
    unsigned char      *s;
    Atom                a, ar;
@@ -54,7 +58,7 @@ CommsFindCommsWindow()
    unsigned int        duint;
 
    EDBUG(6, "CommsFindCommsWindow");
-   a = XInternAtom(disp, "ENLIGHTENMENT_COMMS", True);
+   a = XA_ENLIGHTENMENT_COMMS;
    if (a != None)
      {
 	s = NULL;
@@ -74,7 +78,8 @@ CommsFindCommsWindow()
 	  {
 	     if (!EGetGeometry
 		 (disp, comms_win, &rt, &dint, &dint, &duint, &duint, &duint,
-		  &duint)) comms_win = 0;
+		  &duint))
+		comms_win = 0;
 	     s = NULL;
 	     if (comms_win)
 	       {
@@ -91,25 +96,24 @@ CommsFindCommsWindow()
    EDBUG_RETURN_;
 }
 
-void
-CommsSend(Client * c, char *s)
+static void
+CommsDoSend(Window win, char *s)
 {
    char                ss[21];
    int                 i, j, k, len;
    XEvent              ev;
-   static Atom         a = 0;
 
-   EDBUG(5, "CommsSend");
-   if ((!s) || (!c))
+   EDBUG(5, "CommsDoSend");
+
+   if ((!win) || (!s))
       EDBUG_RETURN_;
+
    len = strlen(s);
-   if (!a)
-      a = XInternAtom(disp, "ENL_MSG", True);
    ev.xclient.type = ClientMessage;
    ev.xclient.serial = 0;
    ev.xclient.send_event = True;
-   ev.xclient.window = c->win;
-   ev.xclient.message_type = a;
+   ev.xclient.window = win;
+   ev.xclient.message_type = XA_ENL_MSG;
    ev.xclient.format = 8;
    for (i = 0; i < len + 1; i += 12)
      {
@@ -123,11 +127,24 @@ CommsSend(Client * c, char *s)
 	ss[20] = 0;
 	for (k = 0; k < 20; k++)
 	   ev.xclient.data.b[k] = ss[k];
-	XSendEvent(disp, c->win, False, 0, (XEvent *) & ev);
+	XSendEvent(disp, win, False, 0, (XEvent *) & ev);
      }
    EDBUG_RETURN_;
 }
 
+void
+CommsSend(Client * c, char *s)
+{
+   EDBUG(5, "CommsSend");
+
+   if (!c)
+      EDBUG_RETURN_;
+
+   CommsDoSend(c->win, s);
+
+   EDBUG_RETURN_;
+}
+
 /*
  * When we are running in multi-head, connect to the master wm process
  * and send the message
@@ -135,44 +152,13 @@ CommsSend(Client * c, char *s)
 void
 CommsSendToMasterWM(char *s)
 {
-   Window              otherrootwin;
-   char                ss[21];
-   int                 i, j, k, len;
-   XEvent              ev;
-   Atom                a = 0;
-
    EDBUG(5, "CommsSendToMasterWM");
+
    if (root.scr == master_screen || master_pid == getpid())
       EDBUG_RETURN_;
 
-   if (!s)
-      EDBUG_RETURN_;
+   CommsDoSend(RootWindow(disp, master_screen), s);
 
-   otherrootwin = RootWindow(disp, master_screen);
-
-   len = strlen(s);
-   if (!a)
-      a = XInternAtom(disp, "ENL_MSG", True);
-   ev.xclient.type = ClientMessage;
-   ev.xclient.serial = 0;
-   ev.xclient.send_event = True;
-   ev.xclient.window = otherrootwin;
-   ev.xclient.message_type = a;
-   ev.xclient.format = 8;
-   for (i = 0; i < len + 1; i += 12)
-     {
-	Esnprintf(ss, sizeof(ss), "%8x", (int)comms_win);
-	for (j = 0; j < 12; j++)
-	  {
-	     ss[8 + j] = s[i + j];
-	     if (!s[i + j])
-		j = 12;
-	  }
-	ss[20] = 0;
-	for (k = 0; k < 20; k++)
-	   ev.xclient.data.b[k] = ss[k];
-	XSendEvent(disp, otherrootwin, False, 0, (XEvent *) & ev);
-     }
    EDBUG_RETURN_;
 }
 
@@ -183,79 +169,44 @@ CommsSendToMasterWM(char *s)
 void
 CommsBroadcastToSlaveWMs(char *s)
 {
-   Window              otherrootwin;
-   char                ss[21];
-   int                 i, j, k, len, screen;
-   XEvent              ev;
-   Atom                a = 0;
+   int                 screen;
 
    EDBUG(5, "CommsBroadcastToSlaveWMs");
+
    if (root.scr != master_screen || master_pid != getpid()
        || display_screens < 2 || single_screen_mode != 0)
       EDBUG_RETURN_;
 
-   if (!s)
-      EDBUG_RETURN_;
-
    for (screen = 0; screen < display_screens; screen++)
      {
 	if (screen != master_screen)
-	  {
-	     otherrootwin = RootWindow(disp, screen);
-
-	     len = strlen(s);
-	     if (!a)
-		a = XInternAtom(disp, "ENL_MSG", False);
-	     ev.xclient.type = ClientMessage;
-	     ev.xclient.serial = 0;
-	     ev.xclient.send_event = True;
-	     ev.xclient.window = otherrootwin;
-	     ev.xclient.message_type = a;
-	     ev.xclient.format = 8;
-	     for (i = 0; i < len + 1; i += 12)
-	       {
-		  Esnprintf(ss, sizeof(ss), "%8x", (int)comms_win);
-		  for (j = 0; j < 12; j++)
-		    {
-		       ss[8 + j] = s[i + j];
-		       if (!s[i + j])
-			  j = 12;
-		    }
-		  ss[20] = 0;
-		  for (k = 0; k < 20; k++)
-		     ev.xclient.data.b[k] = ss[k];
-		  XSendEvent(disp, otherrootwin, False, 0, (XEvent *) & ev);
-	       }
-	  }
+	   CommsDoSend(RootWindow(disp, screen), s);
      }
+
    EDBUG_RETURN_;
 }
 
-char               *
-CommsGet(Client ** c, XEvent * ev)
+static char        *
+CommsGet(Client ** c, XClientMessageEvent * ev)
 {
    char                s[13], s2[9], *msg, st[32];
    int                 i;
    Window              win = 0;
    Client             *cl;
-   Atom                a = 0;
 
    EDBUG(5, "CommsGet");
-   if (!a)
-      a = XInternAtom(disp, "ENL_MSG", True);
    if ((!ev) || (!c))
       EDBUG_RETURN(NULL);
-   if (ev->type != ClientMessage)
-      EDBUG_RETURN(NULL);
-   if (ev->xclient.message_type != a)
+   if (ev->message_type != XA_ENL_MSG)
       EDBUG_RETURN(NULL);
+
    s[12] = 0;
    s2[8] = 0;
    msg = NULL;
    for (i = 0; i < 8; i++)
-      s2[i] = ev->xclient.data.b[i];
+      s2[i] = ev->data.b[i];
    for (i = 0; i < 12; i++)
-      s[i] = ev->xclient.data.b[i + 8];
+      s[i] = ev->data.b[i + 8];
    sscanf(s2, "%x", (int *)&win);
    cl = (Client *) FindItem(NULL, win, LIST_FINDBY_ID, LIST_TYPE_CLIENT);
    if (!cl)
@@ -380,7 +331,7 @@ DeleteClient(Client * c)
 }
 
 void
-HandleComms(XEvent * ev)
+HandleComms(XClientMessageEvent * ev)
 {
    Client             *c;
    char               *s, *s1, *s2;
@@ -392,6 +343,7 @@ HandleComms(XEvent * ev)
    s = CommsGet(&c, ev);
    if (!s)
       EDBUG_RETURN_;
+
    if (HandleIPC(s, c))
      {
 	Efree(s);
@@ -531,9 +483,8 @@ HandleComms(XEvent * ev)
 	char                dodel = 1;
 
 	sscanf(s, "%*s %1000s", w);
-	bg =
-	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	if (bg)
 	  {
 	     /* check for desktops referencing this bg - if there are - don't */
@@ -545,9 +496,8 @@ HandleComms(XEvent * ev)
 	       }
 	     if (dodel)
 	       {
-		  bg =
-		     (Background *) RemoveItem(w, 0, LIST_FINDBY_NAME,
-					       LIST_TYPE_BACKGROUND);
+		  bg = (Background *) RemoveItem(w, 0, LIST_FINDBY_NAME,
+						 LIST_TYPE_BACKGROUND);
 		  if (bg->name)
 		     Efree(bg->name);
 		  if (bg->bg.file)
@@ -555,7 +505,7 @@ HandleComms(XEvent * ev)
 		  if (bg->top.file)
 		     Efree(bg->top.file);
 		  if (bg->pmap)
-		     Imlib_free_pixmap(id, bg->pmap);
+		     Imlib_free_pixmap(pImlibData, bg->pmap);
 		  Efree(bg);
 	       }
 	  }
@@ -567,9 +517,8 @@ HandleComms(XEvent * ev)
 	char                view;
 
 	sscanf(s, "%*s %1000s", w);
-	bg =
-	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	if (bg)
 	  {
 	     wd = 3;
@@ -653,9 +602,8 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], buf2[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	bg =
-	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	buf[0] = 0;
 	if (bg)
 	  {
@@ -677,9 +625,8 @@ HandleComms(XEvent * ev)
 	int                 i, mod;
 	char               *buf = NULL, buf2[FILEPATH_LEN_MAX];
 
-	ac =
-	   (ActionClass *) FindItem("KEYBINDINGS", 0, LIST_FINDBY_NAME,
-				    LIST_TYPE_ACLASS_GLOBAL);
+	ac = (ActionClass *) FindItem("KEYBINDINGS", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_ACLASS_GLOBAL);
 	if (ac)
 	  {
 	     for (i = 0; i < ac->num; i++)
@@ -706,8 +653,8 @@ HandleComms(XEvent * ev)
 			    else if (a->modifiers == (ShiftMask | Mod1Mask))
 			       mod = 6;
 			    else if (a->modifiers ==
-				     (ShiftMask | ControlMask | Mod1Mask)) mod =
-				  7;
+				     (ShiftMask | ControlMask | Mod1Mask))
+			       mod = 7;
 			    else if (a->modifiers == (Mod2Mask))
 			       mod = 8;
 			    else if (a->modifiers == (Mod3Mask))
@@ -727,15 +674,15 @@ HandleComms(XEvent * ev)
 			    else if (a->modifiers == (Mod4Mask | ControlMask))
 			       mod = 16;
 			    else if (a->modifiers ==
-				     (Mod4Mask | ControlMask | ShiftMask)) mod =
-				  17;
+				     (Mod4Mask | ControlMask | ShiftMask))
+			       mod = 17;
 			    else if (a->modifiers == (Mod5Mask | ShiftMask))
 			       mod = 18;
 			    else if (a->modifiers == (Mod5Mask | ControlMask))
 			       mod = 19;
 			    else if (a->modifiers ==
-				     (Mod5Mask | ControlMask | ShiftMask)) mod =
-				  20;
+				     (Mod5Mask | ControlMask | ShiftMask))
+			       mod = 20;
 			    if (a->action->params)
 			       Esnprintf(buf2, sizeof(buf2), "%s %i %i %s\n",
 					 key, mod, a->action->Type,
@@ -774,9 +721,8 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], *sp, *ss;
 
 	mode.keybinds_changed = 1;
-	ac =
-	   (ActionClass *) RemoveItem("KEYBINDINGS", 0, LIST_FINDBY_NAME,
-				      LIST_TYPE_ACLASS_GLOBAL);
+	ac = (ActionClass *) RemoveItem("KEYBINDINGS", 0, LIST_FINDBY_NAME,
+					LIST_TYPE_ACLASS_GLOBAL);
 	if (ac)
 	   RemoveActionClass(ac);
 	ac = CreateAclass("KEYBINDINGS");
@@ -866,12 +812,10 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], buf2[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s %1000s", buf, buf2);
-	bg =
-	   (Background *) FindItem(buf, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
-	cm =
-	   (ColorModifierClass *) FindItem(buf2, 0, LIST_FINDBY_NAME,
-					   LIST_TYPE_COLORMODIFIER);
+	bg = (Background *) FindItem(buf, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
+	cm = (ColorModifierClass *) FindItem(buf2, 0, LIST_FINDBY_NAME,
+					     LIST_TYPE_COLORMODIFIER);
 	if ((bg) && (bg->cmclass != cm))
 	  {
 	     if (!strcmp(buf, "(null)"))
@@ -885,7 +829,7 @@ HandleComms(XEvent * ev)
 		  bg->cmclass = cm;
 	       }
 	     if (bg->pmap)
-		Imlib_free_pixmap(id, bg->pmap);
+		Imlib_free_pixmap(pImlibData, bg->pmap);
 	     bg->pmap = 0;
 	     for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
 	       {
@@ -900,9 +844,8 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	bg =
-	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	Esnprintf(buf, sizeof(buf), "(null)");
 	if ((bg) && (bg->cmclass))
 	   Esnprintf(buf, sizeof(buf), "%s", bg->cmclass->name);
@@ -914,9 +857,8 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	cm =
-	   (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
-					   LIST_TYPE_COLORMODIFIER);
+	cm = (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
+					     LIST_TYPE_COLORMODIFIER);
 	Esnprintf(buf, sizeof(buf), "(null)");
 	if (cm)
 	   FreeCMClass(cm);
@@ -928,9 +870,8 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX], buf2[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	cm =
-	   (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
-					   LIST_TYPE_COLORMODIFIER);
+	cm = (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
+					     LIST_TYPE_COLORMODIFIER);
 	Esnprintf(buf, sizeof(buf), "(null)");
 	if (cm)
 	  {
@@ -974,9 +915,8 @@ HandleComms(XEvent * ev)
 	unsigned char      *bpx = NULL, *bpy = NULL;
 
 	sscanf(s, "%*s %1000s", w);
-	cm =
-	   (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
-					   LIST_TYPE_COLORMODIFIER);
+	cm = (ColorModifierClass *) FindItem(w, 0, LIST_FINDBY_NAME,
+					     LIST_TYPE_COLORMODIFIER);
 	name = duplicate(w);
 	i = 3;
 	word(s, i++, w);
@@ -1025,9 +965,8 @@ HandleComms(XEvent * ev)
 	   ModifyCMClass(name, rnum, rpx, rpy, gnum, gpx, gpy, bnum, bpx, bpy);
 	else
 	  {
-	     cm =
-		CreateCMClass(name, rnum, rpx, rpy, gnum, gpx, gpy, bnum, bpx,
-			      bpy);
+	     cm = CreateCMClass(name, rnum, rpx, rpy, gnum, gpx, gpy, bnum, bpx,
+				bpy);
 	     AddItem(cm, cm->name, 0, LIST_TYPE_COLORMODIFIER);
 	  }
 	Efree(name);
@@ -1050,9 +989,8 @@ HandleComms(XEvent * ev)
 	char                buf[FILEPATH_LEN_MAX];
 
 	sscanf(s, "%*s %1000s", w);
-	bg =
-	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	Esnprintf(buf, sizeof(buf), "(null)");
 	if (bg)
 	  {
@@ -1107,16 +1045,14 @@ HandleComms(XEvent * ev)
 	int                 txjust, tyjust, txperc, typerc;
 
 	sscanf(s, "%1000s %1000s", tmp, w);
-	bg =
-	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	icl.r = 99;
-	i =
-	   sscanf(s,
-		  "%1000s %1000s %i %i %i %1000s %i %i %i %i %i %i %1000s %i %i %i %i %i",
-		  tmp, tmp, &(icl.r), &(icl.g), &(icl.b), tmp, &tile,
-		  (int *)&keep_aspect, &xjust, &yjust, &xperc, &yperc, tmp,
-		  &tkeep_aspect, &txjust, &tyjust, &txperc, &typerc);
+	i = sscanf(s,
+		   "%1000s %1000s %i %i %i %1000s %i %i %i %i %i %i %1000s %i %i %i %i %i",
+		   tmp, tmp, &(icl.r), &(icl.g), &(icl.b), tmp, &tile,
+		   (int *)&keep_aspect, &xjust, &yjust, &xperc, &yperc, tmp,
+		   &tkeep_aspect, &txjust, &tyjust, &txperc, &typerc);
 	if (bg)
 	  {
 	     name = duplicate(w);
@@ -1192,7 +1128,7 @@ HandleComms(XEvent * ev)
 	     if (updated)
 	       {
 		  if (bg->pmap)
-		     Imlib_free_pixmap(id, bg->pmap);
+		     Imlib_free_pixmap(pImlibData, bg->pmap);
 		  bg->pmap = 0;
 		  for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
 		    {
@@ -1220,10 +1156,9 @@ HandleComms(XEvent * ev)
 	     word(s, 13, w);
 	     if (strcmp("(null)", w))
 		topf = duplicate(w);
-	     bg =
-		CreateDesktopBG(name, &icl, bgf, tile, keep_aspect, xjust,
-				yjust, xperc, yperc, topf, tkeep_aspect, txjust,
-				tyjust, txperc, typerc);
+	     bg = CreateDesktopBG(name, &icl, bgf, tile, keep_aspect, xjust,
+				  yjust, xperc, yperc, topf, tkeep_aspect,
+				  txjust, tyjust, txperc, typerc);
 	     if (name)
 		Efree(name);
 	     if (bgf)
@@ -1239,17 +1174,15 @@ HandleComms(XEvent * ev)
 	Background         *bg;
 
 	sscanf(s, "%*s %x %1000s", (unsigned int *)&win, w);
-	bg =
-	   (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	bg = (Background *) FindItem(w, 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	if (bg)
-	   SetBackgroundTo(id, win, bg, 0);
+	   SetBackgroundTo(pImlibData, win, bg, 0);
 	CommsSend(c, "done");
      }
    else if (!strcmp(w, "set_controls"))
      {
-	int                 i, num, wd;
-	Button            **blst;
+	int                 wd;
 	int                 a, b;
 	int                 ax, ay;
 	char                dragbar_change = 0;
@@ -1284,7 +1217,7 @@ HandleComms(XEvent * ev)
 	       {
 		  word(s, wd, w);
 		  mode.movemode = atoi(w);
-		  if ((ird) && (mode.movemode == 5))
+		  if ((prImlibData) && (mode.movemode == 5))
 		     mode.movemode = 3;
 	       }
 	     else if (!strcmp(w, "RESIZEMODE:"))
@@ -1451,12 +1384,7 @@ HandleComms(XEvent * ev)
 	       }
 	     else if (!strcmp(w, "SHOWICONS:"))
 	       {
-		  word(s, wd, w);
-		  mode.showicons = atoi(w);
-		  if (mode.showicons)
-		     ShowIcons();
-		  else
-		     HideIcons();
+		  /* Obsolete */
 	       }
 	     else if (!strcmp(w, "ALL_NEW_WINDOWS_GET_FOCUS:"))
 	       {
@@ -1538,16 +1466,15 @@ HandleComms(XEvent * ev)
 	  {
 	     Button             *b;
 
-	     while (
-		    (b =
+	     while ((b =
 		     RemoveItem("_DESKTOP_DRAG_CONTROL", 0, LIST_FINDBY_NAME,
-				LIST_TYPE_BUTTON))) DestroyButton(b);
+				LIST_TYPE_BUTTON)))
+		DestroyButton(b);
 	     InitDesktopControls();
 	     ShowDesktopControls();
 	  }
 	FixFocus();
-	GNOME_SetDeskCount();
-	GNOME_SetDeskNames();
+
 	GetAreaSize(&ax, &ay);
 	GetCurrentArea(&a, &b);
 	if (a >= ax)
@@ -1557,21 +1484,6 @@ HandleComms(XEvent * ev)
 	  }
 	if (b >= ay)
 	   SetCurrentArea(a, ay - 1);
-	blst = (Button **) ListItemType(&num, LIST_TYPE_BUTTON);
-	if (blst)
-	  {
-	     for (i = 0; i < num; i++)
-	       {
-		  if (!strcmp(blst[i]->name, "ICON"))
-		    {
-		       if (mode.showicons)
-			  ShowButton(blst[i]);
-		       else
-			  HideButton(blst[i]);
-		    }
-	       }
-	     Efree(blst);
-	  }
      }
    else if (!strcmp(w, "get_controls"))
      {
@@ -1593,7 +1505,7 @@ HandleComms(XEvent * ev)
 		  "DRAGBARORDERING: %i\n" "DRAGBARLENGTH: %i\n"
 		  "DESKSLIDEIN: %i\n" "DESKSLIDESPEED: %i\n" "HIQUALITYBG: %i\n"
 		  "TRANSIENTSFOLLOWLEADER: %i\n" "SWITCHFORTRANSIENTMAP: %i\n"
-		  "SHOWICONS: %i\n" "AREA_SIZE: %i %i\n"
+		  "AREA_SIZE: %i %i\n"
 		  "ALL_NEW_WINDOWS_GET_FOCUS: %i\n"
 		  "NEW_TRANSIENTS_GET_FOCUS: %i\n"
 		  "NEW_TRANSIENTS_GET_FOCUS_IF_GROUP_FOCUSED: %i\n"
@@ -1615,7 +1527,7 @@ HandleComms(XEvent * ev)
 		  desks.dragbar_ordering, desks.dragbar_length, desks.slidein,
 		  desks.slidespeed, desks.hiqualitybg,
 		  mode.transientsfollowleader, mode.switchfortransientmap,
-		  mode.showicons, a, b, mode.all_new_windows_get_focus,
+		  a, b, mode.all_new_windows_get_focus,
 		  mode.new_transients_get_focus,
 		  mode.new_transients_get_focus_if_group_focused,
 		  mode.manual_placement, mode.manual_placement_mouse_pointer,
@@ -1913,7 +1825,6 @@ HandleComms(XEvent * ev)
    else if (!strcmp(w, "list_clients"))
      {
 	char                buf[FILEPATH_LEN_MAX], *ret = NULL, none[] =
-
 	   "-NONE-";
 	EWin              **lst;
 	int                 i, num;
@@ -2162,7 +2073,7 @@ DisplayClientInfo(Client * c, int onoff)
 }
 
 void
-HideClientInfo()
+HideClientInfo(void)
 {
    EDBUG(6, "HideClientInfo");
    EDBUG_RETURN_;
