@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -37,11 +37,10 @@ GetUniqueBGString(Background * bg)
 #endif
    int                 n1, n2, n3, n4, n5, f1, f2, f3, f4, f5, f6;
 
-   n1 =
-      (bg->bg.solid.r << 24) | (bg->bg.solid.g << 16) | (bg->bg.solid.
-							 b << 8) | (bg->bg.
-								    tile << 7) |
-      (bg->bg.keep_aspect << 6) | (bg->top.keep_aspect << 5);
+   n1 = (bg->bg.solid.r << 24) | (bg->bg.solid.g << 16) | (bg->bg.solid.
+							   b << 8) | (bg->bg.
+								      tile << 7)
+      | (bg->bg.keep_aspect << 6) | (bg->top.keep_aspect << 5);
    n2 = (bg->bg.xjust << 16) | (bg->bg.yjust);
    n3 = (bg->bg.xperc << 16) | (bg->bg.yperc);
    n4 = (bg->top.xjust << 16) | (bg->top.yjust);
@@ -183,26 +182,21 @@ ChangeNumberOfDesktops(int quantity)
    if (desks.current >= mode.numdesktops)
       GotoDesktop(mode.numdesktops - 1);
 
-   GNOME_SetDeskCount();
-   GNOME_SetDeskNames();
-
-   if (mode.kde_support)
-      KDE_SetNumDesktops();
-
+   HintsSetDesktopConfig();
 }
 
 void
 ShowDesktopControls()
 {
-   Button            **lst;
+   Button            **blst;
    int                 num, i;
 
-   lst = (Button **) ListItemTypeID(&num, LIST_TYPE_BUTTON, 1);
-   if ((lst) && (num > 0))
+   blst = (Button **) ListItemTypeID(&num, LIST_TYPE_BUTTON, 1);
+   if ((blst) && (num > 0))
      {
 	for (i = 0; i < num; i++)
-	   SimpleShowButton(lst[i]);
-	Efree(lst);
+	   ShowButton(blst[i]);
+	Efree(blst);
 	StackDesktops();
      }
 }
@@ -210,15 +204,15 @@ ShowDesktopControls()
 void
 ShowDesktopTabs()
 {
-   Button            **lst;
+   Button            **blst;
    int                 num, i;
 
-   lst = (Button **) ListItemTypeID(&num, LIST_TYPE_BUTTON, 2);
-   if ((lst) && (num > 0))
+   blst = (Button **) ListItemTypeID(&num, LIST_TYPE_BUTTON, 2);
+   if ((blst) && (num > 0))
      {
 	for (i = 0; i < num; i++)
-	   SimpleShowButton(lst[i]);
-	Efree(lst);
+	   ShowButton(blst[i]);
+	Efree(blst);
 	StackDesktops();
      }
 }
@@ -337,13 +331,13 @@ KeepBGimages(Background * bg, char onoff)
      {
 	bg->keepim = 0;
 	if (bg->bg.im)
-	   Imlib_destroy_image(id, bg->bg.im);
+	   Imlib_destroy_image(pImlibData, bg->bg.im);
 	bg->bg.im = NULL;
 	if (bg->top.im)
-	   Imlib_destroy_image(id, bg->top.im);
+	   Imlib_destroy_image(pImlibData, bg->top.im);
 	bg->top.im = NULL;
 	if (bg->pmap)
-	   Imlib_free_pixmap(id, bg->pmap);
+	   Imlib_free_pixmap(pImlibData, bg->pmap);
 	bg->pmap = 0;
      }
 }
@@ -358,14 +352,14 @@ RemoveImagesFromBG(Background * bg)
    bg->bg.file = NULL;
    bg->bg.real_file = NULL;
    if (bg->bg.im)
-      Imlib_destroy_image(id, bg->bg.im);
+      Imlib_destroy_image(pImlibData, bg->bg.im);
    bg->bg.im = NULL;
    if (bg->top.im)
-      Imlib_destroy_image(id, bg->top.im);
+      Imlib_destroy_image(pImlibData, bg->top.im);
    bg->top.im = NULL;
    bg->keepim = 0;
    if (bg->pmap)
-      Imlib_free_pixmap(id, bg->pmap);
+      Imlib_free_pixmap(pImlibData, bg->pmap);
    bg->pmap = 0;
 }
 
@@ -394,15 +388,15 @@ FreeDesktopBG(Background * bg)
    if (bg->bg.real_file)
       Efree(bg->bg.real_file);
    if (bg->bg.im)
-      Imlib_destroy_image(id, bg->bg.im);
+      Imlib_destroy_image(pImlibData, bg->bg.im);
    if (bg->top.file)
       Efree(bg->top.file);
    if (bg->top.real_file)
       Efree(bg->top.real_file);
    if (bg->top.im)
-      Imlib_destroy_image(id, bg->top.im);
+      Imlib_destroy_image(pImlibData, bg->top.im);
    if (bg->pmap)
-      Imlib_free_pixmap(id, bg->pmap);
+      Imlib_free_pixmap(pImlibData, bg->pmap);
    if (bg->name)
       Efree(bg->name);
    Efree(bg);
@@ -421,13 +415,13 @@ CreateDesktopBG(char *name, ImlibColor * solid, char *bg, char tile,
 
    EDBUG(6, "CreateDesktopBG");
 
-   if (ird)
+   if (prImlibData)
      {
-	imd = ird;
+	imd = prImlibData;
      }
    else
      {
-	imd = id;
+	imd = pImlibData;
      }
 
    d = Emalloc(sizeof(Background));
@@ -507,10 +501,10 @@ RefreshDesktop(int num)
    dsk = desks.desk[num].bg;
    if (!dsk)
       EDBUG_RETURN_;
-   if ((ird) && (num == 0))
-      imd = ird;
+   if ((prImlibData) && (num == 0))
+      imd = prImlibData;
    else
-      imd = id;
+      imd = pImlibData;
 
    SetBackgroundTo(imd, desks.desk[num].win, dsk, 1);
    EDBUG_RETURN_;
@@ -534,8 +528,9 @@ SetBackgroundTo(ImlibData * imd, Window win, Background * dsk, char setbg)
       EDBUG_RETURN_;
    GetWinWH(win, &rw, &rh);
    depth = GetWinDepth(win);
-   if ((depth != imd->x.depth) && (ird) && (depth == ird->x.depth))
-      imd = ird;
+   if ((depth != imd->x.depth) && (prImlibData)
+       && (depth == prImlibData->x.depth))
+      imd = prImlibData;
    r = dsk->bg.solid.r;
    g = dsk->bg.solid.g;
    b = dsk->bg.solid.b;
@@ -546,7 +541,7 @@ SetBackgroundTo(ImlibData * imd, Window win, Background * dsk, char setbg)
    h = 0;
    hasbg = 0;
    hasfg = 0;
-   rt = Imlib_get_render_type(id);
+   rt = Imlib_get_render_type(pImlibData);
 
    if (desks.hiqualitybg)
       Imlib_set_render_type(imd, RT_DITHER_TRUECOL);
@@ -563,10 +558,9 @@ SetBackgroundTo(ImlibData * imd, Window win, Background * dsk, char setbg)
 	  }
 	else
 	  {
-	     cm =
-		(ColorModifierClass *) FindItem("BACKGROUND", 0,
-						LIST_FINDBY_NAME,
-						LIST_TYPE_COLORMODIFIER);
+	     cm = (ColorModifierClass *) FindItem("BACKGROUND", 0,
+						  LIST_FINDBY_NAME,
+						  LIST_TYPE_COLORMODIFIER);
 	  }
 
 	if (dsk->bg.file)
@@ -592,15 +586,21 @@ SetBackgroundTo(ImlibData * imd, Window win, Background * dsk, char setbg)
 	     cm->ref_count++;
 	     if (dsk->top.im)
 	       {
-		  Imlib_set_image_red_curve(id, dsk->top.im, cm->red.map);
-		  Imlib_set_image_green_curve(id, dsk->top.im, cm->green.map);
-		  Imlib_set_image_blue_curve(id, dsk->top.im, cm->blue.map);
+		  Imlib_set_image_red_curve(pImlibData, dsk->top.im,
+					    cm->red.map);
+		  Imlib_set_image_green_curve(pImlibData, dsk->top.im,
+					      cm->green.map);
+		  Imlib_set_image_blue_curve(pImlibData, dsk->top.im,
+					     cm->blue.map);
 	       }
 	     if (dsk->bg.im)
 	       {
-		  Imlib_set_image_red_curve(id, dsk->bg.im, cm->red.map);
-		  Imlib_set_image_green_curve(id, dsk->bg.im, cm->green.map);
-		  Imlib_set_image_blue_curve(id, dsk->bg.im, cm->blue.map);
+		  Imlib_set_image_red_curve(pImlibData, dsk->bg.im,
+					    cm->red.map);
+		  Imlib_set_image_green_curve(pImlibData, dsk->bg.im,
+					      cm->green.map);
+		  Imlib_set_image_blue_curve(pImlibData, dsk->bg.im,
+					     cm->blue.map);
 	       }
 	  }
      }
@@ -720,18 +720,16 @@ SetBackgroundTo(ImlibData * imd, Window win, Background * dsk, char setbg)
 		  if (((ww << 10) / hh) !=
 		      ((dsk->top.im->rgb_width << 10) /
 		       dsk->top.im->rgb_height))
-		     hh =
-			((ww * dsk->top.im->rgb_height) /
-			 dsk->top.im->rgb_width);
+		     hh = ((ww * dsk->top.im->rgb_height) /
+			   dsk->top.im->rgb_width);
 	       }
 	     else
 	       {
 		  if (((hh << 10) / ww) !=
 		      ((dsk->top.im->rgb_height << 10) /
 		       dsk->top.im->rgb_width))
-		     ww =
-			((hh * dsk->top.im->rgb_width) /
-			 dsk->top.im->rgb_height);
+		     ww = ((hh * dsk->top.im->rgb_width) /
+			   dsk->top.im->rgb_height);
 	       }
 	  }
 	Imlib_render(imd, dsk->top.im, ww, hh);
@@ -895,18 +893,16 @@ SetBackgroundTo(ImlibData * imd, Window win, Background * dsk, char setbg)
 		  if (((ww << 10) / hh) !=
 		      ((dsk->top.im->rgb_width << 10) /
 		       dsk->top.im->rgb_height))
-		     hh =
-			((ww * dsk->top.im->rgb_height) /
-			 dsk->top.im->rgb_width);
+		     hh = ((ww * dsk->top.im->rgb_height) /
+			   dsk->top.im->rgb_width);
 	       }
 	     else
 	       {
 		  if (((hh << 10) / ww) !=
 		      ((dsk->top.im->rgb_height << 10) /
 		       dsk->top.im->rgb_width))
-		     ww =
-			((hh * dsk->top.im->rgb_width) /
-			 dsk->top.im->rgb_height);
+		     ww = ((hh * dsk->top.im->rgb_width) /
+			   dsk->top.im->rgb_height);
 	       }
 	  }
 	Imlib_render(imd, dsk->top.im, ww, hh);
@@ -1126,9 +1122,8 @@ InitDesktopControls()
 
 	if (desks.dragdir < 2)
 	  {
-	     ic =
-		FindItem("DESKTOP_DRAGBUTTON_VERT", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("DESKTOP_DRAGBUTTON_VERT", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     ic2 =
 		FindItem("DESKTOP_RAISEBUTTON_VERT", 0, LIST_FINDBY_NAME,
 			 LIST_TYPE_ICLASS);
@@ -1141,9 +1136,8 @@ InitDesktopControls()
 	  }
 	else
 	  {
-	     ic =
-		FindItem("DESKTOP_DRAGBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("DESKTOP_DRAGBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     ic2 =
 		FindItem("DESKTOP_RAISEBUTTON_HORIZ", 0, LIST_FINDBY_NAME,
 			 LIST_TYPE_ICLASS);
@@ -1246,58 +1240,51 @@ InitDesktopControls()
 
 	if (desks.dragbar_width > 0)
 	  {
-	     b =
-		CreateButton("_DESKTOP_DRAG_CONTROL", ic2, ac2, NULL, NULL, -1,
-			     FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[0], 0,
-			     y[0], 0, 0, w[0], 0, h[0], 0, i, 0);
+	     b = CreateButton("_DESKTOP_DRAG_CONTROL", ic2, ac2, NULL, NULL, -1,
+			      FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[0], 0,
+			      y[0], 0, 0, w[0], 0, h[0], 0, i, 0);
 	     AddItem(b, b->name, 1, LIST_TYPE_BUTTON);
-	     b =
-		CreateButton("_DESKTOP_DRAG_CONTROL", ic3, ac3, NULL, NULL, -1,
-			     FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[1], 0,
-			     y[1], 0, 0, w[1], 0, h[1], 0, i, 0);
+	     b = CreateButton("_DESKTOP_DRAG_CONTROL", ic3, ac3, NULL, NULL, -1,
+			      FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[1], 0,
+			      y[1], 0, 0, w[1], 0, h[1], 0, i, 0);
 	     AddItem(b, b->name, 1, LIST_TYPE_BUTTON);
-	     b =
-		CreateButton("_DESKTOP_DRAG_CONTROL", ic, ac, NULL, NULL, -1,
-			     FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[2], 0,
-			     y[2], 0, 0, w[2], 0, h[2], 0, i, 0);
+	     b = CreateButton("_DESKTOP_DRAG_CONTROL", ic, ac, NULL, NULL, -1,
+			      FLAG_FIXED, 1, 99999, 1, 99999, 0, 0, x[2], 0,
+			      y[2], 0, 0, w[2], 0, h[2], 0, i, 0);
 	     AddItem(b, b->name, 1, LIST_TYPE_BUTTON);
 	  }
 	if (i > 0)
 	  {
 	     if (desks.dragdir == 0)
 	       {
-		  b =
-		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				  NULL, NULL, 1, FLAG_FIXED_VERT, 1, 99999, 1,
-				  99999, 0, 0, desks.desk[i].x, 0,
-				  desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
+		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				   NULL, NULL, 1, FLAG_FIXED_VERT, 1, 99999, 1,
+				   99999, 0, 0, desks.desk[i].x, 0,
+				   desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
 	       }
 	     else if (desks.dragdir == 1)
 	       {
-		  b =
-		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				  NULL, NULL, 1, FLAG_FIXED_VERT, 1, 99999, 1,
-				  99999, 0, 0,
-				  desks.desk[i].x + root.w -
-				  desks.dragbar_width, 0, desks.desk[i].y, 0, 0,
-				  0, 0, 0, 1, 0, 1);
+		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				   NULL, NULL, 1, FLAG_FIXED_VERT, 1, 99999, 1,
+				   99999, 0, 0,
+				   desks.desk[i].x + root.w -
+				   desks.dragbar_width, 0, desks.desk[i].y, 0,
+				   0, 0, 0, 0, 1, 0, 1);
 	       }
 	     else if (desks.dragdir == 2)
 	       {
-		  b =
-		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				  NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
-				  99999, 0, 0, desks.desk[i].x, 0,
-				  desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
+		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				   NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
+				   99999, 0, 0, desks.desk[i].x, 0,
+				   desks.desk[i].y, 0, 0, 0, 0, 0, 1, 0, 1);
 	       }
 	     else
 	       {
-		  b =
-		     CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
-				  NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
-				  99999, 0, 0, desks.desk[i].x, 0,
-				  desks.desk[i].y + root.h -
-				  desks.dragbar_width, 0, 0, 0, 0, 0, 1, 0, 1);
+		  b = CreateButton("_DESKTOP_DESKRAY_DRAG_CONTROL", ic4, ac,
+				   NULL, NULL, 1, FLAG_FIXED_HORIZ, 1, 99999, 1,
+				   99999, 0, 0, desks.desk[i].x, 0,
+				   desks.desk[i].y + root.h -
+				   desks.dragbar_width, 0, 0, 0, 0, 0, 1, 0, 1);
 	       }
 	     AddItem(b, b->name, 2, LIST_TYPE_BUTTON);
 	     desks.desk[i].tag = b;
@@ -1360,10 +1347,8 @@ ConformEwinToDesktop(EWin * ewin)
 			ewin->y);
 	ICCCM_Configure(ewin);
 	StackDesktops();
-	GNOME_SetEwinDesk(ewin);
-	EDBUG_RETURN_;
      }
-   if (ewin->floating)
+   else if (ewin->floating)
      {
 	DesktopRemoveEwin(ewin);
 	xo = desks.desk[ewin->desktop].x;
@@ -1377,10 +1362,8 @@ ConformEwinToDesktop(EWin * ewin)
 	XRaiseWindow(disp, ewin->win);
 	ShowEdgeWindows();
 	ICCCM_Configure(ewin);
-	GNOME_SetEwinDesk(ewin);
-	EDBUG_RETURN_;
      }
-   if (ewin->parent != desks.desk[ewin->desktop].win)
+   else if (ewin->parent != desks.desk[ewin->desktop].win)
      {
 	ewin->parent = desks.desk[ewin->desktop].win;
 	DesktopAddEwinToTop(ewin);
@@ -1389,12 +1372,15 @@ ConformEwinToDesktop(EWin * ewin)
 	RaiseEwin(ewin);
 /*      ShowEwin(ewin); */
 	ICCCM_Configure(ewin);
-	GNOME_SetEwinDesk(ewin);
 	StackDesktops();
 	SetEwinToCurrentArea(ewin);
      }
+   else
+     {
+	MoveEwin(ewin, ewin->x, ewin->y);
+     }
+   HintsSetWindowDesktop(ewin);
    EDBUG_RETURN_;
-
 }
 
 int
@@ -1440,8 +1426,8 @@ MoveStickyWindowsToCurrentDesk(void)
 		  XLowerWindow(disp, ewin->win);
 		  EMoveWindow(disp, ewin->win, ewin->x, ewin->y);
 		  DesktopAddEwinToTop(ewin);
-		  GNOME_SetEwinArea(ewin);
-		  GNOME_SetEwinDesk(ewin);
+		  HintsSetWindowArea(ewin);
+		  HintsSetWindowDesktop(ewin);
 		  last_ewin = ewin;
 	       }
 	  }
@@ -1466,7 +1452,6 @@ GotoDesktop(int num)
       EDBUG_RETURN_;
    pdesk = desks.current;
 
-   WarpFocusFinish();
    if (mode.slideout)
       HideSlideout(mode.slideout, mode.context_win);
 
@@ -1513,17 +1498,9 @@ GotoDesktop(int num)
 			 mode.ewin->y + desks.desk[mode.ewin->desktop].y);
 	  }
      }
+
    FocusToEWin(NULL);
    BeginNewDeskFocus();
-   CloneDesktop(desks.current);
-   ICCCM_Cmap(NULL);
-   desks.current = num;
-   MoveStickyWindowsToCurrentDesk();
-
-   GNOME_SetCurrentDesk();
-
-   if (mode.kde_support)
-      KDE_SetRootArea();
 
    if (num > 0)
      {
@@ -1607,13 +1584,12 @@ GotoDesktop(int num)
 	       }
 	  }
      }
+
    NewDeskFocus();
-   FX_DeskChange();
-   RemoveClones();
    RedrawPagersForDesktop(num, 3);
    ForceUpdatePagersForDesktop(num);
-   UpdatePagerSel();
    HandleDrawQueue();
+
    EDBUG_RETURN_;
 }
 
@@ -1760,7 +1736,7 @@ RaiseDesktop(int num)
    ForceUpdatePagersForDesktop(num);
    UpdatePagerSel();
    HandleDrawQueue();
-   GNOME_SetCurrentDesk();
+   HintsSetCurrentDesktop();
    EMapWindow(disp, desks.desk[num].win);
    XSync(disp, False);
 
@@ -1791,7 +1767,7 @@ LowerDesktop(int num)
    ForceUpdatePagersForDesktop(deskorder[0]);
    UpdatePagerSel();
    HandleDrawQueue();
-   GNOME_SetCurrentDesk();
+   HintsSetCurrentDesktop();
    XSync(disp, False);
 
    EDBUG_RETURN_;
@@ -1849,121 +1825,122 @@ ShowDesktop(int num)
 
 void
 StackDesktops()
+{
+   EDBUG(2, "StackDesktops");
+
+   StackDesktop(0);
+
+   EDBUG_RETURN_;
+}
+
+#define _APPEND_TO_WIN_LIST(win) \
+  { \
+     wl = Erealloc(wl, ++tot * sizeof(Window)); \
+     wl[tot - 1] = win; \
+  }
+void
+StackDesktop(int num)
 {
    Window             *wl, *wl2;
-   int                 i, num, tot, bnum, n;
-   EWin              **lst;
+   int                 i, wnum, tot, bnum;
+   EWin              **lst, *ewin;
    Button            **blst;
 
-   EDBUG(2, "StackDesktops");
+   EDBUG(2, "StackDesktop");
    tot = 0;
    wl = NULL;
 
-   wl2 = ListProgressWindows(&n);
+   wl2 = ListProgressWindows(&wnum);
    if (wl2)
      {
-	tot += n;
-	wl = Erealloc(wl, tot * sizeof(Window));
-	for (i = 0; i < n; i++)
-	   wl[tot - n + i] = wl2[i];
+	for (i = 0; i < wnum; i++)
+	   _APPEND_TO_WIN_LIST(wl2[i]);
 	Efree(wl2);
      }
    if (init_win_ext)
      {
-	tot += 1;
-	wl = Erealloc(wl, tot * sizeof(Window));
-	wl[tot - 1] = init_win_ext;
+	_APPEND_TO_WIN_LIST(init_win_ext);
      }
    if (init_win1)
      {
-	tot += 2;
-	wl = Erealloc(wl, tot * sizeof(Window));
-	wl[tot - 2] = init_win1;
-	wl[tot - 1] = init_win2;
+	_APPEND_TO_WIN_LIST(init_win1);
+	_APPEND_TO_WIN_LIST(init_win2);
      }
-   lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
+
+   lst = (EWin **) ListItemType(&wnum, LIST_TYPE_EWIN);
    blst = (Button **) ListItemType(&bnum, LIST_TYPE_BUTTON);
 
    if (blst)
      {
 	for (i = 0; i < bnum; i++)
 	  {
-	     if (blst[i]->sticky)
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = blst[i]->win;
-	       }
+	     if (!blst[i]->sticky || blst[i]->internal)
+		continue;
+
+	     _APPEND_TO_WIN_LIST(blst[i]->win);
 	  }
      }
    if (lst)
      {
-	for (i = 0; i < num; i++)
+	for (i = 0; i < wnum; i++)
 	  {
-	     if ( /* (lst[i]->sticky) || */ (lst[i]->floating))
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = lst[i]->win;
-	       }
+	     if (!lst[i]->floating)
+		continue;
+
+	     _APPEND_TO_WIN_LIST(lst[i]->win);
 	  }
      }
    for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
      {
 	if (deskorder[i] == 0)
-	   i = ENLIGHTENMENT_CONF_NUM_DESKTOPS;
-	else
-	  {
-	     tot++;
-	     wl = Erealloc(wl, tot * sizeof(Window));
-	     wl[tot - 1] = desks.desk[deskorder[i]].win;
-	  }
+	   break;
+
+	_APPEND_TO_WIN_LIST(desks.desk[deskorder[i]].win);
      }
    if (blst)
      {
 	for (i = 0; i < bnum; i++)
 	  {
-	     if ((blst[i]->desktop == 0) && (blst[i]->ontop == 1)
-		 && (!blst[i]->sticky))
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = blst[i]->win;
-	       }
+	     if (blst[i]->desktop != num || blst[i]->ontop != 1 ||
+		 blst[i]->sticky || blst[i]->internal)
+		continue;
+
+	     _APPEND_TO_WIN_LIST(blst[i]->win);
 	  }
      }
-   for (i = 0; i < desks.desk[0].num; i++)
+   for (i = 0; i < desks.desk[num].num; i++)
      {
-	tot++;
-	wl = Erealloc(wl, tot * sizeof(Window));
-	wl[tot - 1] = desks.desk[0].list[i]->win;
+	ewin = desks.desk[num].list[i];
+
+	_APPEND_TO_WIN_LIST(ewin->win);
+	if (ewin->win == mode.menu_win_covered)
+	   _APPEND_TO_WIN_LIST(mode.menu_cover_win);
      }
    if (blst)
      {
 	for (i = 0; i < bnum; i++)
 	  {
-	     if ((blst[i]->desktop == 0) && (blst[i]->ontop == -1)
-		 && (!blst[i]->sticky))
-	       {
-		  tot++;
-		  wl = Erealloc(wl, tot * sizeof(Window));
-		  wl[tot - 1] = blst[i]->win;
-	       }
+	     if (blst[i]->desktop != num || blst[i]->ontop != -1 ||
+		 blst[i]->sticky || blst[i]->internal)
+		continue;
+
+	     _APPEND_TO_WIN_LIST(blst[i]->win);
 	  }
      }
-   tot++;
-   wl = Erealloc(wl, tot * sizeof(Window));
-   wl[tot - 1] = desks.desk[0].win;
+   _APPEND_TO_WIN_LIST(desks.desk[num].win);
+
+   XRestackWindows(disp, wl, tot);
+   ShowEdgeWindows();
+   RaiseProgressbars();
+   HintsSetClientList();
+
    if (wl)
-     {
-	XRestackWindows(disp, wl, tot);
-	Efree(wl);
-     }
+      Efree(wl);
    if (lst)
       Efree(lst);
    if (blst)
       Efree(blst);
-   ShowEdgeWindows();
+
    EDBUG_RETURN_;
 }
 
@@ -2012,8 +1989,6 @@ MoveEwinToDesktop(EWin * ewin, int num)
      }
    ForceUpdatePagersForDesktop(pdesk);
    ForceUpdatePagersForDesktop(ewin->desktop);
-   if (mode.kde_support)
-      KDE_UpdateClient(ewin);
    EDBUG_RETURN_;
 }
 
@@ -2138,15 +2113,18 @@ DesktopAddEwinToBottom(EWin * ewin)
 void
 MoveEwinToDesktopAt(EWin * ewin, int num, int x, int y)
 {
-   int                 dx, dy, pdesk;
+   int                 dx, dy;
 
    EDBUG(3, "MoveEwinToDesktopAt");
 /*   ewin->sticky = 0; */
-   pdesk = ewin->desktop;
    ewin->floating = 0;
-   DesktopRemoveEwin(ewin);
-   ewin->desktop = DESKTOPS_WRAP_NUM(num);
-   DesktopAddEwinToTop(ewin);
+   if (num != ewin->desktop)
+     {
+	DesktopRemoveEwin(ewin);
+	ForceUpdatePagersForDesktop(ewin->desktop);
+	ewin->desktop = DESKTOPS_WRAP_NUM(num);
+	DesktopAddEwinToTop(ewin);
+     }
    dx = x - ewin->x;
    dy = y - ewin->y;
    ewin->x = x;
@@ -2168,11 +2146,11 @@ MoveEwinToDesktopAt(EWin * ewin, int num, int x, int y)
 	     Efree(lst);
 	  }
      }
-   ForceUpdatePagersForDesktop(pdesk);
    ForceUpdatePagersForDesktop(ewin->desktop);
    EDBUG_RETURN_;
 }
 
+#if 0				/* Unused */
 void
 FloatEwinAboveDesktops(EWin * ewin)
 {
@@ -2199,6 +2177,7 @@ FloatEwinAboveDesktops(EWin * ewin)
      }
    EDBUG_RETURN_;
 }
+#endif
 
 void
 DesktopAccounting()
@@ -2224,15 +2203,15 @@ DesktopAccounting()
 	       {
 		  if ((now - lst[i]->last_viewed) > mode.desktop_bg_timeout)
 		    {
-		       imd = id;
+		       imd = pImlibData;
 		       for (j = 0; j < ENLIGHTENMENT_CONF_NUM_DESKTOPS; j++)
 			 {
 			    if (desks.desk[j].bg == lst[i])
 			      {
-				 if ((ird) && (j == 0))
-				    imd = ird;
+				 if ((prImlibData) && (j == 0))
+				    imd = prImlibData;
 				 else
-				    imd = id;
+				    imd = pImlibData;
 				 j = ENLIGHTENMENT_CONF_NUM_DESKTOPS;
 			      }
 			 }
