@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -285,7 +285,6 @@ DialogAlert(char *fmt, ...)
    char                text[10240];
    va_list             ap;
 
-   SC_Kill();
    va_start(ap, fmt);
    Evsnprintf(text, 10240, fmt, ap);
    va_end(ap);
@@ -511,7 +510,6 @@ ShowDialog(Dialog * d)
    XClassHint         *xch;
    Snapshot           *sn;
 
-   SC_Kill();
    if (d->title)
      {
 	xtp.encoding = XA_STRING;
@@ -550,12 +548,10 @@ ShowDialog(Dialog * d)
      }
    h += d->iclass->padding.top + d->iclass->padding.bottom + mh;
 
-   if (
-       (d->iclass->padding.left + d->iclass->padding.right +
+   if ((d->iclass->padding.left + d->iclass->padding.right +
 	(d->num_buttons *
 	 (mw + d->iclass->padding.left + d->iclass->padding.right))) > w)
-      w =
-	 d->iclass->padding.left + d->iclass->padding.right +
+      w = d->iclass->padding.left + d->iclass->padding.right +
 	 (d->num_buttons *
 	  (mw + d->iclass->padding.left + d->iclass->padding.right));
 
@@ -589,162 +585,28 @@ ShowDialog(Dialog * d)
 		  d->button[i]->h, 0, 0, STATE_NORMAL, 0);
    queue_up = pq;
 
-   ewin = AddInternalToFamily(d->win, 1, NULL, 0, d);
+   ewin = AddInternalToFamily(d->win, 1, NULL, EWIN_TYPE_DIALOG, d);
    XSelectInput(disp, d->win,
 		ExposureMask | PointerMotionMask | EnterWindowMask |
 		LeaveWindowMask | FocusChangeMask | KeyPressMask);
    if (ewin)
      {
 	DesktopRemoveEwin(ewin);
-	ewin->layer = 4;
 	DesktopAddEwinToTop(ewin);
 	sn = FindSnapshot(ewin);
 	/* get the size right damnit! */
-	if (sn)
+	if (sn && sn->use_wh)
+	   ResizeEwin(ewin, sn->w, sn->h);
+	if (sn && sn->use_xy)
 	  {
-	     if (sn->use_wh)
-		ResizeEwin(ewin, sn->w, sn->h);
-	     if (sn->use_xy)
-	       {
-		  MoveEwin(ewin, sn->x, sn->y);
-	       }
-	     else
-	       {
-		  if (FindADialog())
-		    {
-		       ArrangeEwin(ewin);
-		    }
-		  else
-		    {
-#ifdef HAS_XINERAMA
-		       if (xinerama_active)
-			 {
-			    Window              rt, ch;
-			    int                 d;
-			    unsigned int        ud;
-			    int                 pointer_x, pointer_y;
-			    int                 num;
-			    XineramaScreenInfo *screens;
-
-			    XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
-					  &pointer_y, &d, &d, &ud);
-			    screens = XineramaQueryScreens(disp, &num);
-			    for (i = 0; i < num; i++)
-			      {
-				 for (i = 0; i < num; i++)
-				   {
-				      if (pointer_x >= screens[i].x_org)
-					{
-					   if (pointer_x <=
-					       (screens[i].width +
-						screens[i].x_org))
-					     {
-						if (pointer_y >=
-						    screens[i].y_org)
-						  {
-						     if (pointer_y <=
-							 (screens[i].height +
-							  screens[i].y_org))
-						       {
-							  ewin->x =
-							     ((screens
-							       [i].width -
-							       ewin->w) / 2) +
-							     screens[i].x_org;
-							  ewin->y =
-							     ((screens
-							       [i].height -
-							       ewin->h) / 2) +
-							     screens[i].y_org;
-							  MoveEwin(ewin,
-								   ewin->x,
-								   ewin->y);
-						       }
-						  }
-					     }
-					}
-				   }
-			      }
-			    XFree(screens);
-
-			 }
-		       else
-			 {
-#endif
-			    MoveEwin(ewin, ((root.w - (ewin->w)) / 2),
-				     ((root.h - (ewin->h)) / 2));
-#ifdef HAS_XINERAMA
-			 }
-#endif
-		    }
-	       }
+	     MoveEwin(ewin, sn->x, sn->y);
 	  }
 	else
 	  {
 	     if (FindADialog())
-	       {
-		  ArrangeEwin(ewin);
-	       }
+		ArrangeEwin(ewin);
 	     else
-	       {
-#ifdef HAS_XINERAMA
-		  if (xinerama_active)
-		    {
-		       Window              rt, ch;
-		       int                 d;
-		       unsigned int        ud;
-		       int                 pointer_x, pointer_y;
-		       int                 num;
-		       XineramaScreenInfo *screens;
-
-		       XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
-				     &pointer_y, &d, &d, &ud);
-		       screens = XineramaQueryScreens(disp, &num);
-		       for (i = 0; i < num; i++)
-			 {
-			    for (i = 0; i < num; i++)
-			      {
-				 if (pointer_x >= screens[i].x_org)
-				   {
-				      if (pointer_x <=
-					  (screens[i].width + screens[i].x_org))
-					{
-					   if (pointer_y >= screens[i].y_org)
-					     {
-						if (pointer_y <=
-						    (screens[i].height +
-						     screens[i].y_org))
-						  {
-						     ewin->x =
-							((screens
-							  [i].width -
-							  ewin->w) / 2) +
-							screens[i].x_org;
-						     ewin->y =
-							((screens
-							  [i].height -
-							  ewin->h) / 2) +
-							screens[i].y_org;
-						     MoveEwin(ewin, ewin->x,
-							      ewin->y);
-						  }
-					     }
-					}
-				   }
-			      }
-			 }
-		       XFree(screens);
-
-		    }
-		  else
-		    {
-#endif
-		       MoveEwin(ewin, ((root.w - (ewin->w)) / 2),
-				((root.h - (ewin->h)) / 2));
-#ifdef HAS_XINERAMA
-		    }
-#endif
-	       }
+		ArrangeEwinCentered(ewin, 0);
 	  }
 	RestackEwin(ewin);
 	ShowEwin(ewin);
@@ -1095,8 +957,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	     di->win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	     EMapWindow(disp, di->win);
 	     XSelectInput(disp, di->win,
-			  EnterWindowMask | LeaveWindowMask | ButtonPressMask |
-			  ButtonReleaseMask);
+			  EnterWindowMask | LeaveWindowMask | ButtonPressMask
+			  | ButtonReleaseMask);
 	  }
 	di->item.slider.base_win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	EMapWindow(disp, di->item.slider.base_win);
@@ -1136,7 +998,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	       {
 		  di->item.slider.base_orig_w = im->rgb_width;
 		  di->item.slider.base_orig_h = im->rgb_height;
-		  Imlib_destroy_image(id, im);
+		  Imlib_destroy_image(pImlibData, im);
 	       }
 	  }
 	if (di->item.slider.ic_base)
@@ -1174,7 +1036,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	       {
 		  di->item.slider.knob_orig_w = im->rgb_width;
 		  di->item.slider.knob_orig_h = im->rgb_height;
-		  Imlib_destroy_image(id, im);
+		  Imlib_destroy_image(pImlibData, im);
 	       }
 	  }
 	if (!di->item.slider.ic_border)
@@ -1198,14 +1060,13 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	       {
 		  ImlibImage         *im;
 
-		  im =
-		     ELoadImage(di->item.slider.ic_border->norm.
-				normal->im_file);
+		  im = ELoadImage(di->item.slider.ic_border->norm.
+				  normal->im_file);
 		  if (im)
 		    {
 		       di->item.slider.border_orig_w = im->rgb_width;
 		       di->item.slider.border_orig_h = im->rgb_height;
-		       Imlib_destroy_image(id, im);
+		       Imlib_destroy_image(pImlibData, im);
 		       di->item.slider.border_win =
 			  ECreateWindow(d->win, -20, -20, 2, 2, 0);
 		       EMapWindow(disp, di->item.slider.border_win);
@@ -1215,8 +1076,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	  }
 	if (di->item.slider.horizontal)
 	  {
-	     iw =
-		di->item.slider.min_length +
+	     iw = di->item.slider.min_length +
 		di->item.slider.ic_base->padding.left +
 		di->item.slider.ic_base->padding.right;
 	     ih = di->item.slider.base_orig_h;
@@ -1224,8 +1084,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	else
 	  {
 	     iw = di->item.slider.base_orig_w;
-	     ih =
-		di->item.slider.min_length +
+	     ih = di->item.slider.min_length +
 		di->item.slider.ic_base->padding.top +
 		di->item.slider.ic_base->padding.bottom;
 	  }
@@ -1233,8 +1092,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	di->h = ih;
 	break;
      case DITEM_BUTTON:
-	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.button.text, &iw, &ih,
-		 17);
+	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.button.text, &iw,
+		 &ih, 17);
 	iw += di->iclass->padding.left + di->iclass->padding.right;
 	ih += di->iclass->padding.top + di->iclass->padding.bottom;
 	di->win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
@@ -1271,7 +1130,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	       {
 		  di->item.check_button.check_orig_w = im->rgb_width;
 		  di->item.check_button.check_orig_h = im->rgb_height;
-		  Imlib_destroy_image(id, im);
+		  Imlib_destroy_image(pImlibData, im);
 	       }
 	  }
 	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.check_button.text,
@@ -1307,8 +1166,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 		ih = im->rgb_height;
 		di->win = ECreateWindow(d->win, 0, 0, iw, ih, 0);
 		EMapWindow(disp, di->win);
-		Imlib_apply_image(id, im, di->win);
-		Imlib_destroy_image(id, im);
+		Imlib_apply_image(pImlibData, im, di->win);
+		Imlib_destroy_image(pImlibData, im);
 	     }
 	}
 	di->w = iw;
@@ -1332,7 +1191,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	       {
 		  di->item.radio_button.radio_orig_w = im->rgb_width;
 		  di->item.radio_button.radio_orig_h = im->rgb_height;
-		  Imlib_destroy_image(id, im);
+		  Imlib_destroy_image(pImlibData, im);
 	       }
 	  }
 	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->item.radio_button.text,
@@ -1481,32 +1340,28 @@ DialogRealizeItem(Dialog * d, DItem * di)
 					       dii->w, dii->h);
 			  if (dii->type == DITEM_CHECKBUTTON)
 			     EMoveResizeWindow(disp,
-					       dii->item.check_button.check_win,
-					       dii->x,
+					       dii->item.check_button.
+					       check_win, dii->x,
 					       dii->y +
-					       ((dii->h
-						 -
-						 dii->item.
-						 check_button.check_orig_h) /
-						2),
-					       dii->item.
-					       check_button.check_orig_w,
-					       dii->item.
-					       check_button.check_orig_h);
+					       ((dii->h -
+						 dii->item.check_button.
+						 check_orig_h) / 2),
+					       dii->item.check_button.
+					       check_orig_w,
+					       dii->item.check_button.
+					       check_orig_h);
 			  if (dii->type == DITEM_RADIOBUTTON)
 			     EMoveResizeWindow(disp,
-					       dii->item.radio_button.radio_win,
-					       dii->x,
+					       dii->item.radio_button.
+					       radio_win, dii->x,
 					       dii->y +
-					       ((dii->h
-						 -
-						 dii->item.
-						 radio_button.radio_orig_h) /
-						2),
-					       dii->item.
-					       radio_button.radio_orig_w,
-					       dii->item.
-					       radio_button.radio_orig_h);
+					       ((dii->h -
+						 dii->item.radio_button.
+						 radio_orig_h) / 2),
+					       dii->item.radio_button.
+					       radio_orig_w,
+					       dii->item.radio_button.
+					       radio_orig_h);
 			  if (dii->type == DITEM_AREA)
 			    {
 			       dii->item.area.w =
@@ -1515,7 +1370,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			       dii->item.area.h =
 				  dii->h - (dii->iclass->padding.top +
 					    dii->iclass->padding.bottom);
-			       EMoveResizeWindow(disp, dii->item.area.area_win,
+			       EMoveResizeWindow(disp,
+						 dii->item.area.area_win,
 						 dii->iclass->padding.left,
 						 dii->iclass->padding.top,
 						 dii->item.area.w,
@@ -1546,7 +1402,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 						    dii->item.slider.base_h);
 			       if (dii->item.slider.border_win)
 				  EMoveResizeWindow(disp,
-						    dii->item.slider.border_win,
+						    dii->item.slider.
+						    border_win,
 						    dii->x +
 						    dii->item.slider.border_x,
 						    dii->y +
@@ -1556,10 +1413,13 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			       if (dii->win)
 				  EMoveResizeWindow(disp, dii->win,
 						    dii->x +
-						    dii->item.slider.numeric_x,
+						    dii->item.slider.
+						    numeric_x,
 						    dii->y +
-						    dii->item.slider.numeric_y,
-						    dii->item.slider.numeric_w,
+						    dii->item.slider.
+						    numeric_y,
+						    dii->item.slider.
+						    numeric_w,
 						    dii->item.slider.numeric_h);
 			    }
 		       }
@@ -1734,8 +1594,8 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 	     if (di->item.slider.border_win)
 		IclassApply(di->item.slider.ic_border,
 			    di->item.slider.border_win,
-			    di->item.slider.border_w, di->item.slider.border_h,
-			    0, 0, STATE_NORMAL, 0);
+			    di->item.slider.border_w,
+			    di->item.slider.border_h, 0, 0, STATE_NORMAL, 0);
 	     state = STATE_NORMAL;
 	     if ((di->hilited) && (di->clicked))
 		state = STATE_CLICKED;
@@ -1761,8 +1621,8 @@ DialogDrawItems(Dialog * d, DItem * di, int x, int y, int w, int h)
 			 di->tclass, di->item.button.text);
 	     break;
 	  case DITEM_AREA:
-	     IclassApply(di->iclass, di->win, di->w, di->h, 0, 0, STATE_NORMAL,
-			 0);
+	     IclassApply(di->iclass, di->win, di->w, di->h, 0, 0,
+			 STATE_NORMAL, 0);
 	     break;
 	  case DITEM_CHECKBUTTON:
 	     state = STATE_NORMAL;
@@ -1886,9 +1746,9 @@ DialogItemRadioButtonSetEventFunc(DItem * di,
 void
 DialogItemRadioButtonSetText(DItem * di, char *text)
 {
-   if (di->item.check_button.text)
-      Efree(di->item.check_button.text);
-   di->item.check_button.text = duplicate(text);
+   if (di->item.radio_button.text)
+      Efree(di->item.radio_button.text);
+   di->item.radio_button.text = duplicate(text);
 }
 
 void
@@ -2026,7 +1886,8 @@ DialogItemAreaSetSize(DItem * di, int w, int h)
    di->item.area.h = h;
 }
 
-Window DialogItemAreaGetWindow(DItem * di)
+Window
+DialogItemAreaGetWindow(DItem * di)
 {
    return di->item.area.area_win;
 }
@@ -2057,12 +1918,12 @@ DialogFreeItem(DItem * di)
    switch (di->type)
      {
      case DITEM_BUTTON:
-	if (di->item.text.text)
-	   Efree(di->item.text.text);
+	if (di->item.button.text)
+	   Efree(di->item.button.text);
 	break;
      case DITEM_CHECKBUTTON:
-	if (di->item.text.text)
-	   Efree(di->item.text.text);
+	if (di->item.check_button.text)
+	   Efree(di->item.check_button.text);
 	break;
      case DITEM_TEXT:
 	if (di->item.text.text)
@@ -2072,6 +1933,10 @@ DialogFreeItem(DItem * di)
 	if (di->item.image.image)
 	   Efree(di->item.image.image);
 	break;
+     case DITEM_RADIOBUTTON:
+	if (di->item.radio_button.text)
+	   Efree(di->item.radio_button.text);
+	break;
      case DITEM_SLIDER:
 	if (di->item.slider.ic_base)
 	   di->item.slider.ic_base->ref_count--;
