@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -44,8 +44,7 @@ HandleDrawQueue()
    /* find all DRAW queue entries most recent first and add them to the */
    /* end of the draw list array if there are no previous entries for that */
    /* draw type and that window in the array */
-   while (
-	  (dq =
+   while ((dq =
 	   (DrawQueue *) RemoveItem(NULL, 0, LIST_FINDBY_NONE, LIST_TYPE_DRAW)))
      {
 	already = 0;
@@ -56,7 +55,7 @@ HandleDrawQueue()
 		  if ((lst[i]->win == dq->win) && (lst[i]->shape_propagate))
 		    {
 		       already = 1;
-		       i = num;
+		       break;
 		    }
 	       }
 	  }
@@ -67,7 +66,7 @@ HandleDrawQueue()
 		  if ((lst[i]->win == dq->win) && (lst[i]->text))
 		    {
 		       already = 1;
-		       i = num;
+		       break;
 		    }
 	       }
 	  }
@@ -79,7 +78,7 @@ HandleDrawQueue()
 		      && (!lst[i]->text))
 		    {
 		       already = 1;
-		       i = num;
+		       break;
 		    }
 	       }
 	  }
@@ -90,7 +89,7 @@ HandleDrawQueue()
 		  if ((lst[i]->win == dq->win) && (lst[i]->pager))
 		    {
 		       already = 1;
-		       i = num;
+		       break;
 		    }
 	       }
 	  }
@@ -118,7 +117,7 @@ HandleDrawQueue()
 			  lst[i]->h +=
 			     (dq->y + dq->h) - (lst[i]->y + lst[i]->h);
 		       already = 1;
-		       i = num;
+		       break;
 		    }
 	       }
 	  }
@@ -156,10 +155,11 @@ HandleDrawQueue()
 			    break;
 			 }
 		       already = 1;
-		       i = num;
+		       break;
 		    }
 	       }
 	  }
+
 	if (already)
 	  {
 	     if (dq)
@@ -185,57 +185,62 @@ HandleDrawQueue()
      {
 	for (i = num - 1; i >= 0; i--)
 	  {
-	     if (lst[i]->shape_propagate)
+	     dq = lst[i];
+	     if (dq->shape_propagate)
 	       {
-		  PropagateShapes(lst[i]->win);
-/*            printf("S %x\n", lst[i]->win); */
+/*            printf("S %x\n", dq->win); */
+		  if (WinExists(dq->win))
+		     PropagateShapes(dq->win);
 	       }
-	     else if (lst[i]->text)
+	     else if (dq->text)
 	       {
-		  TclassApply(lst[i]->iclass, lst[i]->win, lst[i]->w, lst[i]->h,
-			      lst[i]->active, lst[i]->sticky, lst[i]->state,
-			      lst[i]->expose, lst[i]->tclass, lst[i]->text);
-		  Efree(lst[i]->text);
-/*            printf("T %x\n", lst[i]->win); */
+/*            printf("T %x\n", dq->win); */
+		  if (WinExists(dq->win))
+		     TclassApply(dq->iclass, dq->win, dq->w, dq->h, dq->active,
+				 dq->sticky, dq->state, dq->expose, dq->tclass,
+				 dq->text);
+		  Efree(dq->text);
 	       }
-	     else if (lst[i]->iclass)
+	     else if (dq->iclass)
 	       {
-		  IclassApply(lst[i]->iclass, lst[i]->win, lst[i]->w, lst[i]->h,
-			      lst[i]->active, lst[i]->sticky, lst[i]->state, 0);
-/*            printf("I %x\n", lst[i]->win); */
+/*            printf("I %x\n", dq->win); */
+		  if (WinExists(dq->win))
+		     IclassApply(dq->iclass, dq->win, dq->w, dq->h, dq->active,
+				 dq->sticky, dq->state, 0);
 	       }
-	     else if (lst[i]->pager)
+	     else if (dq->pager)
 	       {
+/*            printf("P %x\n", dq->win); */
 		  if (FindItem
-		      ((char *)(lst[i]->pager), 0, LIST_FINDBY_POINTER,
-		       LIST_TYPE_PAGER)) PagerForceUpdate(lst[i]->pager);
-/*            printf("P %x\n", lst[i]->win); */
-	       }
-	     else if (lst[i]->d)
-	       {
-		  if (FindItem
-		      ((char *)(lst[i]->d), 0, LIST_FINDBY_POINTER,
-		       LIST_TYPE_DIALOG))
-		     DialogDrawItems(lst[i]->d, lst[i]->di, lst[i]->x,
-				     lst[i]->y, lst[i]->w, lst[i]->h);
-/*            printf("D %x\n", lst[i]->d->ewin->client.win); */
-	       }
-	     else if (lst[i]->redraw_pager)
-	       {
-		  if (FindItem
-		      ((char *)(lst[i]->redraw_pager), 0, LIST_FINDBY_POINTER,
+		      ((char *)(dq->pager), 0, LIST_FINDBY_POINTER,
 		       LIST_TYPE_PAGER))
-		     PagerRedraw(lst[i]->redraw_pager, lst[i]->newbg);
-/*            printf("p %x\n", lst[i]->win); */
+		     PagerForceUpdate(dq->pager);
 	       }
-	     if (lst[i]->iclass)
-		lst[i]->iclass->ref_count--;
-	     if (lst[i]->tclass)
-		lst[i]->tclass->ref_count--;
-	     Efree(lst[i]);
+	     else if (dq->d)
+	       {
+/*            printf("D %x\n", dq->d->ewin->client.win); */
+		  if (FindItem
+		      ((char *)(dq->d), 0, LIST_FINDBY_POINTER,
+		       LIST_TYPE_DIALOG))
+		     DialogDrawItems(dq->d, dq->di, dq->x, dq->y, dq->w, dq->h);
+	       }
+	     else if (dq->redraw_pager)
+	       {
+/*            printf("p %x\n", dq->win); */
+		  if (FindItem
+		      ((char *)(dq->redraw_pager), 0, LIST_FINDBY_POINTER,
+		       LIST_TYPE_PAGER))
+		     PagerRedraw(dq->redraw_pager, dq->newbg);
+	       }
+	     if (dq->iclass)
+		dq->iclass->ref_count--;
+	     if (dq->tclass)
+		dq->tclass->ref_count--;
+	     Efree(dq);
 	  }
 	Efree(lst);
      }
+
    queue_up = p_queue;
    EDBUG_RETURN_;
 }
@@ -281,17 +286,17 @@ ECreatePixImg(Window win, int w, int h)
    int                 bpp;
    PixImg             *pi;
 
-   if (id->x.depth <= 8)
+   if (pImlibData->x.depth <= 8)
       bpp = 1;
-   else if (id->x.depth <= 16)
+   else if (pImlibData->x.depth <= 16)
       bpp = 2;
-   else if (id->x.depth <= 24)
+   else if (pImlibData->x.depth <= 24)
       bpp = 3;
    else
       bpp = 4;
-   if ((id->max_shm) && ((bpp * w * h) > id->max_shm))
+   if ((pImlibData->max_shm) && ((bpp * w * h) > pImlibData->max_shm))
       return NULL;
-   if ((!id->x.shm) || (!id->x.shmp))
+   if ((!pImlibData->x.shm) || (!pImlibData->x.shmp))
       return NULL;
 
    pi = Emalloc(sizeof(PixImg));
@@ -514,15 +519,14 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 
 		  ptr1 =
 		     (unsigned int *)(s1->xim->data +
-				      ((x) * ((s1->xim->bits_per_pixel) >> 3)) +
+				      ((x) *
+				       ((s1->xim->bits_per_pixel) >> 3)) +
 				      ((j + y) * s1->xim->bytes_per_line));
 		  ptr2 =
 		     (unsigned int *)(s2->xim->data +
 				      ((ox) *
-				       ((s2->xim->bits_per_pixel) >> 3)) + ((j +
-									     oy)
-									    *
-									    s2->xim->bytes_per_line));
+				       ((s2->xim->bits_per_pixel) >> 3)) +
+				      ((j + oy) * s2->xim->bytes_per_line));
 		  ptr3 =
 		     (unsigned int *)(dst->xim->data +
 				      ((ox) *
@@ -535,8 +539,8 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 		       p1 = *ptr1++;
 		       p2 = *ptr2++;
 		       *ptr3++ =
-			  ((p1 >> 1) & 0x7f7f7f7f) + ((p2 >> 1) & 0x7f7f7f7f) +
-			  (p1 & p2 & 0x01010101);
+			  ((p1 >> 1) & 0x7f7f7f7f) +
+			  ((p2 >> 1) & 0x7f7f7f7f) + (p1 & p2 & 0x01010101);
 		    }
 	       }
 	     break;
@@ -557,7 +561,7 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 	       }
 	     break;
 	  case 16:
-	     if (id->x.render_depth != 15)
+	     if (pImlibData->x.render_depth != 15)
 	       {
 		  for (j = 0; j < h; j++)
 		    {
@@ -566,20 +570,32 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 		       ptr1 =
 			  (unsigned int *)(s1->xim->data +
 					   ((x) *
-					    ((s1->xim->bits_per_pixel) >> 3)) +
-					   ((j + y) * s1->xim->bytes_per_line));
+					    ((s1->xim->
+					      bits_per_pixel) >> 3)) + ((j +
+									 y) *
+									s1->
+									xim->
+									bytes_per_line));
 		       ptr2 =
 			  (unsigned int *)(s2->xim->data +
 					   ((ox) *
-					    ((s2->xim->bits_per_pixel) >> 3)) +
-					   ((j + oy) *
-					    s2->xim->bytes_per_line));
+					    ((s2->xim->
+					      bits_per_pixel) >> 3)) + ((j +
+									 oy)
+									*
+									s2->
+									xim->
+									bytes_per_line));
 		       ptr3 =
 			  (unsigned int *)(dst->xim->data +
 					   ((ox) *
-					    ((dst->xim->bits_per_pixel) >> 3)) +
-					   ((j + oy) *
-					    dst->xim->bytes_per_line));
+					    ((dst->xim->
+					      bits_per_pixel) >> 3)) + ((j +
+									 oy)
+									*
+									dst->
+									xim->
+									bytes_per_line));
 		       if (!(w & 0x1))
 			 {
 			    for (i = 0; i < w; i += 2)
@@ -590,13 +606,17 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 				 p2 = *ptr2++;
 				 *ptr3++ =
 				    ((p1 >> 1) &
-				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3) |
-				      (0x78 << 24) | (0x7c << 19) | (0x78 <<
-								     13))) +
+				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3)
+				      | (0x78 << 24) | (0x7c << 19) | (0x78
+								       <<
+								       13)))
+				    +
 				    ((p2 >> 1) &
-				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3) |
-				      (0x78 << 24) | (0x7c << 19) | (0x78 <<
-								     13))) +
+				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3)
+				      | (0x78 << 24) | (0x7c << 19) | (0x78
+								       <<
+								       13)))
+				    +
 				    (p1 & p2 &
 				     ((0x1 << 11) | (0x1 << 5) | (0x1) |
 				      (0x1 << 27) | (0x1 << 21) | (0x1 << 16)));
@@ -612,13 +632,17 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 				 p2 = *ptr2++;
 				 *ptr3++ =
 				    ((p1 >> 1) &
-				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3) |
-				      (0x78 << 24) | (0x7c << 19) | (0x78 <<
-								     13))) +
+				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3)
+				      | (0x78 << 24) | (0x7c << 19) | (0x78
+								       <<
+								       13)))
+				    +
 				    ((p2 >> 1) &
-				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3) |
-				      (0x78 << 24) | (0x7c << 19) | (0x78 <<
-								     13))) +
+				     ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3)
+				      | (0x78 << 24) | (0x7c << 19) | (0x78
+								       <<
+								       13)))
+				    +
 				    (p1 & p2 &
 				     ((0x1 << 11) | (0x1 << 5) | (0x1) |
 				      (0x1 << 27) | (0x1 << 21) | (0x1 << 16)));
@@ -634,11 +658,13 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 			       pp2 = *pptr2;
 			       *pptr3 =
 				  ((pp1 >> 1) &
-				   ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3))) +
+				   ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3)))
+				  +
 				  ((pp2 >> 1) &
-				   ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3))) +
-				  (pp1 & pp2 & ((0x1 << 11) | (0x1 << 5) |
-						(0x1)));
+				   ((0x78 << 8) | (0x7c << 3) | (0x78 >> 3)))
+				  +
+				  (pp1 & pp2 &
+				   ((0x1 << 11) | (0x1 << 5) | (0x1)));
 			    }
 			 }
 		    }
@@ -652,20 +678,32 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 		       ptr1 =
 			  (unsigned int *)(s1->xim->data +
 					   ((x) *
-					    ((s1->xim->bits_per_pixel) >> 3)) +
-					   ((j + y) * s1->xim->bytes_per_line));
+					    ((s1->xim->
+					      bits_per_pixel) >> 3)) + ((j +
+									 y) *
+									s1->
+									xim->
+									bytes_per_line));
 		       ptr2 =
 			  (unsigned int *)(s2->xim->data +
 					   ((ox) *
-					    ((s2->xim->bits_per_pixel) >> 3)) +
-					   ((j + oy) *
-					    s2->xim->bytes_per_line));
+					    ((s2->xim->
+					      bits_per_pixel) >> 3)) + ((j +
+									 oy)
+									*
+									s2->
+									xim->
+									bytes_per_line));
 		       ptr3 =
 			  (unsigned int *)(dst->xim->data +
 					   ((ox) *
-					    ((dst->xim->bits_per_pixel) >> 3)) +
-					   ((j + oy) *
-					    dst->xim->bytes_per_line));
+					    ((dst->xim->
+					      bits_per_pixel) >> 3)) + ((j +
+									 oy)
+									*
+									dst->
+									xim->
+									bytes_per_line));
 		       if (!(w & 0x1))
 			 {
 			    for (i = 0; i < w; i += 2)
@@ -676,13 +714,17 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 				 p2 = *ptr2++;
 				 *ptr3++ =
 				    ((p1 >> 1) &
-				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3) |
-				      (0x78 << 23) | (0x78 << 18) | (0x78 <<
-								     13))) +
+				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3)
+				      | (0x78 << 23) | (0x78 << 18) | (0x78
+								       <<
+								       13)))
+				    +
 				    ((p2 >> 1) &
-				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3) |
-				      (0x78 << 23) | (0x78 << 18) | (0x78 <<
-								     13))) +
+				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3)
+				      | (0x78 << 23) | (0x78 << 18) | (0x78
+								       <<
+								       13)))
+				    +
 				    (p1 & p2 &
 				     ((0x1 << 10) | (0x1 << 5) | (0x1) |
 				      (0x1 << 26) | (0x1 << 20) | (0x1 << 16)));
@@ -698,13 +740,17 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 				 p2 = *ptr2++;
 				 *ptr3++ =
 				    ((p1 >> 1) &
-				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3) |
-				      (0x78 << 23) | (0x78 << 18) | (0x78 <<
-								     13))) +
+				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3)
+				      | (0x78 << 23) | (0x78 << 18) | (0x78
+								       <<
+								       13)))
+				    +
 				    ((p2 >> 1) &
-				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3) |
-				      (0x78 << 23) | (0x78 << 18) | (0x78 <<
-								     13))) +
+				     ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3)
+				      | (0x78 << 23) | (0x78 << 18) | (0x78
+								       <<
+								       13)))
+				    +
 				    (p1 & p2 &
 				     ((0x1 << 10) | (0x1 << 5) | (0x1) |
 				      (0x1 << 26) | (0x1 << 20) | (0x1 << 16)));
@@ -720,11 +766,13 @@ EBlendPixImg(EWin * ewin, PixImg * s1, PixImg * s2, PixImg * dst, int x, int y,
 			       pp2 = *pptr2;
 			       *pptr3++ =
 				  ((pp1 >> 1) &
-				   ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3))) +
+				   ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3)))
+				  +
 				  ((pp2 >> 1) &
-				   ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3))) +
-				  (pp1 & pp2 & ((0x1 << 10) | (0x1 << 5) |
-						(0x1)));
+				   ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3)))
+				  +
+				  (pp1 & pp2 &
+				   ((0x1 << 10) | (0x1 << 5) | (0x1)));
 			    }
 			 }
 		    }
@@ -875,16 +923,17 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
       md = 0;
    if (md == 5)
      {
-	if (id->x.depth <= 8)
+	if (pImlibData->x.depth <= 8)
 	   bpp = 1;
-	else if (id->x.depth <= 16)
+	else if (pImlibData->x.depth <= 16)
 	   bpp = 2;
-	else if (id->x.depth <= 24)
+	else if (pImlibData->x.depth <= 24)
 	   bpp = 3;
 	else
 	   bpp = 4;
-	if ((ird) || ((id->max_shm) && ((bpp * w * h) > id->max_shm))
-	    || ((!id->x.shm) || (!id->x.shmp)))
+	if ((prImlibData)
+	    || ((pImlibData->max_shm) && ((bpp * w * h) > pImlibData->max_shm))
+	    || ((!pImlibData->x.shm) || (!pImlibData->x.shmp)))
 	   md = 0;
      }
    pw = w;
@@ -908,17 +957,14 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
      case 4:
      case 5:
 	if (!b1)
-	   b1 =
-	      XCreateBitmapFromData(disp, root.win, flipped_gray_bits,
-				    flipped_gray_width, flipped_gray_height);
+	   b1 = XCreateBitmapFromData(disp, root.win, flipped_gray_bits,
+				      flipped_gray_width, flipped_gray_height);
 	if (!b2)
-	   b2 =
-	      XCreateBitmapFromData(disp, root.win, gray_bits, gray_width,
-				    gray_height);
+	   b2 = XCreateBitmapFromData(disp, root.win, gray_bits, gray_width,
+				      gray_height);
 	if (!b3)
-	   b3 =
-	      XCreateBitmapFromData(disp, root.win, gray3_bits, gray3_width,
-				    gray3_height);
+	   b3 = XCreateBitmapFromData(disp, root.win, gray3_bits, gray3_width,
+				      gray3_height);
 	x1 = ewin->x + desks.desk[ewin->desktop].x;
 	y1 = ewin->y + desks.desk[ewin->desktop].y;
 	w1 = ewin->w - (ewin->border->border.left + ewin->border->border.right);
@@ -950,9 +996,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 	     if (gcv.foreground == 0)
 		gcv.foreground = BlackPixel(disp, root.scr);
 	     gcv.subwindow_mode = IncludeInferiors;
-	     gc =
-		XCreateGC(disp, root.win,
-			  GCFunction | GCForeground | GCSubwindowMode, &gcv);
+	     gc = XCreateGC(disp, root.win,
+			    GCFunction | GCForeground | GCSubwindowMode, &gcv);
 	  }
 #define DRAW_H_ARROW(x1, x2, y1) \
       if (((x2) - (x1)) >= 12) \
@@ -1174,7 +1219,7 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
 		       UngrabX();
 		       DrawEwinShape(ewin, mode.movemode, x, y, w, h,
 				     firstlast);
-		       EDBUG_RETURN_;
+		       goto exit;
 		    }
 		  EFillPixmap(root.win, root_pi->pmap, x1, y1, ewin->w,
 			      ewin->h);
@@ -1306,6 +1351,8 @@ DrawEwinShape(EWin * ewin, int md, int x, int y, int w, int h, char firstlast)
      default:
 	break;
      }
+
+ exit:
    queue_up = pq;
    EDBUG_RETURN_;
 }
@@ -1314,7 +1361,7 @@ ImlibImage         *
 ELoadImage(char *file)
 {
    EDBUG(5, "ELoadImage");
-   EDBUG_RETURN(ELoadImageImlibData(id, file));
+   EDBUG_RETURN(ELoadImageImlibData(pImlibData, file));
 }
 
 ImlibImage         *
@@ -1398,9 +1445,8 @@ PropagateShapes(Window win)
 	     if ((att.class == InputOutput) && (att.map_state != IsUnmapped))
 	       {
 		  rl = NULL;
-		  rl =
-		     EShapeGetRectangles(disp, list[i], ShapeBounding, &rn,
-					 &ord);
+		  rl = EShapeGetRectangles(disp, list[i], ShapeBounding, &rn,
+					   &ord);
 		  if (rl)
 		    {
 		       num_rects += rn;
