@@ -1,6 +1,5 @@
-
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  * *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -23,25 +22,6 @@
  */
 #include "E.h"
 
-#define WIN_LAYER_DESKTOP                0
-#define WIN_LAYER_BELOW                  2
-#define WIN_LAYER_NORMAL                 4
-#define WIN_LAYER_ONTOP                  6
-#define WIN_LAYER_DOCK                   8
-#define WIN_LAYER_ABOVE_DOCK             10
-#define WIN_LAYER_MENU                   12
-
-#define WIN_STATE_STICKY          (1<<0)	/* everyone knows sticky */
-#define WIN_STATE_RESERVED_BIT1   (1<<1)	/* removed minimize here */
-#define WIN_STATE_MAXIMIZED_VERT  (1<<2)	/* window in maximized V state */
-#define WIN_STATE_MAXIMIZED_HORIZ (1<<3)	/* window in maximized H state */
-#define WIN_STATE_HIDDEN          (1<<4)	/* not on taskbar but window visible */
-#define WIN_STATE_SHADED          (1<<5)	/* shaded (NeXT style) */
-#define WIN_STATE_HID_WORKSPACE   (1<<6)	/* not on current desktop */
-#define WIN_STATE_HID_TRANSIENT   (1<<7)	/* owner of transient is hidden */
-#define WIN_STATE_FIXED_POSITION  (1<<8)	/* window is fixed in position even */
-#define WIN_STATE_ARRANGE_IGNORE  (1<<9)	/* ignore for auto arranging */
-
 static ToolTip     *ttip = NULL;
 struct _mdata
 {
@@ -116,126 +96,24 @@ ToolTipTimeout(int val, void *data)
 void
 HandleClientMessage(XEvent * ev)
 {
-   EWin               *ewin;
-
-   static Atom         a1 = 0, a2 = 0, a3 = 0, a4 = 0, a5 = 0, a6 = 0;
-
    EDBUG(5, "HandleClientMessage");
-   if (!a1)
-      a1 = XInternAtom(disp, "ENL_MSG", False);
-   if (!a2)
-      a2 = XInternAtom(disp, "_WIN_AREA", False);
-   if (!a3)
-      a3 = XInternAtom(disp, "_WIN_WORKSPACE", False);
-   if (!a4)
-      a4 = XInternAtom(disp, "_WIN_LAYER", False);
-   if (!a5)
-      a5 = XInternAtom(disp, "_WIN_STATE", False);
-   if (!a6)
-      a6 = XInternAtom(disp, "WM_CHANGE_STATE", False);
-   if (ev->xclient.message_type == a1)
+
+   if (debug_flags & EDBUG_CLIENT_MESSAGES)
      {
-	HandleComms(ev);
-	EDBUG_RETURN_;
+	char               *name = XGetAtomName(disp, ev->xclient.message_type);
+
+	printf
+	   ("HandleClientMessage: ev_type=%s(%d) ev_win=%#x data[0-3]= %08lx %08lx %08lx %08lx\n",
+	    name, (unsigned)ev->xclient.message_type,
+	    (unsigned)ev->xclient.window, ev->xclient.data.l[0],
+	    ev->xclient.data.l[1], ev->xclient.data.l[2],
+	    ev->xclient.data.l[3]);
+	XFree(name);
      }
-   if (ev->xclient.message_type == a2)
-     {
-	SetCurrentArea(ev->xclient.data.l[0], ev->xclient.data.l[1]);
-	EDBUG_RETURN_;
-     }
-   if (ev->xclient.message_type == a3)
-     {
-	GotoDesktop(ev->xclient.data.l[0]);
-	EDBUG_RETURN_;
-     }
-   if (ev->xclient.message_type == a4)
-     {
-	ewin =
-	   FindItem(NULL, ev->xclient.window, LIST_FINDBY_ID, LIST_TYPE_EWIN);
-	if (ewin)
-	  {
-	     ewin->layer = ev->xclient.data.l[0];
-	     XChangeProperty(disp, ewin->win, a4, XA_CARDINAL, 32,
-			     PropModeReplace,
-			     (unsigned char *)(&(ev->xclient.data.l[0])), 1);
-	     RaiseEwin(ewin);
-	  }
-	EDBUG_RETURN_;
-     }
-   if (ev->xclient.message_type == a5)
-     {
-	ewin =
-	   FindItem(NULL, ev->xclient.window, LIST_FINDBY_ID, LIST_TYPE_EWIN);
-	if (!ewin)
-	   EDBUG_RETURN_;
-	if (ev->xclient.data.l[0] & WIN_STATE_FIXED_POSITION)
-	  {
-	     if (ev->xclient.data.l[1] & WIN_STATE_FIXED_POSITION)
-		ewin->fixedpos = 1;
-	     else
-		ewin->fixedpos = 0;
-	  }
-	if (ev->xclient.data.l[0] & WIN_STATE_ARRANGE_IGNORE)
-	  {
-	     if (ev->xclient.data.l[1] & WIN_STATE_ARRANGE_IGNORE)
-		ewin->ignorearrange = 1;
-	     else
-		ewin->ignorearrange = 0;
-	  }
-	if ((ev->xclient.data.l[0] & WIN_STATE_STICKY)
-	    && (!ewin->ignorearrange))
-	  {
-	     if (ev->xclient.data.l[1] & WIN_STATE_STICKY)
-	       {
-		  if (!(ewin->sticky))
-		    {
-		       ewin->sticky = 1;
-		       RaiseEwin(ewin);
-		       DrawEwin(ewin);
-		       ApplySclass(FindItem
-				   ("SOUND_WINDOW_STICK", 0, LIST_FINDBY_NAME,
-				    LIST_TYPE_SCLASS));
-		    }
-	       }
-	     else
-	       {
-		  if (ewin->sticky)
-		    {
-		       ewin->sticky = 0;
-		       RaiseEwin(ewin);
-		       DrawEwin(ewin);
-		       ApplySclass(FindItem
-				   ("SOUND_WINDOW_UNSTICK", 0, LIST_FINDBY_NAME,
-				    LIST_TYPE_SCLASS));
-		    }
-	       }
-	  }
-	if (ev->xclient.data.l[0] & WIN_STATE_SHADED)
-	  {
-	     if (ev->xclient.data.l[1] & WIN_STATE_SHADED)
-		ShadeEwin(ewin);
-	     else
-		UnShadeEwin(ewin);
-	  }
-	GNOME_SetHint(ewin);
-	EDBUG_RETURN_;
-     }
-   if (ev->xclient.message_type == a6)
-     {
-	ewin =
-	   FindItem(NULL, ev->xclient.window, LIST_FINDBY_ID, LIST_TYPE_EWIN);
-	if ((ewin) && (ev->xclient.data.l[0] == IconicState)
-	    && (!(ewin->iconified)))
-	  {
-	     IconifyEwin(ewin);
-	     EDBUG_RETURN_;
-	  }
-     }
-   if (mode.kde_support)
-      KDE_ProcessClientMessage(&(ev->xclient));
+
+   HintsProcessClientMessage(&(ev->xclient));
 
    EDBUG_RETURN_;
-
 }
 
 void
@@ -300,7 +178,7 @@ HandleFocusWindow(Window win)
 	  {
 	     if (!found_ewin)
 		ICCCM_Cmap(NULL);
-	     if (found_ewin)
+	     else if (!(found_ewin->focusclick))
 		FocusToEWin(found_ewin);
 	     mode.mouse_over_win = found_ewin;
 	  }
@@ -359,8 +237,7 @@ HandleMotion(XEvent * ev)
    ewin = NULL;
    desks.current = DesktopAt(mode.x, mode.y);
 
-   if (
-       (!(ev->xmotion.state
+   if ((!(ev->xmotion.state
 	  & (Button1Mask | Button2Mask | Button3Mask | Button4Mask |
 	     Button5Mask)) && (!mode.place)))
      {
@@ -404,8 +281,8 @@ HandleMotion(XEvent * ev)
 	     else
 	       {
 		  gwins =
-		     ListWinGroupMembersForEwin(ewin, ACTION_MOVE, mode.nogroup,
-						&num);
+		     ListWinGroupMembersForEwin(ewin, ACTION_MOVE,
+						mode.nogroup, &num);
 	       }
 	     if ((mode.moveresize_pending_ewin)
 		 && (mode.ewin == mode.moveresize_pending_ewin))
@@ -496,17 +373,13 @@ HandleMotion(XEvent * ev)
 				 &&
 				 (!(IN_RANGE
 				    (gwins[i]->reqx, gwins[i]->x,
-				     screen_snap_dist)))) || ((gwins[i]->x != 0)
-							      && (gwins[i]->x !=
-								  (root.w -
-								   gwins[i]->w)
-								  &&
-								  (!(IN_RANGE
-								     (gwins
-								      [i]->reqx,
-								      gwins
-								      [i]->x,
-								      mode.edge_snap_dist)))))))
+				     screen_snap_dist))))
+			     || ((gwins[i]->x != 0)
+				 && (gwins[i]->x != (root.w - gwins[i]->w)
+				     &&
+				     (!(IN_RANGE
+					(gwins[i]->reqx, gwins[i]->x,
+					 mode.edge_snap_dist)))))))
 		       {
 			  jumpx = 1;
 			  ndx = gwins[i]->reqx - gwins[i]->x + dx;
@@ -522,17 +395,13 @@ HandleMotion(XEvent * ev)
 				 &&
 				 (!(IN_RANGE
 				    (gwins[i]->reqy, gwins[i]->y,
-				     screen_snap_dist)))) || ((gwins[i]->y != 0)
-							      && (gwins[i]->y !=
-								  (root.h -
-								   gwins[i]->h)
-								  &&
-								  (!(IN_RANGE
-								     (gwins
-								      [i]->reqy,
-								      gwins
-								      [i]->y,
-								      mode.edge_snap_dist)))))))
+				     screen_snap_dist))))
+			     || ((gwins[i]->y != 0)
+				 && (gwins[i]->y != (root.h - gwins[i]->h)
+				     &&
+				     (!(IN_RANGE
+					(gwins[i]->reqy, gwins[i]->y,
+					 mode.edge_snap_dist)))))))
 		       {
 			  jumpy = 1;
 			  ndy = gwins[i]->reqy - gwins[i]->y + dy;
@@ -573,8 +442,7 @@ HandleMotion(XEvent * ev)
 				  continue;
 
 			       /* check for sufficient overlap and avoid flickering */
-			       if (
-				   ((gwins
+			       if (((gwins
 				     [i]->x >= all_gwins[j]->x
 				     && gwins[i]->x <=
 				     all_gwins[j]->x + all_gwins[j]->w / 2
@@ -834,12 +702,6 @@ HandleMotion(XEvent * ev)
      {
 	int                 i, offx = 0, offy = 0, xdist = 0, ydist = 0;
 	EWin               *ewin;
-
-#ifdef HAS_XINERAMA
-	static XineramaScreenInfo *screens;
-	static int          num_screens;
-
-#endif
 	EWin               *menus[256];
 	int                 fx[256];
 	int                 fy[256];
@@ -848,43 +710,8 @@ HandleMotion(XEvent * ev)
 	static int          menu_scroll_dist = 4;
 	int                 my_width, my_height, x_org, y_org, head_num = 0;
 
-	my_width = root.w;
-	my_height = root.h;
-	x_org = 0;
-	y_org = 0;
-
-#ifdef HAS_XINERAMA
-	if (xinerama_active)
-	  {
-	     int                 i;
-
-	     if (!screens)
-	       {
-		  screens = XineramaQueryScreens(disp, &num_screens);
-	       }
-	     for (i = 0; i < num_screens; i++)
-	       {
-		  if (mode.x >= screens[i].x_org)
-		    {
-		       if (mode.x <= (screens[i].width + screens[i].x_org))
-			 {
-			    if (mode.y >= screens[i].y_org)
-			      {
-				 if (mode.y <=
-				     (screens[i].height + screens[i].y_org))
-				   {
-				      my_width = screens[i].width;
-				      my_height = screens[i].height;
-				      x_org = screens[i].x_org;
-				      y_org = screens[i].y_org;
-				      head_num = i;
-				   }
-			      }
-			 }
-		    }
-	       }
-	  }
-#endif
+	head_num = ScreenGetGeometry(mode.x, mode.y, &x_org, &y_org,
+				     &my_width, &my_height);
 
 	if (mode.x > ((x_org + my_width) - (menu_scroll_dist + 1)))
 	  {
@@ -1089,6 +916,8 @@ HandleMotion(XEvent * ev)
 		       MoveEwin(gwins[i], x, y);
 		    }
 	       }
+	     if (gwins)
+		Efree(gwins);
 	  }
      }
    /* dialogs? */
@@ -1162,7 +991,7 @@ HandleDestroy(XEvent * ev)
 
    EDBUG(5, "HandleDestroy");
    win = ev->xdestroywindow.window;
-   DelXID(win);
+   EForgetWindow(disp, win);
    ewin = RemoveItem(NULL, win, LIST_FINDBY_ID, LIST_TYPE_EWIN);
    if (ewin)
       if (ewin->iconified > 0)
@@ -1170,8 +999,10 @@ HandleDestroy(XEvent * ev)
 
    mode.context_win = win;
 
+#if ENABLE_KDE
    if (mode.kde_support)
       KDE_RemoveModule(win);
+#endif
 
    if (ewin)
      {
@@ -1219,18 +1050,15 @@ HandleDestroy(XEvent * ev)
 	   mode.ewin = NULL;
 	if (mode.dockapp_support && ewin->docked)
 	   DockDestroy(ewin);
-	DesktopRemoveEwin(ewin);
 	FreeEwin(ewin);
-	GNOME_SetClientList();
+	HintsSetClientList();
 	EDBUG_RETURN_;
      }
+
    c = FindItem(NULL, win, LIST_FINDBY_ID, LIST_TYPE_CLIENT);
    if (c)
       DeleteClient(c);
-   if (win == external_pager_window)
-     {
-	ShowIcons();
-     }
+
    EDBUG_RETURN_;
 }
 
@@ -1242,7 +1070,18 @@ HandleProperty(XEvent * ev)
    char                title[10240];
    int                 desktop;
 
+   if (debug_flags & EDBUG_PROPERTY_CHANGE)
+     {
+	char               *name = XGetAtomName(disp, ev->xproperty.atom);
+
+	printf("HandleProperty: Atom=%s(%d) id=%#x\n",
+	       name, (unsigned)ev->xproperty.atom,
+	       (unsigned)ev->xproperty.window);
+	XFree(name);
+     }
+
    EDBUG(5, "HandleProperty");
+
    win = ev->xproperty.window;
    ewin = FindItem(NULL, win, LIST_FINDBY_ID, LIST_TYPE_EWIN);
    if (ewin)
@@ -1254,13 +1093,9 @@ HandleProperty(XEvent * ev)
 	if (ewin->client.title)
 	   strncpy(title, ewin->client.title, 10240);
 	desktop = ewin->desktop;
-	GNOME_GetHintDesktop(ewin, ev->xproperty.atom);
+	HintsProcessPropertyChange(ewin, ev->xproperty.atom);
 	if ((desktop != ewin->desktop) && (!ewin->sticky))
 	   MoveEwinToDesktop(ewin, ewin->desktop);
-	GNOME_GetHintIcons(ewin, ev->xproperty.atom);
-	GNOME_GetHintAppState(ewin, ev->xproperty.atom);
-	GNOME_GetExpandedSize(ewin, ev->xproperty.atom);
-	GNOME_GetHint(ewin, ev->xproperty.atom);
 	ICCCM_GetTitle(ewin, ev->xproperty.atom);
 	ICCCM_GetHints(ewin, ev->xproperty.atom);
 	ICCCM_GetInfo(ewin, ev->xproperty.atom);
@@ -1268,15 +1103,19 @@ HandleProperty(XEvent * ev)
 	ICCCM_GetGeoms(ewin, ev->xproperty.atom);
 	SessionGetInfo(ewin, ev->xproperty.atom);
 	SyncBorderToEwin(ewin);
+#if ENABLE_KDE
 	if (mode.kde_support)
 	   KDE_ClientChange(win, ev->xproperty.atom);
+#endif
 	if (ewin->client.title)
 	   if (strncmp(title, ewin->client.title, 10240))
 	     {
 		UpdateBorderInfo(ewin);
 		CalcEwinSizes(ewin);
+#if ENABLE_KDE
 		if (mode.kde_support)
 		   KDE_UpdateClient(ewin);
+#endif
 	     }
 	if ((ewin->iconified) && (pm != ewin->client.icon_pmap))
 	  {
@@ -1308,15 +1147,19 @@ HandleProperty(XEvent * ev)
    else if (win == root.win)
      {
 	/* we're in the root window, not in a client */
+#if ENABLE_KDE
 	if (mode.kde_support)
 	  {
 	     KDE_HintChange(ev->xproperty.atom);
 	  }
+#endif
      }
+#if ENABLE_KDE
    else if (mode.kde_support)
      {
 	KDE_ClientChange(win, ev->xproperty.atom);
      }
+#endif
    EDBUG_RETURN_;
 }
 
@@ -1399,7 +1242,7 @@ HandleReparent(XEvent * ev)
 	     if ((mode.slideout) && (ewin == mode.ewin))
 		HideSlideout(mode.slideout, mode.context_win);
 	     FreeEwin(ewin);
-	     GNOME_SetClientList();
+	     HintsSetClientList();
 	  }
      }
    EDBUG_RETURN_;
@@ -1534,6 +1377,13 @@ HandleResizeRequest(XEvent * ev)
    EDBUG_RETURN_;
 }
 
+void
+HandleMap(XEvent * ev)
+{
+   EDBUG(5, "HandleMap");
+   EDBUG_RETURN_;
+}
+
 void
 HandleUnmap(XEvent * ev)
 {
@@ -1544,14 +1394,6 @@ HandleUnmap(XEvent * ev)
    EDBUG(5, "HandleUnmap");
    win = ev->xunmap.window;
    ewin = FindItem(NULL, win, LIST_FINDBY_ID, LIST_TYPE_EWIN);
-   if (ewin)
-     {
-	if (ewin->iconified > 1)
-	  {
-	     ewin->iconified = ewin->iconified - 1;
-	     EDBUG_RETURN_;
-	  }
-     }
    if (ewin)
      {
 	if (ewin->pager)
@@ -1601,15 +1443,15 @@ HandleUnmap(XEvent * ev)
 				   &ewin->client.y, &win);
 	     EReparentWindow(disp, ewin->client.win, root.win, ewin->client.x,
 			     ewin->client.y);
-	     XRemoveFromSaveSet(disp, ewin->client.win);
 	     ICCCM_Withdraw(ewin);
 	     RemoveItem(NULL, ewin->client.win, LIST_FINDBY_ID, LIST_TYPE_EWIN);
-	     DesktopRemoveEwin(ewin);
 	     FreeEwin(ewin);
-	     GNOME_SetClientList();
+	     HintsSetClientList();
 	  }
 	else
-	   HideEwin(ewin);
+	  {
+	     HideEwin(ewin);
+	  }
      }
    EDBUG_RETURN_;
 }
@@ -1631,7 +1473,8 @@ HandleMapRequest(XEvent * ev)
    else
      {
 	AddToFamily(ev->xmap.window);
-	GNOME_SetClientList();
+	HintsSetClientList();
+#if ENABLE_KDE
 	if (mode.kde_support)
 	  {
 	     EWin               *ewin;
@@ -1639,8 +1482,8 @@ HandleMapRequest(XEvent * ev)
 	     ewin =
 		FindItem(NULL, ev->xmap.window, LIST_FINDBY_ID, LIST_TYPE_EWIN);
 	     KDE_NewWindow(ewin);
-
 	  }
+#endif
      }
    EDBUG_RETURN_;
 }
@@ -1787,10 +1630,10 @@ HandleMouseDown(XEvent * ev)
    if (mode.tooltips)
       DoIn("TOOLTIP_TIMEOUT", mode.tiptime, ToolTipTimeout, 0, NULL);
 
-   if (
-       (((float)(ev->xbutton.time - last_time) / 1000) <
+   if ((((float)(ev->xbutton.time - last_time) / 1000) <
 	mode_double_click_time)
-       && ((int)(ev->xbutton.button) == (int)(last_button))) double_click = 1;
+       && ((int)(ev->xbutton.button) == (int)(last_button)))
+      double_click = 1;
    last_time = ev->xbutton.time;
    last_button = ev->xbutton.button;
 
@@ -1921,14 +1764,21 @@ HandleMouseDown(XEvent * ev)
 	       {
 		  GrabThePointer(win);
 		  if (buttons[i]->inside_win)
-		     XSendEvent(disp, buttons[i]->inside_win, False,
-				ButtonPressMask, ev);
+		    {
+		       Window              id;
+
+		       id = ev->xany.window;
+		       ev->xany.window = buttons[i]->inside_win;
+		       XSendEvent(disp, buttons[i]->inside_win, False,
+				  ButtonPressMask, ev);
+		       ev->xany.window = id;
+		    }
+
 		  mode.button = buttons[i];
 		  buttons[i]->state = STATE_CLICKED;
 		  DrawButton(buttons[i]);
-		  ac =
-		     FindItem("ACTION_BUTTON_DRAG", 0, LIST_FINDBY_NAME,
-			      LIST_TYPE_ACLASS);
+		  ac = FindItem("ACTION_BUTTON_DRAG", 0, LIST_FINDBY_NAME,
+				LIST_TYPE_ACLASS);
 		  if (ac)
 		     EventAclass(ev, ac);
 		  if (buttons[i]->aclass)
@@ -2011,9 +1861,8 @@ HandleMouseDown(XEvent * ev)
      {
 	ActionClass        *ac;
 
-	ac =
-	   (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
-				    LIST_TYPE_ACLASS);
+	ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_ACLASS);
 	if (ac)
 	  {
 	     mode.ewin = ewin;
@@ -2047,6 +1896,9 @@ HandleMouseDown(XEvent * ev)
 		gwin_py[i] = gwins[i]->y;
 	     }
 
+	   if (gwins)
+	      Efree(gwins);
+
 	   if (ev->xbutton.window == p->hi_win)
 	     {
 		int                 hx, hy;
@@ -2488,9 +2340,8 @@ HandleMouseUp(XEvent * ev)
      {
 	ActionClass        *ac;
 
-	ac =
-	   (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
-				    LIST_TYPE_ACLASS);
+	ac = (ActionClass *) FindItem("BUTTONBINDINGS", 0, LIST_FINDBY_NAME,
+				      LIST_TYPE_ACLASS);
 	if (ac)
 	  {
 	     mode.borderpartpress = 1;
@@ -2548,8 +2399,7 @@ HandleMouseUp(XEvent * ev)
 		       if (((ew->pager) || (ew->ibox))
 			   && ((ew->desktop == desks.current) || (ew->sticky)))
 			 {
-			    if (
-				(ev->xbutton.x_root >=
+			    if ((ev->xbutton.x_root >=
 				 (ew->x + ew->border->border.left))
 				&& (ev->xbutton.x_root <
 				    (ew->x + ew->w - ew->border->border.right))
@@ -2572,9 +2422,6 @@ HandleMouseUp(XEvent * ev)
 		       int                 wx, wy, base_x = 0, base_y = 0;
 		       Window              dw;
 
-		       gwins =
-			  ListWinGroupMembersForEwin(p->hi_ewin, ACTION_MOVE,
-						     mode.nogroup, &num);
 		       pp = ewin->pager;
 		       cx = desks.desk[pp->desktop].current_area_x;
 		       cy = desks.desk[pp->desktop].current_area_y;
@@ -2583,24 +2430,20 @@ HandleMouseUp(XEvent * ev)
 		       GetWinWH(p->hi_win, &w, &h);
 		       XTranslateCoordinates(disp, pp->win, root.win, 0, 0, &px,
 					     &py, &dw);
-		       wx =
-			  ((x - px) -
-			   (cx * (pp->w / ax))) * (root.w / (pp->w / ax));
-		       wy =
-			  ((y - py) -
-			   (cy * (pp->h / ay))) * (root.h / (pp->h / ay));
+		       wx = ((x - px) -
+			     (cx * (pp->w / ax))) * (root.w / (pp->w / ax));
+		       wy = ((y - py) -
+			     (cy * (pp->h / ay))) * (root.h / (pp->h / ay));
 		       if (((x + w) <= px) || ((y + h) <= py)
 			   || (x >= (px + pp->w)) || (y >= (py + pp->h)))
 			 {
 			    int                 ndesk, nx, ny;
 
 			    ndesk = desks.current;
-			    nx =
-			       (int)ev->xbutton.x_root -
+			    nx = (int)ev->xbutton.x_root -
 			       desks.desk[desks.current].x -
 			       ((int)p->hi_ewin->w / 2);
-			    ny =
-			       (int)ev->xbutton.y_root -
+			    ny = (int)ev->xbutton.y_root -
 			       desks.desk[desks.current].y -
 			       ((int)p->hi_ewin->h / 2);
 			    MoveEwin(p->hi_ewin, nx, ny);
@@ -2636,6 +2479,8 @@ HandleMouseUp(XEvent * ev)
 					     ((root.h * ay) + wy +
 					      (gwin_py[i] - base_y)) % root.h);
 			      }
+			    if (gwins)
+			       Efree(gwins);
 			 }
 		    }
 		  else if ((ewin) && (ewin->ibox)
@@ -2643,7 +2488,8 @@ HandleMouseUp(XEvent * ev)
 			   (!((p->hi_ewin->ibox) || ((ewin->client.need_input)
 						     && ((ewin->skiptask)
 							 ||
-							 (ewin->skipwinlist))))))
+							 (ewin->
+							  skipwinlist))))))
 		    {
 		       char                was_shaded;
 
@@ -2683,6 +2529,8 @@ HandleMouseUp(XEvent * ev)
 				 ICCCM_Iconify(gwins[i]);
 			      }
 			 }
+		       if (gwins)
+			  Efree(gwins);
 		    }
 		  else
 		    {
@@ -2690,12 +2538,10 @@ HandleMouseUp(XEvent * ev)
 			  0, ax, ay;
 
 		       ndesk = desks.current;
-		       nx =
-			  (int)ev->xbutton.x_root -
+		       nx = (int)ev->xbutton.x_root -
 			  desks.desk[desks.current].x -
 			  ((int)p->hi_ewin->w / 2);
-		       ny =
-			  (int)ev->xbutton.y_root -
+		       ny = (int)ev->xbutton.y_root -
 			  desks.desk[desks.current].y -
 			  ((int)p->hi_ewin->h / 2);
 		       GetAreaSize(&ax, &ay);
@@ -2723,11 +2569,9 @@ HandleMouseUp(XEvent * ev)
 			    if (!gwins[i]->sticky)
 			       MoveEwinToDesktop(gwins[i], ndesk);
 			 }
+		       if (gwins)
+			  Efree(gwins);
 		    }
-		  RedrawPagersForDesktop(p->hi_ewin->desktop, 3);
-		  ForceUpdatePagersForDesktop(p->hi_ewin->desktop);
-		  p->hi_visible = 1;
-		  PagerHideHi(p);
 	       }
 	     else if ((ev->xbutton.x >= 0) && (ev->xbutton.y >= 0)
 		      && (ev->xbutton.x < p->w) && (ev->xbutton.y < p->h))
@@ -2742,6 +2586,13 @@ HandleMouseUp(XEvent * ev)
 		       FocusToEWin(ewin);
 		    }
 	       }
+	     if (p->hi_ewin)
+	       {
+		  RedrawPagersForDesktop(p->hi_ewin->desktop, 3);
+		  ForceUpdatePagersForDesktop(p->hi_ewin->desktop);
+		  p->hi_visible = 1;
+		  PagerHideHi(p);
+	       }
 	     mode.mode = MODE_NONE;
 	     mode.context_pager = NULL;
 	  }
@@ -2986,7 +2837,8 @@ HandleMouseIn(XEvent * ev)
 		else if (di->type == DITEM_RADIOBUTTON)
 		  {
 		     if (di->item.radio_button.event_func)
-			(di->item.radio_button.event_func) (di->item.radio_button.val,
+			(di->item.radio_button.event_func) (di->item.
+							    radio_button.val,
 							    ev);
 		  }
 		di->hilited = 1;
@@ -3112,7 +2964,8 @@ HandleMouseOut(XEvent * ev)
 		else if (di->type == DITEM_RADIOBUTTON)
 		  {
 		     if (di->item.radio_button.event_func)
-			(di->item.radio_button.event_func) (di->item.radio_button.val,
+			(di->item.radio_button.event_func) (di->item.
+							    radio_button.val,
 							    NULL);
 		  }
 		di->hilited = 0;
