@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -263,22 +263,19 @@ cp(char *s, char *ss)
    EDBUG_RETURN_;
 }
 
-time_t moddate(char *s)
+time_t
+moddate(char *s)
 {
    struct stat         st;
 
    EDBUG(9, "moddate");
    if ((!s) || (!*s))
       EDBUG_RETURN(0);
-   if (!stat(s, &st) < 0)
+   if (stat(s, &st) < 0)
       EDBUG_RETURN(0);
    if (st.st_mtime > st.st_ctime)
-     {
-	EDBUG_RETURN(st.st_mtime);
-     }
-   else
-      EDBUG_RETURN(st.st_ctime);
-   EDBUG_RETURN(0);
+      EDBUG_RETURN(st.st_mtime);
+   EDBUG_RETURN(st.st_ctime);
 }
 
 int
@@ -354,7 +351,7 @@ permissions(char *s)
    EDBUG(9, "permissions");
    if ((!s) || (!*s))
       EDBUG_RETURN(0);
-   if (!stat(s, &st) < 0)
+   if (stat(s, &st) < 0)
       EDBUG_RETURN(0);
    EDBUG_RETURN(st.st_mode);
 }
@@ -367,7 +364,7 @@ owner(char *s)
    EDBUG(9, "owner");
    if ((!s) || (!*s))
       EDBUG_RETURN(0);
-   if (!stat(s, &st) < 0)
+   if (stat(s, &st) < 0)
       EDBUG_RETURN(0);
    EDBUG_RETURN(st.st_uid);
 }
@@ -380,7 +377,7 @@ group(char *s)
    EDBUG(9, "group");
    if ((!s) || (!*s))
       EDBUG_RETURN(0);
-   if (!stat(s, &st) < 0)
+   if (stat(s, &st) < 0)
       EDBUG_RETURN(0);
    EDBUG_RETURN(st.st_gid);
 }
