@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -155,8 +155,8 @@ FindActionClass(Window win)
 
 	if (win == desks.desk[i].win)
 	  {
-	     ac =
-		FindItem("DESKBINDINGS", 0, LIST_FINDBY_NAME, LIST_TYPE_ACLASS);
+	     ac = FindItem("DESKBINDINGS", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ACLASS);
 	     EDBUG_RETURN(ac);
 	  }
      }
