@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -25,6 +25,8 @@
 static void         ReverseTimeout(int val, void *data);
 static void         AutoraiseTimeout(int val, void *data);
 
+static int          new_desk_focus_nesting = 0;
+
 /* Mostly stolen from the temporary 'ToolTipTimeout' */
 static void
 AutoraiseTimeout(int val, void *data)
@@ -72,12 +74,8 @@ GetNextFocusEwin(void)
 	for (i = 0; i < num0; i++)
 	  {
 	     ewin = lst0[i];
-	     if (((ewin->sticky) || (ewin->desktop == desks.current))
-		 && ((ewin->area_x == ax) && (ewin->area_y == ay))
-		 && (!ewin->skipfocus) && (!ewin->neverfocus)
-		 && (!ewin->iconified) && (!ewin->menu) && (!ewin->pager)
-		 && (!ewin->ibox) && (!ewin->iconified)	/*&& (ewin->client.mwm_decor_title) &&
-							 * * * * (ewin->client.mwm_decor_border) */
+	     if (((ewin->sticky) || (ewin->desktop == desks.current)) && ((ewin->area_x == ax) && (ewin->area_y == ay)) && (!ewin->skipfocus) && (!ewin->neverfocus) && (!ewin->iconified) && (!ewin->menu) && (!ewin->pager) && (!ewin->ibox) && (!ewin->iconified)	/*&& (ewin->client.mwm_decor_title) &&
+																																	 * * * * (ewin->client.mwm_decor_border) */
 		)
 	       {
 		  num++;
@@ -261,8 +259,6 @@ FocusToEWin(EWin * ewin)
      {
 	if (!mode.cur_menu_mode)
 	   mode.context_ewin = ewin;
-	if (mode.kde_support)
-	   KDE_UpdateFocusedWindow();
 	EDBUG_RETURN_;
      }
    /* Never focus a window that's not on the current desktop.  That's just dumb. -- mej */
@@ -282,8 +278,6 @@ FocusToEWin(EWin * ewin)
 	  }
 	if (!mode.cur_menu_mode)
 	   mode.context_ewin = ewin;
-	if (mode.kde_support)
-	   KDE_UpdateFocusedWindow();
 	EDBUG_RETURN_;
      }
    mode.windowdestroy = 0;
@@ -302,12 +296,10 @@ FocusToEWin(EWin * ewin)
      }
    if (!ewin)
      {
-	XSetInputFocus(disp, root.win, RevertToPointerRoot, CurrentTime);
 	mode.focuswin = NULL;
 	mode.realfocuswin = NULL;
 	mode.context_ewin = NULL;
-	if (mode.kde_support)
-	   KDE_UpdateFocusedWindow();
+	ICCCM_Focus(NULL);
 	EDBUG_RETURN_;
      }
    else if (!ewin->menu)
@@ -364,8 +356,6 @@ FocusToEWin(EWin * ewin)
    if (mode.focuswin)
       DoIn("REVERSE_FOCUS_TIMEOUT", 0.5, ReverseTimeout,
 	   mode.focuswin->client.win, NULL);
-   if (mode.kde_support)
-      KDE_UpdateFocusedWindow();
    EDBUG_RETURN_;
 }
 
@@ -375,8 +365,11 @@ BeginNewDeskFocus(void)
    EWin               *ewin, **lst;
    int                 i, j, num;
 
+   if (new_desk_focus_nesting++)
+      return;
+
    /* we are about to flip desktops or areas - disable enter and leave events
-    * temproarily */
+    * temporarily */
 
    lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
    if (lst)
@@ -417,6 +410,7 @@ BeginNewDeskFocus(void)
 	  }
 	Efree(lst);
      }
+
    for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
       XSelectInput(disp, desks.desk[i].win,
 		   PropertyChangeMask | SubstructureRedirectMask |
@@ -431,7 +425,10 @@ NewDeskFocus(void)
 
    EDBUG(4, "NewDeskFocus");
 
-   /* we flipped - re-enable ener and leave events */
+   if (--new_desk_focus_nesting)
+      return;
+
+   /* we flipped - re-enable enter and leave events */
    lst = (EWin **) ListItemType(&num, LIST_TYPE_EWIN);
    if (lst)
      {
@@ -481,6 +478,7 @@ NewDeskFocus(void)
 	  }
 	Efree(lst);
      }
+
    for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
       XSelectInput(disp, desks.desk[i].win,
 		   SubstructureNotifyMask | ButtonPressMask |
@@ -488,6 +486,7 @@ NewDeskFocus(void)
 		   ButtonMotionMask | PropertyChangeMask |
 		   SubstructureRedirectMask | KeyPressMask | KeyReleaseMask |
 		   PointerMotionMask);
+
    if ((mode.focusmode == FOCUS_POINTER) || (mode.focusmode == FOCUS_SLOPPY))
      {
 	ewin = GetEwinPointerInClient();
@@ -514,16 +513,17 @@ NewDeskFocus(void)
 		       && (ewin->desktop == desks.current)))
 		    {
 		       ICCCM_Focus(ewin);
-		       Efree(lst);
-		       EDBUG_RETURN_;
+		       break;
 		    }
 	       }
 	     Efree(lst);
 	  }
      }
+
    EDBUG_RETURN_;
 }
 
+#if 0				/* Clean up if OK -- Remove FocusToNone */
 void
 FocusToNone(void)
 {
@@ -551,3 +551,4 @@ FocusToNone(void)
    mode.realfocuswin = NULL;
    EDBUG_RETURN_;
 }
+#endif
