@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -22,14 +22,24 @@
  */
 #include "E.h"
 
+const char          e_wm_name[] = "Enlightenment";
+const char          e_wm_version[] =
+#ifdef ENLIGHTENMENT_RELEASE
+   "enlightenment-" ENLIGHTENMENT_VERSION "-" ENLIGHTENMENT_RELEASE;
+#else
+   "enlightenment-" ENLIGHTENMENT_VERSION;
+#endif
 pid_t               master_pid;
 int                 master_screen;
 int                 display_screens;
 int                 single_screen_mode;
 Display            *disp;
-ImlibData          *id;
-ImlibData          *ird;
-FnlibData          *fd;
+ImlibData          *pImlibData;
+ImlibData          *prImlibData;
+
+#if USE_FNLIB
+FnlibData          *pFnlibData;
+#endif
 List               *lists;
 int                 event_base_shape;
 Window              comms_win;
@@ -49,13 +59,11 @@ char                themename[FILEPATH_LEN_MAX];
 char               *command;
 char                mustdel;
 char                queue_up;
-char                just_flipped = 0;
 Menu               *all_task_menu = NULL;
 Menu               *task_menu[ENLIGHTENMENT_CONF_NUM_DESKTOPS];
 Menu               *desk_menu = NULL;
 Menu               *group_menu = NULL;
 char                no_overwrite = 0;
-Window              external_pager_window = 0;
 char                clickmenu = 0;
 Window              last_bpress = 0;
 int                 child_count = 0;
@@ -69,7 +77,9 @@ char               *badtheme = NULL;
 char               *badreason = NULL;
 char               *e_machine_name = NULL;
 
-#ifdef HAS_XINERAMA
-char                xinerama_active;
-
+#ifdef DEBUG
+int                 call_level;
+int                 debug_level;
+char               *call_stack[1024];
 #endif
+int                 debug_flags = 0;
