@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -518,10 +518,12 @@ GNOME_GetExpandedSize(EWin * ewin, Atom atom_change)
    retval = AtomGet(ewin->client.win, atom_get, XA_CARDINAL, &size);
    if (retval)
      {
+#if 0				/* Not actually used */
 	ewin->expanded_x = retval[0];
 	ewin->expanded_y = retval[1];
 	ewin->expanded_width = retval[2];
 	ewin->expanded_height = retval[3];
+#endif
 	Efree(retval);
      }
    EDBUG_RETURN_;
@@ -581,27 +583,24 @@ GNOME_SetCurrentDesk(void)
    val = (CARD32) desks.current;
    XChangeProperty(disp, root.win, atom_set, XA_CARDINAL, 32, PropModeReplace,
 		   (unsigned char *)&val, 1);
-   GNOME_SetCurrentArea();
    EDBUG_RETURN_;
 }
 
-void
-GNOME_SetWMCheck(void)
+static void
+GNOME_SetWMCheck(Window win_wm_check)
 {
    static Atom         atom_set = 0;
    CARD32              val;
-   Window              win;
 
    EDBUG(6, "GNOME_SetWMCheck");
 
    if (!atom_set)
       atom_set = XInternAtom(disp, XA_WIN_SUPPORTING_WM_CHECK, False);
-   win = ECreateWindow(root.win, -200, -200, 5, 5, 0);
-   val = win;
-   XChangeProperty(disp, root.win, atom_set, XA_CARDINAL, 32, PropModeReplace,
-		   (unsigned char *)&val, 1);
-   XChangeProperty(disp, win, atom_set, XA_CARDINAL, 32, PropModeReplace,
-		   (unsigned char *)&val, 1);
+   val = win_wm_check;
+   XChangeProperty(disp, root.win, atom_set, XA_CARDINAL,
+		   32, PropModeReplace, (unsigned char *)&val, 1);
+   XChangeProperty(disp, win_wm_check, atom_set, XA_CARDINAL,
+		   32, PropModeReplace, (unsigned char *)&val, 1);
    EDBUG_RETURN_;
 }
 
@@ -698,18 +697,17 @@ GNOME_SetClientList(void)
    EDBUG_RETURN_;
 }
 
-void
+static void
 GNOME_SetWMNameVer(void)
 {
    static Atom         atom_set = 0, atom_set2 = 0;
-   const char         *wm_name = "Enlightenment";
    const char         *wm_version = ENLIGHTENMENT_VERSION;
 
    EDBUG(6, "GNOME_SetWMNameVer");
    if (!atom_set)
       atom_set = XInternAtom(disp, XA_WIN_WM_NAME, False);
    XChangeProperty(disp, root.win, atom_set, XA_STRING, 8, PropModeReplace,
-		   (unsigned char *)wm_name, strlen(wm_name));
+		   (unsigned char *)e_wm_name, strlen(e_wm_name));
    if (!atom_set2)
       atom_set2 = XInternAtom(disp, XA_WIN_WM_VERSION, False);
    XChangeProperty(disp, root.win, atom_set2, XA_STRING, 8, PropModeReplace,
@@ -758,7 +756,7 @@ GNOME_GetHints(EWin * ewin, Atom atom_change)
 }
 
 void
-GNOME_SetHints(void)
+GNOME_SetHints(Window win_wm_check)
 {
    EDBUG(6, "GNOME_SetHints");
    GNOME_SetWMNameVer();
@@ -766,6 +764,116 @@ GNOME_SetHints(void)
    GNOME_SetDeskCount();
    GNOME_SetDeskNames();
    GNOME_SetAreaCount();
-   GNOME_SetWMCheck();
+   GNOME_SetWMCheck(win_wm_check);
+   {
+      Atom                atom_set;
+      CARD32              val;
+
+      atom_set = XInternAtom(disp, "_WIN_DESKTOP_BUTTON_PROXY", False);
+      bpress_win = ECreateWindow(root.win, -80, -80, 24, 24, 0);
+      val = bpress_win;
+      XChangeProperty(disp, root.win, atom_set, XA_CARDINAL, 32,
+		      PropModeReplace, (unsigned char *)&val, 1);
+      XChangeProperty(disp, bpress_win, atom_set, XA_CARDINAL, 32,
+		      PropModeReplace, (unsigned char *)&val, 1);
+   }
+
    EDBUG_RETURN_;
 }
+
+void
+GNOME_ProcessClientMessage(XClientMessageEvent * event)
+{
+   static Atom         a2 = 0, a3 = 0, a4 = 0, a5 = 0;
+
+   EWin               *ewin;
+
+   if (!a2)
+      a2 = XInternAtom(disp, "_WIN_AREA", False);
+   if (!a3)
+      a3 = XInternAtom(disp, "_WIN_WORKSPACE", False);
+   if (!a4)
+      a4 = XInternAtom(disp, "_WIN_LAYER", False);
+   if (!a5)
+      a5 = XInternAtom(disp, "_WIN_STATE", False);
+
+   if (event->message_type == a2)
+     {
+	SetCurrentArea(event->data.l[0], event->data.l[1]);
+	EDBUG_RETURN_;
+     }
+   if (event->message_type == a3)
+     {
+	GotoDesktop(event->data.l[0]);
+	EDBUG_RETURN_;
+     }
+   if (event->message_type == a4)
+     {
+	ewin = FindItem(NULL, event->window, LIST_FINDBY_ID, LIST_TYPE_EWIN);
+	if (ewin)
+	  {
+	     ewin->layer = event->data.l[0];
+	     XChangeProperty(disp, ewin->win, a4, XA_CARDINAL, 32,
+			     PropModeReplace,
+			     (unsigned char *)(&(event->data.l[0])), 1);
+	     RaiseEwin(ewin);
+	  }
+	EDBUG_RETURN_;
+     }
+   if (event->message_type == a5)
+     {
+	ewin = FindItem(NULL, event->window, LIST_FINDBY_ID, LIST_TYPE_EWIN);
+	if (!ewin)
+	   EDBUG_RETURN_;
+	if (event->data.l[0] & WIN_STATE_FIXED_POSITION)
+	  {
+	     if (event->data.l[1] & WIN_STATE_FIXED_POSITION)
+		ewin->fixedpos = 1;
+	     else
+		ewin->fixedpos = 0;
+	  }
+	if (event->data.l[0] & WIN_STATE_ARRANGE_IGNORE)
+	  {
+	     if (event->data.l[1] & WIN_STATE_ARRANGE_IGNORE)
+		ewin->ignorearrange = 1;
+	     else
+		ewin->ignorearrange = 0;
+	  }
+	if ((event->data.l[0] & WIN_STATE_STICKY) && (!ewin->ignorearrange))
+	  {
+	     if (event->data.l[1] & WIN_STATE_STICKY)
+	       {
+		  if (!(ewin->sticky))
+		    {
+		       ewin->sticky = 1;
+		       RaiseEwin(ewin);
+		       DrawEwin(ewin);
+		       ApplySclass(FindItem
+				   ("SOUND_WINDOW_STICK", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_SCLASS));
+		    }
+	       }
+	     else
+	       {
+		  if (ewin->sticky)
+		    {
+		       ewin->sticky = 0;
+		       RaiseEwin(ewin);
+		       DrawEwin(ewin);
+		       ApplySclass(FindItem
+				   ("SOUND_WINDOW_UNSTICK", 0, LIST_FINDBY_NAME,
+				    LIST_TYPE_SCLASS));
+		    }
+	       }
+	  }
+	if (event->data.l[0] & WIN_STATE_SHADED)
+	  {
+	     if (event->data.l[1] & WIN_STATE_SHADED)
+		ShadeEwin(ewin);
+	     else
+		UnShadeEwin(ewin);
+	  }
+	HintsSetWindowState(ewin);
+	EDBUG_RETURN_;
+     }
+}
