@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -242,22 +242,16 @@ RemoveEwinFromGroup(EWin * ewin, Group * g)
 				 if ((ewin->x + ewin->border->border.left + 1) >
 				     root.w)
 				    x = root.w - ewin->border->border.left - 1;
-				 else
-				    if (
-					(ewin->x + ewin->w -
-					 ewin->border->border.right - 1) < 0)
-				    x =
-				       0 - ewin->w +
+				 else if ((ewin->x + ewin->w -
+					   ewin->border->border.right - 1) < 0)
+				    x = 0 - ewin->w +
 				       ewin->border->border.right + 1;
 				 if ((ewin->y + ewin->border->border.top + 1) >
 				     root.h)
 				    y = root.h - ewin->border->border.top - 1;
-				 else
-				    if (
-					(ewin->y + ewin->h -
-					 ewin->border->border.bottom - 1) < 0)
-				    y =
-				       0 - ewin->h +
+				 else if ((ewin->y + ewin->h -
+					   ewin->border->border.bottom - 1) < 0)
+				    y = 0 - ewin->h +
 				       ewin->border->border.bottom + 1;
 
 				 MoveEwin(ewin, x, y);
@@ -325,9 +319,9 @@ ShowHideWinGroups(EWin * ewin, Group * g, char onoff)
 		  if (!gwins[i]->border->group_border_name)
 		     continue;
 
-		  b =
-		     (Border *) FindItem(gwins[i]->border->group_border_name, 0,
-					 LIST_FINDBY_NAME, LIST_TYPE_BORDER);
+		  b = (Border *) FindItem(gwins[i]->border->group_border_name,
+					  0, LIST_FINDBY_NAME,
+					  LIST_TYPE_BORDER);
 		  if (b)
 		    {
 		       gwins[i]->previous_border = gwins[i]->border;
@@ -347,9 +341,9 @@ ShowHideWinGroups(EWin * ewin, Group * g, char onoff)
 		  if (!gwins[i]->border->group_border_name)
 		     continue;
 
-		  b =
-		     (Border *) FindItem(gwins[i]->border->group_border_name, 0,
-					 LIST_FINDBY_NAME, LIST_TYPE_BORDER);
+		  b = (Border *) FindItem(gwins[i]->border->group_border_name,
+					  0, LIST_FINDBY_NAME,
+					  LIST_TYPE_BORDER);
 		  if (b)
 		    {
 		       gwins[i]->previous_border = gwins[i]->border;
