@@ -1,6 +1,5 @@
-
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -23,6 +22,45 @@
  */
 #include "E.h"
 
+static Atom         E_XA_WM_STATE = 0;
+static Atom         E_XA_WM_CHANGE_STATE = 0;
+
+void
+ICCCM_Init(void)
+{
+   E_XA_WM_STATE = XInternAtom(disp, "WM_STATE", False);
+   E_XA_WM_CHANGE_STATE = XInternAtom(disp, "WM_CHANGE_STATE", False);
+}
+
+void
+ICCCM_ProcessClientMessage(XClientMessageEvent * event)
+{
+   EWin               *ewin;
+
+   if (event->message_type == E_XA_WM_CHANGE_STATE)
+     {
+	ewin = FindItem(NULL, event->window, LIST_FINDBY_ID, LIST_TYPE_EWIN);
+	if (ewin == NULL)
+	   goto exit;
+
+	if (event->data.l[0] == IconicState)
+	  {
+	     if (!(ewin->iconified))
+		IconifyEwin(ewin);
+	  }
+#if 0
+	else if (event->data.l[0] == NormalState)
+	  {
+	     if (ewin->iconified)
+		DeIconifyEwin(ewin);
+	  }
+	HintsSetWindowState(ewin);
+#endif
+     }
+ exit:
+   EDBUG_RETURN_;
+}
+
 void
 ICCCM_GetTitle(EWin * ewin, Atom atom_change)
 {
@@ -207,18 +245,13 @@ ICCCM_Save(EWin * ewin)
 void
 ICCCM_Iconify(EWin * ewin)
 {
-   static Atom         a = 0;
-   unsigned long       c[2];
+   unsigned long       c[2] = { IconicState, 0 };
 
    EDBUG(6, "ICCCM_Iconify");
    if (!ewin)
       EDBUG_RETURN_;
-   if (!a)
-      a = XInternAtom(disp, "WM_STATE", False);
-   c[0] = IconicState;
-   c[1] = 0;
-   XChangeProperty(disp, ewin->client.win, a, a, 32, PropModeReplace,
-		   (unsigned char *)c, 2);
+   XChangeProperty(disp, ewin->client.win, E_XA_WM_STATE, E_XA_WM_STATE,
+		   32, PropModeReplace, (unsigned char *)c, 2);
    ewin->iconified = 3;
    AddItem(ewin, "ICON", ewin->client.win, LIST_TYPE_ICONIFIEDS);
    EUnmapWindow(disp, ewin->client.win);
@@ -228,19 +261,14 @@ ICCCM_Iconify(EWin * ewin)
 void
 ICCCM_DeIconify(EWin * ewin)
 {
-   static Atom         a;
-   unsigned long       c[2];
+   unsigned long       c[2] = { NormalState, 0 };
 
    EDBUG(6, "ICCCM_DeIconify");
    if (!ewin)
       EDBUG_RETURN_;
-   if (!a)
-      a = XInternAtom(disp, "WM_STATE", False);
-   c[0] = NormalState;
-   c[1] = 0;
    ewin->iconified = 0;
-   XChangeProperty(disp, ewin->client.win, a, a, 32, PropModeReplace,
-		   (unsigned char *)c, 2);
+   XChangeProperty(disp, ewin->client.win, E_XA_WM_STATE, E_XA_WM_STATE,
+		   32, PropModeReplace, (unsigned char *)c, 2);
    RemoveItem("ICON", ewin->client.win, LIST_FINDBY_BOTH, LIST_TYPE_ICONIFIEDS);
    EMapWindow(disp, ewin->client.win);
    EDBUG_RETURN_;
@@ -359,28 +387,26 @@ ICCCM_Configure(EWin * ewin)
 }
 
 void
-ICCCM_AdoptStart(EWin * ewin, Window win)
+ICCCM_AdoptStart(EWin * ewin)
 {
+   Window              win = ewin->client.win;
+
    EDBUG(6, "ICCCM_AdoptStart");
    if (!ewin->internal)
-     {
-	XAddToSaveSet(disp, win);
-     }
+      XAddToSaveSet(disp, win);
    EDBUG_RETURN_;
 }
 
 void
-ICCCM_Adopt(EWin * ewin, Window win)
+ICCCM_Adopt(EWin * ewin)
 {
-   static Atom         a = 0;
-   unsigned long       c[2];
+   Window              win = ewin->client.win;
+   unsigned long       c[2] = { 0, 0 };
    XWindowAttributes   att;
 
    EDBUG(6, "ICCCM_Adopt");
    if (!ewin->internal)
-     {
-	XSetWindowBorderWidth(disp, win, 0);
-     }
+      XSetWindowBorderWidth(disp, win, 0);
    EReparentWindow(disp, win, ewin->win_container, 0, 0);
    XGetWindowAttributes(disp, win, &att);
    XSelectInput(disp, win,
@@ -388,18 +414,9 @@ ICCCM_Adopt(EWin * ewin, Window win)
 		LeaveWindowMask | FocusChangeMask | ResizeRedirectMask |
 		StructureNotifyMask | ColormapChangeMask);
    XShapeSelectInput(disp, win, ShapeNotifyMask);
-   if (!a)
-      a = XInternAtom(disp, "WM_STATE", False);
-   if (ewin->client.start_iconified)
-     {
-	c[0] = IconicState;
-     }
-   else
-     {
-	c[0] = NormalState;
-     }
-   c[1] = 0;
-   XChangeProperty(disp, win, a, a, 32, PropModeReplace, (unsigned char *)c, 2);
+   c[0] = (ewin->client.start_iconified) ? IconicState : NormalState;
+   XChangeProperty(disp, win, E_XA_WM_STATE, E_XA_WM_STATE, 32, PropModeReplace,
+		   (unsigned char *)c, 2);
    ewin->x = ewin->client.x;
    ewin->y = ewin->client.y;
    ewin->reqx = ewin->client.x;
@@ -414,23 +431,18 @@ ICCCM_Adopt(EWin * ewin, Window win)
 void
 ICCCM_Withdraw(EWin * ewin)
 {
-   static Atom         a = 0;
-   unsigned long       c[2];
+   unsigned long       c[2] = { WithdrawnState, 0 };
 
    EDBUG(6, "ICCCM_Withdraw");
    if (!ewin)
       EDBUG_RETURN_;
-   if (!a)
-      a = XInternAtom(disp, "WM_STATE", False);
-
    /* We have a choice of deleting the WM_STATE property
     * or changing the value to Withdrawn. Since twm/fvwm does
     * it that way, we change it to Withdrawn.
     */
-   c[0] = WithdrawnState;
-   c[1] = 0;
-   XChangeProperty(disp, ewin->client.win, a, a, 32, PropModeReplace,
-		   (unsigned char *)c, 2);
+   XChangeProperty(disp, ewin->client.win, E_XA_WM_STATE, E_XA_WM_STATE,
+		   32, PropModeReplace, (unsigned char *)c, 2);
+   XRemoveFromSaveSet(disp, ewin->client.win);
    EDBUG_RETURN_;
 }
 
@@ -508,6 +520,7 @@ ICCCM_Focus(EWin * ewin)
    if (!ewin)
      {
 	XSetInputFocus(disp, root.win, RevertToPointerRoot, CurrentTime);
+	HintsSetActiveWindow(ewin);
 	EDBUG_RETURN_;
      }
    if (ewin->menu)
@@ -543,6 +556,7 @@ ICCCM_Focus(EWin * ewin)
      }
 /*   else */
    XSetInputFocus(disp, ewin->client.win, RevertToPointerRoot, CurrentTime);
+   HintsSetActiveWindow(ewin);
    EDBUG_RETURN_;
 }
 
@@ -1378,9 +1392,8 @@ ICCCM_GetEInfo(EWin * ewin)
 	       {
 		  Border             *b = NULL;
 
-		  b =
-		     (Border *) FindItem(str, 0, LIST_FINDBY_NAME,
-					 LIST_TYPE_BORDER);
+		  b = (Border *) FindItem(str, 0, LIST_FINDBY_NAME,
+					  LIST_TYPE_BORDER);
 		  if ((ewin->border) && (strcmp(ewin->border->name, b->name)))
 		     b = NULL;
 		  if (b)
