@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -42,12 +42,13 @@ IB_Animate(char iconify, EWin * from, EWin * to)
    spd = 0.00001;
    gcv.subwindow_mode = IncludeInferiors;
    gcv.function = GXxor;
+   gcv.fill_style = FillOpaqueStippled;
    gcv.foreground = WhitePixel(disp, root.scr);
    if (gcv.foreground == 0)
       gcv.foreground = BlackPixel(disp, root.scr);
-   gc =
-      XCreateGC(disp, root.win, GCFunction | GCForeground | GCSubwindowMode,
-		&gcv);
+   gc = XCreateGC(disp, root.win,
+		  GCFunction | GCForeground | GCSubwindowMode | GCFillStyle,
+		  &gcv);
    t1 = GetTime();
    if (iconify)
      {
@@ -226,11 +227,6 @@ IconifyEwin(EWin * ewin)
 	     UpdateAppIcon(ewin, ib->icon_mode);
 	  }
 	HideEwin(ewin);
-	MoveEwin(ewin,
-		 ewin->x + ((desks.desk[ewin->desktop].current_area_x) -
-			    ewin->area_x) * root.w,
-		 ewin->y + ((desks.desk[ewin->desktop].current_area_y) -
-			    ewin->area_y) * root.h);
 	if (was_shaded != ewin->shaded)
 	   InstantShadeEwin(ewin);
 	MakeIcon(ewin);
@@ -257,28 +253,19 @@ IconifyEwin(EWin * ewin)
 		       if (!lst[i]->iconified)
 			 {
 			    HideEwin(lst[i]);
-			    MoveEwin(lst[i],
-				     lst[i]->x +
-				     ((desks.desk
-				       [lst[i]->desktop].current_area_x) -
-				      lst[i]->area_x) * root.w,
-				     lst[i]->y +
-				     ((desks.desk
-				       [lst[i]->desktop].current_area_y) -
-				      lst[i]->area_y) * root.h);
 			    lst[i]->iconified = 4;
 			    if (lst[i] == mode.focuswin)
 			       FocusToEWin(NULL);
 			 }
 		    }
-		  GNOME_SetClientList();
+		  HintsSetClientList();
 		  Efree(lst);
 	       }
 	  }
      }
    call_depth--;
 
-   KDE_UpdateClient(ewin);
+   HintsSetWindowState(ewin);
    EDBUG_RETURN_;
 }
 
@@ -287,6 +274,7 @@ DeIconifyEwin(EWin * ewin)
 {
    static int          call_depth = 0;
    Iconbox            *ib;
+   int                 x, y, dx, dy;
 
    EDBUG(6, "DeIconifyEwin");
    call_depth++;
@@ -299,14 +287,26 @@ DeIconifyEwin(EWin * ewin)
      {
 	ib = SelectIconboxForEwin(ewin);
 	RemoveMiniIcon(ewin);
+
+	dx = ewin->w / 2;
+	dy = ewin->h / 2;
+	x = (ewin->x + dx) % root.w;
+	if (x < 0)
+	   x += root.w;
+	x -= dx;
+	y = (ewin->y + dy) % root.h;
+	if (y < 0)
+	   y += root.h;
+	y -= dy;
+
+	dx = x - ewin->x;
+	dy = y - ewin->y;
+
 	if (!ewin->sticky)
-	  {
-	     MoveEwinToDesktopAt(ewin, desks.current, ewin->x, ewin->y);
-	     ewin->area_x = desks.desk[desks.current].current_area_x;
-	     ewin->area_y = desks.desk[desks.current].current_area_y;
-	  }
+	   MoveEwinToDesktopAt(ewin, desks.current, ewin->x + dx, ewin->y + dy);
 	else
-	   ConformEwinToDesktop(ewin);
+	   MoveEwin(ewin, ewin->x + dx, ewin->y + dy);
+
 	AUDIO_PLAY("SOUND_DEICONIFY");
 	if (ib)
 	  {
@@ -320,7 +320,7 @@ DeIconifyEwin(EWin * ewin)
 	mode.destroy = 1;
 	if (ewin->has_transients)
 	  {
-	     EWin              **lst;
+	     EWin              **lst, *e;
 	     int                 i, num;
 
 	     lst = ListTransientsFor(ewin->client.win, &num);
@@ -328,34 +328,29 @@ DeIconifyEwin(EWin * ewin)
 	       {
 		  for (i = 0; i < num; i++)
 		    {
-		       if (lst[i]->iconified == 4)
-			 {
-			    if (!lst[i]->sticky)
-			      {
-				 MoveEwinToDesktopAt(lst[i], desks.current,
-						     lst[i]->x, lst[i]->y);
-				 lst[i]->area_x =
-				    desks.desk[desks.current].current_area_x;
-				 lst[i]->area_y =
-				    desks.desk[desks.current].current_area_y;
-			      }
-			    else
-			       ConformEwinToDesktop(lst[i]);
-			    RaiseEwin(lst[i]);
-			    ShowEwin(lst[i]);
-			    lst[i]->iconified = 0;
-			 }
+		       e = lst[i];
+
+		       if (e->iconified != 4)
+			  continue;
+
+		       if (!e->sticky)
+			  MoveEwinToDesktopAt(e, desks.current,
+					      e->x + dx, e->y + dy);
+		       else
+			  MoveEwin(e, e->x + dx, e->y + dy);
+		       RaiseEwin(e);
+		       ShowEwin(e);
+		       e->iconified = 0;
 		    }
-		  GNOME_SetClientList();
+		  HintsSetClientList();
 		  Efree(lst);
 	       }
 	  }
      }
    call_depth--;
 
-   KDE_UpdateClient(ewin);
+   HintsSetWindowState(ewin);
    EDBUG_RETURN_;
-
 }
 
 void
@@ -378,25 +373,6 @@ RemoveMiniIcon(EWin * ewin)
       DelEwinFromIconbox(ib, ewin);
 }
 
-void
-HideIcons(void)
-{
-   /* ummmmmmmmmm don't need this anymore - but it used to hide the icons */
-   /* when a the gnome pager came up */
-}
-
-void
-ShowIcons(void)
-{
-   /* ummmmmmmmmm don't need this anymore - but it used to show the icons */
-   /* when a the gnome pager came up */
-}
-
-void
-HandlePager(void)
-{
-}
-
 Iconbox            *
 CreateIconbox(char *name)
 {
@@ -443,7 +419,7 @@ CreateIconbox(char *name)
    ib->arrow2_win = ECreateWindow(ib->win, 122, 26, 6, 6, 0);
    ib->scrollbar_win = ECreateWindow(ib->scroll_win, 122, 26, 6, 6, 0);
    ib->scrollbarknob_win = ECreateWindow(ib->scrollbar_win, -20, -20, 4, 4, 0);
-   ib->pmap = ECreatePixmap(disp, ib->icon_win, 128, 32, id->x.depth);
+   ib->pmap = ECreatePixmap(disp, ib->icon_win, 128, 32, pImlibData->x.depth);
    XSelectInput(disp, ib->icon_win,
 		EnterWindowMask | LeaveWindowMask | ButtonPressMask |
 		ButtonReleaseMask | PointerMotionMask);
@@ -515,7 +491,7 @@ ShowIconbox(Iconbox * ib)
    XSetClassHint(disp, ib->win, xch);
    XFree(xch);
    MatchToSnapInfoIconbox(ib);
-   ewin = AddInternalToFamily(ib->win, 1, "ICONBOX", 2, ib);
+   ewin = AddInternalToFamily(ib->win, 1, "ICONBOX", EWIN_TYPE_ICONBOX, ib);
    if (ewin)
      {
 	Snapshot           *sn;
@@ -532,9 +508,8 @@ ShowIconbox(Iconbox * ib)
 	     ImageClass         *ic;
 	     int                 extra = 0;
 
-	     ic =
-		FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     if (ic)
 		extra = ic->padding.left + ic->padding.right;
 	     ib->ewin->client.width.max = ib->ewin->client.width.min =
@@ -546,9 +521,8 @@ ShowIconbox(Iconbox * ib)
 	     ImageClass         *ic;
 	     int                 extra = 0;
 
-	     ic =
-		FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     if (ic)
 		extra = ic->padding.left + ic->padding.right;
 	     ib->ewin->client.height.max = ib->ewin->client.height.min =
@@ -650,9 +624,8 @@ IB_SnapEWin(EWin * ewin)
      }
    if (ib->draw_icon_base)
      {
-	ic =
-	   FindItem("DEFAULT_ICON_BUTTON", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("DEFAULT_ICON_BUTTON", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     w -= ic->padding.left + ic->padding.right;
@@ -669,7 +642,7 @@ IB_SnapEWin(EWin * ewin)
       h = 4;
    ewin->icon_pmap_w = w;
    ewin->icon_pmap_h = h;
-   ewin->icon_pmap = ECreatePixmap(disp, ewin->win, w, h, id->x.depth);
+   ewin->icon_pmap = ECreatePixmap(disp, ewin->win, w, h, pImlibData->x.depth);
    PagerScaleRect(ewin->icon_pmap, ewin->win, 0, 0, 0, 0, ewin->w, ewin->h, w,
 		  h);
    r = EShapeGetRectangles(disp, ewin->win, ShapeBounding, &rn, &ord);
@@ -705,9 +678,9 @@ IB_SnapEWin(EWin * ewin)
    if ((ewin->icon_pmap_w < 1) || (ewin->icon_pmap_h < 1))
      {
 	if (ewin->icon_pmap)
-	   Imlib_free_pixmap(id, ewin->icon_pmap);
+	   Imlib_free_pixmap(pImlibData, ewin->icon_pmap);
 	if (ewin->icon_mask)
-	   Imlib_free_pixmap(id, ewin->icon_mask);
+	   Imlib_free_pixmap(pImlibData, ewin->icon_mask);
 	ewin->icon_pmap = 0;
 	ewin->icon_mask = 0;
      }
@@ -741,14 +714,16 @@ IB_GetAppIcon(EWin * ewin)
 	r = 255;
 	g = 255;
 	b = 255;
-	XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
+	XSetForeground(disp, gc,
+		       Imlib_best_color_match(pImlibData, &r, &g, &b));
 	XFillRectangle(disp, ewin->icon_pmap, gc, 0, 0, w, h);
 	r = 0;
 	g = 0;
 	b = 0;
 	XSetClipOrigin(disp, gc, 0, 0);
 	XSetClipMask(disp, gc, ewin->client.icon_pmap);
-	XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
+	XSetForeground(disp, gc,
+		       Imlib_best_color_match(pImlibData, &r, &g, &b));
 	XFillRectangle(disp, ewin->icon_pmap, gc, 0, 0, w, h);
 	XFreeGC(disp, gc);
      }
@@ -759,9 +734,9 @@ IB_GetAppIcon(EWin * ewin)
    if ((ewin->icon_pmap_w < 1) || (ewin->icon_pmap_h < 1))
      {
 	if (ewin->icon_pmap)
-	   Imlib_free_pixmap(id, ewin->icon_pmap);
+	   Imlib_free_pixmap(pImlibData, ewin->icon_pmap);
 	if (ewin->icon_mask)
-	   Imlib_free_pixmap(id, ewin->icon_mask);
+	   Imlib_free_pixmap(pImlibData, ewin->icon_mask);
 	ewin->icon_pmap = 0;
 	ewin->icon_mask = 0;
      }
@@ -779,8 +754,8 @@ IB_PasteDefaultBase(Drawable d, int x, int y, int w, int h)
       return;
    IclassApplyCopy(ic, d, w, h, 0, 0, STATE_NORMAL, &p, &m);
    PastePixmap(disp, d, p, m, x, y);
-   Imlib_free_pixmap(id, p);
-   Imlib_free_pixmap(id, m);
+   Imlib_free_pixmap(pImlibData, p);
+   Imlib_free_pixmap(pImlibData, m);
 }
 
 void
@@ -799,7 +774,7 @@ IB_PasteDefaultBaseMask(Drawable d, int x, int y, int w, int h)
    if (m)
      {
 	PasteMask(disp, d, m, x, y, w, h);
-	Imlib_free_pixmap(id, m);
+	Imlib_free_pixmap(pImlibData, m);
      }
    else
      {
@@ -808,7 +783,7 @@ IB_PasteDefaultBaseMask(Drawable d, int x, int y, int w, int h)
 	XFillRectangle(disp, d, gc, x, y, w, h);
 	XFreeGC(disp, gc);
      }
-   Imlib_free_pixmap(id, p);
+   Imlib_free_pixmap(pImlibData, p);
 }
 
 void
@@ -842,9 +817,8 @@ IB_GetEIcon(EWin * ewin)
 		mh = ib->iconsize;
 		if (ib->draw_icon_base)
 		  {
-		     ic =
-			FindItem("DEFAULT_ICON_BUTTON", 0, LIST_FINDBY_NAME,
-				 LIST_TYPE_ICLASS);
+		     ic = FindItem("DEFAULT_ICON_BUTTON", 0, LIST_FINDBY_NAME,
+				   LIST_TYPE_ICLASS);
 		     if (ic)
 		       {
 			  mw -= ic->padding.left + ic->padding.right;
@@ -862,12 +836,12 @@ IB_GetEIcon(EWin * ewin)
 		     h = mh;
 		  }
 	     }
-	   Imlib_render(id, im, w, h);
-	   ewin->icon_pmap = Imlib_copy_image(id, im);
-	   ewin->icon_mask = Imlib_copy_mask(id, im);
+	   Imlib_render(pImlibData, im, w, h);
+	   ewin->icon_pmap = Imlib_copy_image(pImlibData, im);
+	   ewin->icon_mask = Imlib_copy_mask(pImlibData, im);
 	   ewin->icon_pmap_w = w;
 	   ewin->icon_pmap_h = h;
-	   Imlib_destroy_image(id, im);
+	   Imlib_destroy_image(pImlibData, im);
 	}
    }
 }
@@ -1144,12 +1118,14 @@ SelectIconboxForEwin(EWin * ewin)
 	       {
 		  int                 dx, dy, dist;
 
-		  dx =
-		     (ib[i]->ewin->x + (ib[i]->ewin->w / 2)) - (ewin->x +
-								(ewin->w / 2));
-		  dy =
-		     (ib[i]->ewin->y + (ib[i]->ewin->h / 2)) - (ewin->y +
-								(ewin->h / 2));
+		  if (ib[i]->ewin == NULL)
+		     continue;
+		  dx = (ib[i]->ewin->x + (ib[i]->ewin->w / 2)) - (ewin->x +
+								  (ewin->w /
+								   2));
+		  dy = (ib[i]->ewin->y + (ib[i]->ewin->h / 2)) - (ewin->y +
+								  (ewin->h /
+								   2));
 		  dist = (dx * dx) + (dy * dy);
 		  if ((!ib[i]->ewin->sticky)
 		      && (ib[i]->ewin->desktop != ewin->desktop))
@@ -1185,9 +1161,9 @@ UpdateAppIcon(EWin * ewin, int imode)
 {
    /* free whatever we had before */
    if (ewin->icon_pmap)
-      Imlib_free_pixmap(id, ewin->icon_pmap);
+      Imlib_free_pixmap(pImlibData, ewin->icon_pmap);
    if (ewin->icon_mask)
-      Imlib_free_pixmap(id, ewin->icon_mask);
+      Imlib_free_pixmap(pImlibData, ewin->icon_mask);
    ewin->icon_pmap = 0;
    ewin->icon_mask = 0;
 
@@ -1287,8 +1263,8 @@ IB_FindIcon(Iconbox * ib, int px, int py)
 
    if (ib->orientation)
      {
-	ic =
-	   FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	y = -ib->pos;
 	x = 0;
 	if (ic)
@@ -1299,9 +1275,8 @@ IB_FindIcon(Iconbox * ib, int px, int py)
      }
    else
      {
-	ic =
-	   FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	x = -ib->pos;
 	y = 0;
 	if (ic)
@@ -1370,9 +1345,8 @@ IB_DrawScroll(Iconbox * ib)
      {
 	int                 bs, bw, bx;
 
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ib->arrow_side < 3)
 	   bs = ib->h - (ib->arrow_thickness * 2);
 	else
@@ -1381,8 +1355,7 @@ IB_DrawScroll(Iconbox * ib)
 	if (ic)
 	  {
 	     bs -= (ic->padding.top + ic->padding.bottom);
-	     bw =
-		((ib->h - (ic->padding.top + ic->padding.bottom)) * bs) /
+	     bw = ((ib->h - (ic->padding.top + ic->padding.bottom)) * bs) /
 		ib->max;
 	  }
 	if (bs < 1)
@@ -1396,9 +1369,8 @@ IB_DrawScroll(Iconbox * ib)
 	   bx += ic->padding.top;
 	if ((ib->scrollbar_hide) && (bw == bs))
 	   show_sb = 0;
-	ic =
-	   FindItem("ICONBOX_SCROLLKNOB_VERTICAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLKNOB_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if ((ic) && (bw > ib->knob_length))
 	   EMoveResizeWindow(disp, ib->scrollbarknob_win, 0,
 			     (bw - ib->knob_length) / 2, ib->bar_thickness,
@@ -1556,14 +1528,12 @@ IB_DrawScroll(Iconbox * ib)
 			  (ib->scroll_thickness - ib->bar_thickness) / 2, bx,
 			  ib->bar_thickness, bw);
 
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	   IclassApply(ic, ib->scroll_win, -1, -1, 0, 0, STATE_NORMAL, 0);
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_KNOB_VERTICAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_KNOB_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1574,9 +1544,8 @@ IB_DrawScroll(Iconbox * ib)
 		state = STATE_CLICKED;
 	     IclassApply(ic, ib->scrollbar_win, -1, -1, 0, 0, state, 0);
 	  }
-	ic =
-	   FindItem("ICONBOX_SCROLLKNOB_VERTICAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLKNOB_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1587,8 +1556,8 @@ IB_DrawScroll(Iconbox * ib)
 		state = STATE_CLICKED;
 	     IclassApply(ic, ib->scrollbarknob_win, -1, -1, 0, 0, state, 0);
 	  }
-	ic =
-	   FindItem("ICONBOX_ARROW_UP", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_ARROW_UP", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1599,9 +1568,8 @@ IB_DrawScroll(Iconbox * ib)
 		state = STATE_CLICKED;
 	     IclassApply(ic, ib->arrow1_win, -1, -1, 0, 0, state, 0);
 	  }
-	ic =
-	   FindItem("ICONBOX_ARROW_DOWN", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_ARROW_DOWN", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1618,9 +1586,8 @@ IB_DrawScroll(Iconbox * ib)
      {
 	int                 bs, bw, bx;
 
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ib->arrow_side < 3)
 	   bs = ib->w - (ib->arrow_thickness * 2);
 	else
@@ -1629,8 +1596,7 @@ IB_DrawScroll(Iconbox * ib)
 	if (ic)
 	  {
 	     bs -= (ic->padding.left + ic->padding.right);
-	     bw =
-		((ib->w - (ic->padding.left + ic->padding.right)) * bs) /
+	     bw = ((ib->w - (ic->padding.left + ic->padding.right)) * bs) /
 		ib->max;
 	  }
 	if (bs < 1)
@@ -1644,9 +1610,8 @@ IB_DrawScroll(Iconbox * ib)
 	   bx += ic->padding.left;
 	if ((ib->scrollbar_hide) && (bw == bs))
 	   show_sb = 0;
-	ic =
-	   FindItem("ICONBOX_SCROLLKNOB_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLKNOB_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if ((ic) && (bw > ib->knob_length))
 	   EMoveResizeWindow(disp, ib->scrollbarknob_win,
 			     (bw - ib->knob_length) / 2, 0, ib->knob_length,
@@ -1805,14 +1770,12 @@ IB_DrawScroll(Iconbox * ib)
 			  (ib->scroll_thickness - ib->bar_thickness) / 2, bw,
 			  ib->bar_thickness);
 
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	   IclassApply(ic, ib->scroll_win, -1, -1, 0, 0, STATE_NORMAL, 0);
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_KNOB_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_KNOB_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1823,9 +1786,8 @@ IB_DrawScroll(Iconbox * ib)
 		state = STATE_CLICKED;
 	     IclassApply(ic, ib->scrollbar_win, -1, -1, 0, 0, state, 0);
 	  }
-	ic =
-	   FindItem("ICONBOX_SCROLLKNOB_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLKNOB_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1836,9 +1798,8 @@ IB_DrawScroll(Iconbox * ib)
 		state = STATE_CLICKED;
 	     IclassApply(ic, ib->scrollbarknob_win, -1, -1, 0, 0, state, 0);
 	  }
-	ic =
-	   FindItem("ICONBOX_ARROW_LEFT", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_ARROW_LEFT", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1849,9 +1810,8 @@ IB_DrawScroll(Iconbox * ib)
 		state = STATE_CLICKED;
 	     IclassApply(ic, ib->arrow1_win, -1, -1, 0, 0, state, 0);
 	  }
-	ic =
-	   FindItem("ICONBOX_ARROW_RIGHT", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_ARROW_RIGHT", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	  {
 	     int                 state = STATE_NORMAL;
@@ -1883,9 +1843,8 @@ IB_FixPos(Iconbox * ib)
 	ImageClass         *ic;
 	int                 v = 0;
 
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	v = ib->max - ib->h;
 	if (ic)
 	   v += ic->padding.top + ic->padding.bottom;
@@ -1897,9 +1856,8 @@ IB_FixPos(Iconbox * ib)
 	ImageClass         *ic;
 	int                 v = 0;
 
-	ic =
-	   FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	v = ib->max - ib->w;
 	if (ic)
 	   v += ic->padding.left + ic->padding.right;
@@ -1938,36 +1896,31 @@ RedrawIconbox(Iconbox * ib)
 	h = ib->ewin->client.h;
 	if (ib->orientation)
 	  {
-	     ic =
-		FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     if (ic)
 		add = ic->padding.top + ic->padding.bottom;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->border->border.top +
+		  if ((ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
 		     add =
 			root.h - (ib->ewin->border->border.top +
 				  ib->ewin->border->border.bottom);
 	       }
 	     x = ib->ewin->x;
-	     y =
-		ib->ewin->y +
+	     y = ib->ewin->y +
 		(((ib->ewin->client.h - add) * ib->auto_resize_anchor) >> 10);
 	     w = ib->ewin->client.w;
 	     h = add;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->y + ib->ewin->border->border.top +
+		  if ((ib->ewin->y + ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
 		    {
 		       x = ib->ewin->x;
-		       y =
-			  root.h - (ib->ewin->border->border.top +
-				    ib->ewin->border->border.bottom + add);
+		       y = root.h - (ib->ewin->border->border.top +
+				     ib->ewin->border->border.bottom + add);
 		       w = ib->ewin->client.w;
 		       h = add;
 		    }
@@ -1975,35 +1928,30 @@ RedrawIconbox(Iconbox * ib)
 	  }
 	else
 	  {
-	     ic =
-		FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     if (ic)
 		add = ic->padding.left + ic->padding.right;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->border->border.left +
+		  if ((ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
 		     add =
 			root.w - (ib->ewin->border->border.left +
 				  ib->ewin->border->border.right);
 	       }
-	     x =
-		ib->ewin->x +
+	     x = ib->ewin->x +
 		(((ib->ewin->client.w - add) * ib->auto_resize_anchor) >> 10);
 	     y = ib->ewin->y;
 	     w = add;
 	     h = ib->ewin->client.h;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->x + ib->ewin->border->border.left +
+		  if ((ib->ewin->x + ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
 		    {
-		       x =
-			  root.w - (ib->ewin->border->border.left +
-				    ib->ewin->border->border.right + add);
+		       x = root.w - (ib->ewin->border->border.left +
+				     ib->ewin->border->border.right + add);
 		       y = ib->ewin->y;
 		       w = add;
 		       h = ib->ewin->client.h;
@@ -2031,37 +1979,32 @@ RedrawIconbox(Iconbox * ib)
 	IB_CalcMax(ib);
 	if (ib->orientation)
 	  {
-	     ic =
-		FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     if (ic)
 		add = ic->padding.top + ic->padding.bottom;
 	     add += ib->max;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->border->border.top +
+		  if ((ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
 		     add =
 			root.h - (ib->ewin->border->border.top +
 				  ib->ewin->border->border.bottom);
 	       }
 	     x = ib->ewin->x;
-	     y =
-		ib->ewin->y +
+	     y = ib->ewin->y +
 		(((ib->ewin->client.h - add) * ib->auto_resize_anchor) >> 10);
 	     w = ib->ewin->client.w;
 	     h = add;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->y + ib->ewin->border->border.top +
+		  if ((ib->ewin->y + ib->ewin->border->border.top +
 		       ib->ewin->border->border.bottom + add) > root.h)
 		    {
 		       x = ib->ewin->x;
-		       y =
-			  root.h - (ib->ewin->border->border.top +
-				    ib->ewin->border->border.bottom + add);
+		       y = root.h - (ib->ewin->border->border.top +
+				     ib->ewin->border->border.bottom + add);
 		       w = ib->ewin->client.w;
 		       h = add;
 		    }
@@ -2069,36 +2012,31 @@ RedrawIconbox(Iconbox * ib)
 	  }
 	else
 	  {
-	     ic =
-		FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
-			 LIST_TYPE_ICLASS);
+	     ic = FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
+			   LIST_TYPE_ICLASS);
 	     if (ic)
 		add = ic->padding.left + ic->padding.right;
 	     add += ib->max;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->border->border.left +
+		  if ((ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
 		     add =
 			root.w - (ib->ewin->border->border.left +
 				  ib->ewin->border->border.right);
 	       }
-	     x =
-		ib->ewin->x +
+	     x = ib->ewin->x +
 		(((ib->ewin->client.w - add) * ib->auto_resize_anchor) >> 10);
 	     y = ib->ewin->y;
 	     w = add;
 	     h = ib->ewin->client.h;
 	     if (ib->ewin->border)
 	       {
-		  if (
-		      (ib->ewin->x + ib->ewin->border->border.left +
+		  if ((ib->ewin->x + ib->ewin->border->border.left +
 		       ib->ewin->border->border.right + add) > root.w)
 		    {
-		       x =
-			  root.w - (ib->ewin->border->border.left +
-				    ib->ewin->border->border.right + add);
+		       x = root.w - (ib->ewin->border->border.left +
+				     ib->ewin->border->border.right + add);
 		       y = ib->ewin->y;
 		       w = add;
 		       h = ib->ewin->client.h;
@@ -2113,7 +2051,8 @@ RedrawIconbox(Iconbox * ib)
 	     EResizeWindow(disp, ib->win, w, h);
 	     ICCCM_Configure(ib->ewin);
 	     EFreePixmap(disp, ib->pmap);
-	     ib->pmap = ECreatePixmap(disp, ib->icon_win, w, h, id->x.depth);
+	     ib->pmap =
+		ECreatePixmap(disp, ib->icon_win, w, h, pImlibData->x.depth);
 	  }
 	ib->w = w;
 	ib->h = h;
@@ -2138,8 +2077,7 @@ RedrawIconbox(Iconbox * ib)
 	     /* right */
 	     EMoveResizeWindow(disp, ib->icon_win, 0, 0,
 			       ib->w - ib->scroll_thickness, ib->h);
-	     if (
-		 (ic =
+	     if ((ic =
 		  FindItem("ICONBOX_COVER_VERTICAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
@@ -2159,8 +2097,7 @@ RedrawIconbox(Iconbox * ib)
 	     /* left */
 	     EMoveResizeWindow(disp, ib->icon_win, ib->scroll_thickness, 0,
 			       ib->w - ib->scroll_thickness, ib->h);
-	     if (
-		 (ic =
+	     if ((ic =
 		  FindItem("ICONBOX_COVER_VERTICAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
@@ -2176,8 +2113,8 @@ RedrawIconbox(Iconbox * ib)
 	       }
 	  }
 
-	ic =
-	   FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (!ib->nobg)
 	  {
 	     if (ic)
@@ -2192,8 +2129,8 @@ RedrawIconbox(Iconbox * ib)
 		  EShapeCombineMask(disp, ib->icon_win, ShapeBounding, 0, 0,
 				    mask, ShapeSet);
 		  PastePixmap(disp, ib->pmap, pmap, mask, 0, 0);
-		  Imlib_free_pixmap(id, pmap);
-		  Imlib_free_pixmap(id, mask);
+		  Imlib_free_pixmap(pImlibData, pmap);
+		  Imlib_free_pixmap(pImlibData, mask);
 	       }
 	  }
 	else
@@ -2267,8 +2204,7 @@ RedrawIconbox(Iconbox * ib)
 	     /* bottom */
 	     EMoveResizeWindow(disp, ib->icon_win, 0, 0, ib->w,
 			       ib->h - ib->scroll_thickness);
-	     if (
-		 (ic =
+	     if ((ic =
 		  FindItem("ICONBOX_COVER_HORIZONTAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
@@ -2288,8 +2224,7 @@ RedrawIconbox(Iconbox * ib)
 	     /* top */
 	     EMoveResizeWindow(disp, ib->icon_win, 0, ib->scroll_thickness,
 			       ib->w, ib->h - ib->scroll_thickness);
-	     if (
-		 (ic =
+	     if ((ic =
 		  FindItem("ICONBOX_COVER_HORIZONTAL", 0, LIST_FINDBY_NAME,
 			   LIST_TYPE_ICLASS)) && (!(ib->cover_hide)))
 	       {
@@ -2306,9 +2241,8 @@ RedrawIconbox(Iconbox * ib)
 	       }
 	  }
 
-	ic =
-	   FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (!ib->nobg)
 	  {
 	     if (ic)
@@ -2323,8 +2257,8 @@ RedrawIconbox(Iconbox * ib)
 		  EShapeCombineMask(disp, ib->icon_win, ShapeBounding, 0, 0,
 				    mask, ShapeSet);
 		  PastePixmap(disp, ib->pmap, pmap, mask, 0, 0);
-		  Imlib_free_pixmap(id, pmap);
-		  Imlib_free_pixmap(id, mask);
+		  Imlib_free_pixmap(pImlibData, pmap);
+		  Imlib_free_pixmap(pImlibData, mask);
 	       }
 	  }
 	else
@@ -2413,7 +2347,7 @@ IconboxResize(Iconbox * ib, int w, int h)
       return;
    EResizeWindow(disp, ib->win, w, h);
    EFreePixmap(disp, ib->pmap);
-   ib->pmap = ECreatePixmap(disp, ib->icon_win, w, h, id->x.depth);
+   ib->pmap = ECreatePixmap(disp, ib->icon_win, w, h, pImlibData->x.depth);
    ib->w = w;
    ib->h = h;
    RedrawIconbox(ib);
@@ -2443,15 +2377,13 @@ IB_ShowMenu(Iconbox * ib, int x, int y)
    p_menu->style =
       FindItem("DEFAULT", 0, LIST_FINDBY_NAME, LIST_TYPE_MENU_STYLE);
    Esnprintf(s, sizeof(s), "iconbox %s", ib->name);
-   mi =
-      CreateMenuItem(_("This Iconbox Settings..."), NULL, ACTION_CONFIG, s,
-		     NULL);
+   mi = CreateMenuItem(_("This Iconbox Settings..."), NULL, ACTION_CONFIG, s,
+		       NULL);
    AddItemToMenu(p_menu, mi);
    mi = CreateMenuItem(_("Close Iconbox"), NULL, ACTION_KILL, NULL, NULL);
    AddItemToMenu(p_menu, mi);
-   mi =
-      CreateMenuItem(_("Create New Iconbox"), NULL, ACTION_CREATE_ICONBOX,
-		     NULL, NULL);
+   mi = CreateMenuItem(_("Create New Iconbox"), NULL, ACTION_CREATE_ICONBOX,
+		       NULL, NULL);
    AddItemToMenu(p_menu, mi);
    AddItem(p_menu, p_menu->name, 0, LIST_TYPE_MENU);
    Esnprintf(s, sizeof(s), "named %s", p_menu->name);
@@ -2474,8 +2406,8 @@ IB_CompleteRedraw(Iconbox * ib)
 	ImageClass         *ic;
 	int                 extra = 0;
 
-	ic =
-	   FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_VERTICAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	   extra = ic->padding.left + ic->padding.right;
 	ib->ewin->client.width.max = ib->ewin->client.width.min =
@@ -2487,9 +2419,8 @@ IB_CompleteRedraw(Iconbox * ib)
 	ImageClass         *ic;
 	int                 extra = 0;
 
-	ic =
-	   FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
-		    LIST_TYPE_ICLASS);
+	ic = FindItem("ICONBOX_HORIZONTAL", 0, LIST_FINDBY_NAME,
+		      LIST_TYPE_ICLASS);
 	if (ic)
 	   extra = ic->padding.left + ic->padding.right;
 	ib->ewin->client.height.max = ib->ewin->client.height.min =
@@ -2605,9 +2536,8 @@ IconboxHandleEvent(XEvent * ev)
 
 		  if (ib[i]->orientation)
 		    {
-		       ic =
-			  FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0,
-				   LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+		       ic = FindItem("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0,
+				     LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 		       GetWinXY(ib[i]->scrollbar_win, &x, &y);
 		       bs = ib[i]->h - (ib[i]->arrow_thickness * 2);
 		       if (ic)
@@ -2623,9 +2553,8 @@ IconboxHandleEvent(XEvent * ev)
 		    }
 		  else
 		    {
-		       ic =
-			  FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0,
-				   LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+		       ic = FindItem("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0,
+				     LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 		       GetWinXY(ib[i]->scrollbar_win, &x, &y);
 		       bs = ib[i]->w - (ib[i]->arrow_thickness * 2);
 		       if (ic)
@@ -2713,9 +2642,8 @@ IconboxHandleEvent(XEvent * ev)
 		    {
 		       if (ib[i]->shownames)
 			 {
-			    tt =
-			       FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_TOOLTIP);
+			    tt = FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
+					  LIST_TYPE_TOOLTIP);
 			    if (tt)
 			      {
 				 name_ewin = ewin;
@@ -2739,9 +2667,8 @@ IconboxHandleEvent(XEvent * ev)
 	       {
 		  ToolTip            *tt = NULL;
 
-		  tt =
-		     FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
-			      LIST_TYPE_TOOLTIP);
+		  tt = FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
+				LIST_TYPE_TOOLTIP);
 		  if (tt)
 		    {
 		       HideToolTip(tt);
@@ -2768,9 +2695,8 @@ IconboxHandleEvent(XEvent * ev)
 		    {
 		       ToolTip            *tt = NULL;
 
-		       tt =
-			  FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_TOOLTIP);
+		       tt = FindItem("ICONBOX", 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_TOOLTIP);
 		       if (tt)
 			  HideToolTip(tt);
 		       gwins =
