@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -43,12 +43,12 @@ runDocBrowser(void)
 int
 main(int argc, char **argv)
 {
-   char                restarting = 0;
    int                 i, num;
-   Button            **lst;
+   Button            **blst;
    Background         *bg;
    ECursor            *ec = NULL;
    struct utsname      ubuf;
+   char               *str;
 
    /* This function runs all the setup for startup, and then 
     * proceeds into the primary event loop at the end.
@@ -68,14 +68,13 @@ main(int argc, char **argv)
 #ifdef DEBUG
    call_level = 0;
    debug_level = 0;
-   {
-      char               *debug_str;
-
-      debug_str = getenv("EDBUG");
-      if (debug_str)
-	 debug_level = atoi(debug_str);
-   }
+   str = getenv("EDBUG");
+   if (str)
+      debug_level = atoi(str);
 #endif
+   str = getenv("EDBUG_FLAGS");
+   if (str)
+      debug_flags = strtoul(str, NULL, 0);
 
    EDBUG(1, "main");
 
@@ -150,7 +149,6 @@ main(int argc, char **argv)
 	     }
 	   else if ((!strcmp("-ext_init_win", argv[j])) && (argc - j > 1))
 	     {
-		restarting = 1;
 		init_win_ext = atoi(argv[++j]);
 	     }
 	   else if (!strcmp("-no_overwrite", argv[j]))
@@ -230,14 +228,11 @@ main(int argc, char **argv)
    SetSMUserThemePath(themepath);
 
    /* run most of the setup */
-   SetupSignals();
+   SignalsSetup();
    SetupX();
    BlumFlimFrub();
    ZoomInit();
    SetupDirs();
-/*  SC_Init();
- * SC_SetHotspot(30, 30);
- * SC_SetWait(); */
    InitDesktopBgs();
    GotoDesktop(0);
    CommsSetup();
@@ -270,18 +265,17 @@ main(int argc, char **argv)
    /* toss down the dragbar and related */
    InitDesktopControls();
    /* then draw all the buttons that belong on the desktop */
-   lst = (Button **) ListItemTypeID(&num, LIST_TYPE_BUTTON, 0);
-   if (lst)
+   blst = (Button **) ListItemTypeID(&num, LIST_TYPE_BUTTON, 0);
+   if (blst)
      {
 	for (i = 0; i < num; i++)
 	  {
-	     if ((!lst[i]->internal) && (lst[i]->default_show))
-		SimpleShowButton(lst[i]);
+	     if ((!blst[i]->internal) && (blst[i]->default_show))
+		ShowButton(blst[i]);
 	  }
-	Efree(lst);
+	Efree(blst);
      }
-   /* gnome hints stuff & session initialization here */
-   GNOME_SetHints();
+   HintsInit();
    SessionInit();
    ShowDesktopControls();
    CheckEvent();
@@ -291,8 +285,8 @@ main(int argc, char **argv)
    if (mode.mapslide)
       CreateStartupDisplay(0);
    MapUnmap(1);
-   /* set some more stuff for gnome */
-   GNOME_SetCurrentArea();
+   /* set some more hints */
+   HintsSetDesktopViewport();
    desks.current = 0;
    /* Set up the internal pagers */
    IB_Setup();
@@ -301,22 +295,24 @@ main(int argc, char **argv)
 	mode.show_pagers = 0;
 	queue_up = 0;
 	EnableAllPagers();
-	queue_up = 1;
+	queue_up = DRAW_QUEUE_ENABLE;
      }
    if (getpid() == master_pid && init_win_ext)
      {
 	XKillClient(disp, init_win_ext);
 	init_win_ext = 0;
      }
-   GNOME_SetClientList();
+   HintsSetClientList();
 
+#if ENABLE_KDE
    /* start up any kde crap we might need to start up */
    if (mode.kde_support)
       KDE_Init();
+#endif
 
    /* sync just to make sure */
    XSync(disp, False);
-   queue_up = 1;
+   queue_up = DRAW_QUEUE_ENABLE;
 
    /* hello!  we don't have a resizemode of 5! */
    if (mode.resizemode == 5)
@@ -330,10 +326,7 @@ main(int argc, char **argv)
 	ec->inroot = 1;
      }
 
-   if (mode.display_warp < 0)
-      mode.display_warp = 0;
    mode.startup = 0;
-   /*  SC_Kill(); */
    /* ok - paranoia - save current settings to disk */
    if (root.scr == 0)
       autosave();
@@ -372,14 +365,14 @@ main(int argc, char **argv)
    /* if we didn't have an external window piped to us, we'll do some stuff */
    if (!mode.mapslide)
       CreateStartupDisplay(0);
-   if (
-       (bg =
+   if ((bg =
 	RemoveItem("STARTUP_BACKGROUND_SIDEWAYS", 0, LIST_FINDBY_NAME,
-		   LIST_TYPE_BACKGROUND))) FreeDesktopBG(bg);
-   if (
-       (bg =
+		   LIST_TYPE_BACKGROUND)))
+      FreeDesktopBG(bg);
+   if ((bg =
 	RemoveItem("STARTUP_BACKGROUND", 0, LIST_FINDBY_NAME,
-		   LIST_TYPE_BACKGROUND))) FreeDesktopBG(bg);
+		   LIST_TYPE_BACKGROUND)))
+      FreeDesktopBG(bg);
 #ifdef SIGCONT
    for (i = 0; i < child_count; i++)
       kill(e_children[i], SIGCONT);
@@ -388,12 +381,10 @@ main(int argc, char **argv)
    SetupUserInitialization();
    if (mode.firsttime)
       runDocBrowser();
-   if (!restarting)
-     {
-	mode.startup = 1;
-	SpawnSnappedCmds();
-	mode.startup = 0;
-     }
+
+   mode.startup = 1;
+   SpawnSnappedCmds();
+   mode.startup = 0;
 
    BadThemeDialog();
    /* The primary event loop */
