@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -340,9 +340,8 @@ ShowMenu(Menu * m, char noshow)
      {
 	Border             *b;
 
-	b =
-	   (Border *) FindItem(m->style->border_name, 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_BORDER);
+	b = (Border *) FindItem(m->style->border_name, 0, LIST_FINDBY_NAME,
+				LIST_TYPE_BORDER);
 	if (b)
 	  {
 	     int                 width;
@@ -350,51 +349,8 @@ ShowMenu(Menu * m, char noshow)
 	     int                 x_origin;
 	     int                 y_origin;
 
-	     width = root.w;
-	     height = root.h;
-	     x_origin = 0;
-	     y_origin = 0;
-
-#ifdef HAS_XINERAMA
-	     if (xinerama_active)
-	       {
-		  Window              rt, ch;
-		  XineramaScreenInfo *screens;
-		  int                 pointer_x, pointer_y;
-		  int                 num;
-		  int                 d;
-		  unsigned int        ud;
-		  int                 i;
-
-		  XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
-				&pointer_y, &d, &d, &ud);
-		  screens = XineramaQueryScreens(disp, &num);
-		  for (i = 0; i < num; i++)
-		    {
-		       if (pointer_x >= screens[i].x_org)
-			 {
-			    if (pointer_x <=
-				(screens[i].width + screens[i].x_org))
-			      {
-				 if (pointer_y >= screens[i].y_org)
-				   {
-				      if (pointer_y <=
-					  (screens[i].height +
-					   screens[i].y_org))
-					{
-					   x_origin = screens[i].x_org;
-					   y_origin = screens[i].y_org;
-					   width = screens[i].width;
-					   height = screens[i].height;
-					   head_num = i;
-					}
-				   }
-			      }
-			 }
-		    }
-		  XFree(screens);
-	       }
-#endif
+	     head_num =
+		GetPointerScreenGeometry(&x_origin, &y_origin, &width, &height);
 
 	     if (mode.x - x - ((int)mw / 2) > (x_origin + width))
 		wx = x_origin + (int)b->border.left;
@@ -450,11 +406,11 @@ ShowMenu(Menu * m, char noshow)
 	   mode.y = -((-mode.y) - mode.context_h - mh);
 	EMoveWindow(disp, m->win, -mode.x, -mode.y);
      }
-   ewin = AddInternalToFamily(m->win, 1, m->style->border_name, 0, m);
+   ewin =
+      AddInternalToFamily(m->win, 1, m->style->border_name, EWIN_TYPE_MENU, m);
    if (ewin)
      {
 	DesktopRemoveEwin(ewin);
-	ewin->layer = 99;
 	ewin->head = head_num;
 	DesktopAddEwinToTop(ewin);
 	if (ewin->desktop != 0)
@@ -611,6 +567,8 @@ DestroyMenu(Menu * m)
    RemoveItem((char *)m, m->win, LIST_FINDBY_POINTER, LIST_TYPE_MENU);
    if (m->name)
       Efree(m->name);
+   if (m->title)
+      Efree(m->title);
 
    for (i = 0; i < m->num; i++)
      {
@@ -620,7 +578,8 @@ DestroyMenu(Menu * m)
 	       {
 		  if (FindItem
 		      ((char *)m->items[i]->child, 0, LIST_FINDBY_POINTER,
-		       LIST_TYPE_MENU)) DestroyMenu(m->items[i]->child);
+		       LIST_TYPE_MENU))
+		     DestroyMenu(m->items[i]->child);
 	       }
 	     if (m->items[i]->text)
 		Efree(m->items[i]->text);
@@ -629,9 +588,9 @@ DestroyMenu(Menu * m)
 	     for (j = 0; j < 3; j++)
 	       {
 		  if (m->items[i]->pmap[j])
-		     Imlib_free_pixmap(id, m->items[i]->pmap[j]);
+		     Imlib_free_pixmap(pImlibData, m->items[i]->pmap[j]);
 		  if (m->items[i]->mask[j])
-		     Imlib_free_pixmap(id, m->items[i]->mask[j]);
+		     Imlib_free_pixmap(pImlibData, m->items[i]->mask[j]);
 	       }
 	     if (m->items[i]->icon_iclass)
 		m->items[i]->icon_iclass->ref_count--;
@@ -675,9 +634,9 @@ EmptyMenu(Menu * m)
 	     for (j = 0; j < 3; j++)
 	       {
 		  if (m->items[i]->pmap[j])
-		     Imlib_free_pixmap(id, m->items[i]->pmap[j]);
+		     Imlib_free_pixmap(pImlibData, m->items[i]->pmap[j]);
 		  if (m->items[i]->mask[j])
-		     Imlib_free_pixmap(id, m->items[i]->mask[j]);
+		     Imlib_free_pixmap(pImlibData, m->items[i]->mask[j]);
 	       }
 	     if (m->items[i]->win)
 		EDestroyWindow(disp, m->items[i]->win);
@@ -739,7 +698,6 @@ void
 RealizeMenu(Menu * m)
 {
    int                 i, maxh = 0, maxw =
-
       0, maxx1, maxx2, w, h, x, y, r, mmw, mmh;
    unsigned int        iw, ih;
    ImlibImage         *im;
@@ -806,7 +764,7 @@ RealizeMenu(Menu * m)
 		     maxh = im->rgb_height;
 		  if (im->rgb_width > maxx2)
 		     maxx2 = im->rgb_width;
-		  Imlib_destroy_image(id, im);
+		  Imlib_destroy_image(pImlibData, im);
 	       }
 	     else
 		m->items[i]->icon_iclass = NULL;
@@ -975,7 +933,7 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
 	     if (!m->style->use_item_bg)
 	       {
 		  mi->pmap[(int)(mi->state)] =
-		     ECreatePixmap(disp, mi->win, w, h, id->x.depth);
+		     ECreatePixmap(disp, mi->win, w, h, pImlibData->x.depth);
 		  gc = XCreateGC(disp, m->pmap, 0, &gcv);
 		  XCopyArea(disp, m->pmap, mi->pmap[(int)(mi->state)], gc, x, y,
 			    w, h, 0, 0);
@@ -997,9 +955,9 @@ DrawMenuItem(Menu * m, MenuItem * mi, char shape)
 			 }
 		       XCopyArea(disp, pmap, mi->pmap[(int)(mi->state)], gc, 0,
 				 0, w, h, 0, 0);
-		       Imlib_free_pixmap(id, pmap);
+		       Imlib_free_pixmap(pImlibData, pmap);
 		       if (mask)
-			  Imlib_free_pixmap(id, mask);
+			  Imlib_free_pixmap(pImlibData, mask);
 		    }
 		  XFreeGC(disp, gc);
 	       }
@@ -1133,16 +1091,15 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 		       char                s2[4096], s3[512];
 
 		       word(s, 3, s3);
-		       bg =
-			  (Background *) FindItem(s3, 0, LIST_FINDBY_NAME,
-						  LIST_TYPE_BACKGROUND);
+		       bg = (Background *) FindItem(s3, 0, LIST_FINDBY_NAME,
+						    LIST_TYPE_BACKGROUND);
 		       if (!bg)
 			 {
 			    ImlibImage         *im;
 
 			    word(s, 2, s2);
 			    Esnprintf(ss, sizeof(ss), "%s/%s", dir, s2);
-			    im = Imlib_load_image(id, ss);
+			    im = Imlib_load_image(pImlibData, ss);
 			    if (im)
 			      {
 				 ImlibImage         *im2;
@@ -1164,15 +1121,17 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				 if (w2 > maxw)
 				   {
 				      w2 = maxw;
-				      h2 =
-					 (im->rgb_height * w2) / im->rgb_width;
+				      h2 = (im->rgb_height * w2) /
+					 im->rgb_width;
 				   }
-				 im2 = Imlib_clone_scaled_image(id, im, w2, h2);
-				 Imlib_save_image_to_ppm(id, im2, s2);
-				 Imlib_changed_image(id, im2);
-				 Imlib_changed_image(id, im);
-				 Imlib_kill_image(id, im2);
-				 Imlib_kill_image(id, im);
+				 im2 =
+				    Imlib_clone_scaled_image(pImlibData, im, w2,
+							     h2);
+				 Imlib_save_image_to_ppm(pImlibData, im2, s2);
+				 Imlib_changed_image(pImlibData, im2);
+				 Imlib_changed_image(pImlibData, im);
+				 Imlib_kill_image(pImlibData, im2);
+				 Imlib_kill_image(pImlibData, im);
 				 scr_asp = (root.w << 16) / root.h;
 				 im_asp = (width << 16) / height;
 				 if (width == height)
@@ -1224,11 +1183,10 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				 icl.r = 0;
 				 icl.g = 0;
 				 icl.b = 0;
-				 bg =
-				    CreateDesktopBG(s3, &icl, ss, tile,
-						    keep_asp, justx, justy,
-						    scalex, scaley, NULL, 0, 0,
-						    0, 0, 0);
+				 bg = CreateDesktopBG(s3, &icl, ss, tile,
+						      keep_asp, justx, justy,
+						      scalex, scaley, NULL, 0,
+						      0, 0, 0, 0);
 				 AddItem(bg, bg->name, 0, LIST_TYPE_BACKGROUND);
 			      }
 			    else
@@ -1248,9 +1206,8 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 			    ic->norm.normal->unloadable = 1;
 			    IclassPopulate(ic);
 			    AddItem(ic, ic->name, 0, LIST_TYPE_ICLASS);
-			    mi =
-			       CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET,
-					      s3, NULL);
+			    mi = CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET,
+						s3, NULL);
 			    AddItemToMenu(m, mi);
 			 }
 		    }
@@ -1362,14 +1319,13 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 			    chmap[(cc >> 0) & 0x3f], chmap[(cc >> 6) & 0x3f],
 			    chmap[(cc >> 12) & 0x3f], chmap[(cc >> 18) & 0x3f],
 			    chmap[(cc >> 24) & 0x3f], chmap[(cc >> 28) & 0x3f]);
-		  bg =
-		     (Background *) FindItem(s3, 0, LIST_FINDBY_NAME,
-					     LIST_TYPE_BACKGROUND);
+		  bg = (Background *) FindItem(s3, 0, LIST_FINDBY_NAME,
+					       LIST_TYPE_BACKGROUND);
 		  if (!bg)
 		    {
 		       ImlibImage         *im;
 
-		       im = Imlib_load_image(id, ss);
+		       im = Imlib_load_image(pImlibData, ss);
 		       if (im)
 			 {
 			    ImlibImage         *im2;
@@ -1391,12 +1347,13 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 				 w2 = maxw;
 				 h2 = (im->rgb_height * w2) / im->rgb_width;
 			      }
-			    im2 = Imlib_clone_scaled_image(id, im, w2, h2);
-			    Imlib_save_image_to_ppm(id, im2, s2);
-			    Imlib_changed_image(id, im2);
-			    Imlib_changed_image(id, im);
-			    Imlib_kill_image(id, im2);
-			    Imlib_kill_image(id, im);
+			    im2 =
+			       Imlib_clone_scaled_image(pImlibData, im, w2, h2);
+			    Imlib_save_image_to_ppm(pImlibData, im2, s2);
+			    Imlib_changed_image(pImlibData, im2);
+			    Imlib_changed_image(pImlibData, im);
+			    Imlib_kill_image(pImlibData, im2);
+			    Imlib_kill_image(pImlibData, im);
 			    scr_asp = (root.w << 16) / root.h;
 			    im_asp = (width << 16) / height;
 			    if (width == height)
@@ -1438,10 +1395,9 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 			    icl.r = 0;
 			    icl.g = 0;
 			    icl.b = 0;
-			    bg =
-			       CreateDesktopBG(s3, &icl, ss, tile, keep_asp,
-					       512, 512, scalex, scaley, NULL,
-					       0, 0, 0, 0, 0);
+			    bg = CreateDesktopBG(s3, &icl, ss, tile, keep_asp,
+						 512, 512, scalex, scaley, NULL,
+						 0, 0, 0, 0, 0);
 			    AddItem(bg, bg->name, 0, LIST_TYPE_BACKGROUND);
 			 }
 		       else
@@ -1461,9 +1417,8 @@ CreateMenuFromDirectory(char *name, MenuStyle * ms, char *dir)
 		       ic->norm.normal->unloadable = 1;
 		       IclassPopulate(ic);
 		       AddItem(ic, ic->name, 0, LIST_TYPE_ICLASS);
-		       mi =
-			  CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET, s3,
-					 NULL);
+		       mi = CreateMenuItem(NULL, ic, ACTION_BACKGROUND_SET, s3,
+					   NULL);
 		       AddItemToMenu(m, mi);
 		    }
 		  if (f)
@@ -1532,6 +1487,13 @@ FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name, char *file,
 #else
    f = fopen(file, "rt");
 #endif
+   if (!f)
+     {
+	fprintf(stderr, "Unable to open menu file %s -- %s\n", file,
+		strerror(errno));
+	return;
+     }
+
    while (fgets(s, 4096, f))
      {
 	s[strlen(s) - 1] = 0;
@@ -1591,14 +1553,9 @@ FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name, char *file,
 			 {
 			    Efree(tmp);
 
-			    mi =
-			       CreateMenuItem(txt, icc, ACTION_EXEC, params,
-					      NULL);
+			    mi = CreateMenuItem(txt, icc, ACTION_EXEC, params,
+						NULL);
 			    AddItemToMenu(m, mi);
-			    if (txt)
-			       Efree(txt);
-			    if (params)
-			       Efree(params);
 			 }
 		    }
 		  else if ((act) && (!strcmp(act, "menu")) && (params))
@@ -1613,20 +1570,18 @@ FillFlatFileMenu(Menu * m, MenuStyle * ms, char *name, char *file,
 			    mi = CreateMenuItem(txt, icc, 0, NULL, mm);
 			    AddItemToMenu(m, mi);
 			 }
-		       if (txt)
-			  Efree(txt);
 		    }
 		  else
 		    {
 		       mi = CreateMenuItem(txt, icc, 0, NULL, NULL);
 		       AddItemToMenu(m, mi);
-		       if (txt)
-			  Efree(txt);
-		       if (params)
-			  Efree(params);
 		    }
+		  if (txt)
+		     Efree(txt);
 		  if (act)
 		     Efree(act);
+		  if (params)
+		     Efree(params);
 	       }
 	  }
      }
@@ -1758,8 +1713,8 @@ CreateMenuFromGnome(char *name, MenuStyle * ms, char *dir)
 			    else if (name_buf[0]
 				     && !strncmp(s, name_buf, strlen(name_buf)))
 			       iname = duplicate(&(s[strlen(name_buf)]));
-			    else
-			       if (!strncmp(s, "TryExec=", strlen("TryExec=")))
+			    else if (!strncmp
+				     (s, "TryExec=", strlen("TryExec=")))
 			       texec = duplicate(&(s[strlen("TryExec=")]));
 			    else if (!strncmp(s, "Exec=", strlen("Exec=")))
 			       exec = duplicate(&(s[strlen("Exec=")]));
@@ -1785,9 +1740,8 @@ CreateMenuFromGnome(char *name, MenuStyle * ms, char *dir)
 				 if (tmp)
 				    Efree(tmp);
 
-				 mi =
-				    CreateMenuItem(iname, NULL, ACTION_EXEC,
-						   exec, NULL);
+				 mi = CreateMenuItem(iname, NULL, ACTION_EXEC,
+						     exec, NULL);
 				 AddItemToMenu(m, mi);
 			      }
 			 }
@@ -1871,9 +1825,8 @@ CreateMenuFromBorders(char *name, MenuStyle * ms)
 	/* if its not internal (ie doesnt start with _ ) */
 	if (lst[i]->name[0] != '_')
 	  {
-	     mi =
-		CreateMenuItem(lst[i]->name, NULL, ACTION_SET_WINDOW_BORDER,
-			       lst[i]->name, NULL);
+	     mi = CreateMenuItem(lst[i]->name, NULL, ACTION_SET_WINDOW_BORDER,
+				 lst[i]->name, NULL);
 	     AddItemToMenu(m, mi);
 	  }
      }
@@ -1906,9 +1859,8 @@ CreateMenuFromAllEWins(char *name, MenuStyle * ms)
 		 && (lst[i]->client.title) && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
-		  mi =
-		     CreateMenuItem(lst[i]->client.title, NULL,
-				    ACTION_FOCUS_SET, s, NULL);
+		  mi = CreateMenuItem(lst[i]->client.title, NULL,
+				      ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(m, mi);
 	       }
 	  }
@@ -1943,9 +1895,8 @@ CreateMenuFromDesktopEWins(char *name, MenuStyle * ms, int desk)
 		 && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
-		  mi =
-		     CreateMenuItem(lst[i]->client.title, NULL,
-				    ACTION_FOCUS_SET, s, NULL);
+		  mi = CreateMenuItem(lst[i]->client.title, NULL,
+				      ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(m, mi);
 	       }
 	  }
@@ -1976,9 +1927,8 @@ CreateMenuFromDesktops(char *name, MenuStyle * ms)
 	mm->name = duplicate("__SUBMENUDESK_E");
 	mm->style = ms;
 	Esnprintf(s, sizeof(s), "%i", j);
-	mi =
-	   CreateMenuItem(_("Go to this Desktop"), NULL, ACTION_GOTO_DESK, s,
-			  NULL);
+	mi = CreateMenuItem(_("Go to this Desktop"), NULL, ACTION_GOTO_DESK, s,
+			    NULL);
 	AddItemToMenu(mm, mi);
 	for (i = 0; i < num; i++)
 	  {
@@ -1987,9 +1937,8 @@ CreateMenuFromDesktops(char *name, MenuStyle * ms)
 		 && (lst[i]->client.title) && (!lst[i]->ibox))
 	       {
 		  Esnprintf(s, sizeof(s), "%i", (int)(lst[i]->client.win));
-		  mi =
-		     CreateMenuItem(lst[i]->client.title, NULL,
-				    ACTION_FOCUS_SET, s, NULL);
+		  mi = CreateMenuItem(lst[i]->client.title, NULL,
+				      ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(mm, mi);
 	       }
 	  }
@@ -2016,7 +1965,8 @@ ShowMenuMasker(Menu * m)
 
 	parent = desks.desk[ewin->desktop].win;
 	mode.menu_cover_win = ECreateEventWindow(parent, 0, 0, root.w, root.h);
-	wl[0] = ewin->win;
+	mode.menu_win_covered = ewin->win;
+	wl[0] = mode.menu_win_covered;
 	wl[1] = mode.menu_cover_win;
 	XSelectInput(disp, mode.menu_cover_win,
 		     ButtonPressMask | ButtonReleaseMask | EnterWindowMask |
@@ -2030,8 +1980,11 @@ void
 HideMenuMasker(void)
 {
    if (mode.menu_cover_win)
-      EDestroyWindow(disp, mode.menu_cover_win);
-   mode.menu_cover_win = 0;
+     {
+	EDestroyWindow(disp, mode.menu_cover_win);
+	mode.menu_cover_win = 0;
+	mode.menu_win_covered = 0;
+     }
 }
 
 Menu               *
@@ -2057,21 +2010,18 @@ CreateMenuFromGroups(char *name, MenuStyle * ms)
 	     mm->name = duplicate("__SUBMENUGROUP_E");
 	     mm->style = ms;
 	     Esnprintf(s, sizeof(s), "%i", lst[i]->members[0]->client.win);
-	     mi =
-		CreateMenuItem(_("Show/Hide this group"), NULL,
-			       ACTION_SHOW_HIDE_GROUP, s, NULL);
+	     mi = CreateMenuItem(_("Show/Hide this group"), NULL,
+				 ACTION_SHOW_HIDE_GROUP, s, NULL);
 	     AddItemToMenu(mm, mi);
-	     mi =
-		CreateMenuItem(_("Iconify this group"), NULL, ACTION_ICONIFY, s,
-			       NULL);
+	     mi = CreateMenuItem(_("Iconify this group"), NULL, ACTION_ICONIFY,
+				 s, NULL);
 	     AddItemToMenu(mm, mi);
 
 	     for (j = 0; j < lst[i]->num_members; j++)
 	       {
 		  Esnprintf(s, sizeof(s), "%i", lst[i]->members[j]->client.win);
-		  mi =
-		     CreateMenuItem(lst[i]->members[j]->client.title, NULL,
-				    ACTION_FOCUS_SET, s, NULL);
+		  mi = CreateMenuItem(lst[i]->members[j]->client.title, NULL,
+				      ACTION_FOCUS_SET, s, NULL);
 		  AddItemToMenu(mm, mi);
 	       }
 	     mm->parent = m;
