@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -170,7 +170,7 @@ UserCacheDir(void)
 int
 EExit(void *code)
 {
-   int                 exitcode = 0;
+   long                exitcode = 0;
 
    EDBUG(9, "EExit");
 
@@ -190,31 +190,17 @@ EExit(void *code)
 	XSelectInput(disp, root.win, 0);
 	XCloseDisplay(disp);
      }
+
    XSetErrorHandler((XErrorHandler) NULL);
    XSetIOErrorHandler((XIOErrorHandler) NULL);
-   signal(SIGHUP, SIG_DFL);
-   signal(SIGINT, SIG_DFL);
-   signal(SIGQUIT, SIG_DFL);
-   signal(SIGILL, SIG_DFL);
-   signal(SIGABRT, SIG_DFL);
-   signal(SIGFPE, SIG_IGN);
-   signal(SIGSEGV, SIG_IGN);
-   signal(SIGPIPE, SIG_DFL);
-   signal(SIGALRM, SIG_DFL);
-   signal(SIGTERM, SIG_DFL);
-   signal(SIGUSR1, SIG_DFL);
-   signal(SIGUSR2, SIG_DFL);
-   signal(SIGCHLD, SIG_DFL);
-#ifdef SIGTSTP
-   signal(SIGTSTP, SIG_DFL);
-#endif
-   signal(SIGBUS, SIG_IGN);
+
+   SignalsRestore();
 
    if (master_pid == getpid())
      {
 	int                 i;
 
-	exitcode = (int)code;
+	exitcode = (long)code;
 	SoundExit();
 	if (mustdel)
 	  {
@@ -230,7 +216,7 @@ EExit(void *code)
 	for (i = 0; i < child_count; i++)
 	   kill(e_children[i], SIGINT);
      }
-   SaveSnapInfo();
+   Real_SaveSnapInfo(0, NULL);
 
    exit(exitcode);
    EDBUG_RETURN(exitcode);
