@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -124,7 +124,7 @@ PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw, int sy,
 	     xim3 = px_buf;
 	  }
 	difx = (sw / pw) / 2;
-	switch (id->x.render_depth)
+	switch (pImlibData->x.render_depth)
 	  {
 	  case 24:
 	  case 32:
@@ -135,8 +135,7 @@ PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw, int sy,
 		  v2 = XGetPixel(xim1, x2 + difx, 0);
 		  v3 = XGetPixel(xim2, x2, 0);
 		  v4 = XGetPixel(xim2, x2 + difx, 0);
-		  v1 =
-		     ((v1 >> 2) & 0x3f3f3f3f) + ((v2 >> 2) & 0x3f3f3f3f) +
+		  v1 = ((v1 >> 2) & 0x3f3f3f3f) + ((v2 >> 2) & 0x3f3f3f3f) +
 		     ((v3 >> 2) & 0x3f3f3f3f) + ((v4 >> 2) & 0x3f3f3f3f) +
 		     (v1 & v2 & v3 & v4 & 0x03030303);
 		  XPutPixel(xim3, x, 0, v1);
@@ -150,12 +149,14 @@ PagerScaleLine(Pixmap dest, Window src, int dx, int dy, int sw, int pw, int sy,
 		  v2 = XGetPixel(xim1, x2 + difx, 0);
 		  v3 = XGetPixel(xim2, x2, 0);
 		  v4 = XGetPixel(xim2, x2 + difx, 0);
-		  v1 =
-		     ((v1 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4))) +
-		     ((v2 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4))) +
-		     ((v3 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4))) +
-		     ((v4 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4))) +
-		     (v1 & v2 & v3 & v4 & ((0x3 << 11) | (0x3 << 5) | (0x3)));
+		  v1 = ((v1 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4)))
+		     +
+		     ((v2 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4)))
+		     +
+		     ((v3 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4)))
+		     +
+		     ((v4 >> 2) & ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4)))
+		     + (v1 & v2 & v3 & v4 & ((0x3 << 11) | (0x3 << 5) | (0x3)));
 		  XPutPixel(xim3, x, 0, v1);
 	       }
 	     break;
@@ -351,9 +352,10 @@ PagerScaleRect(Pixmap dest, Window src, int sx, int sy, int dx, int dy, int sw,
 		       v2 = XGetPixel(xim1, x2 + difx, y2);
 		       v3 = XGetPixel(xim1, x2, y2 + 1);
 		       v4 = XGetPixel(xim1, x2 + difx, y2 + 1);
-		       v1 =
-			  ((v1 >> 2) & 0x3f3f3f3f) + ((v2 >> 2) & 0x3f3f3f3f) +
-			  ((v3 >> 2) & 0x3f3f3f3f) + ((v4 >> 2) & 0x3f3f3f3f) +
+		       v1 = ((v1 >> 2) & 0x3f3f3f3f) +
+			  ((v2 >> 2) & 0x3f3f3f3f) +
+			  ((v3 >> 2) & 0x3f3f3f3f) +
+			  ((v4 >> 2) & 0x3f3f3f3f) +
 			  (v1 & v2 & v3 & v4 & 0x03030303);
 		       XPutPixel(xim3, x, y, v1);
 		    }
@@ -370,9 +372,8 @@ PagerScaleRect(Pixmap dest, Window src, int sx, int sy, int dx, int dy, int sw,
 		       v2 = XGetPixel(xim1, x2 + difx, y2);
 		       v3 = XGetPixel(xim1, x2, y2 + 1);
 		       v4 = XGetPixel(xim1, x2 + difx, y2 + 1);
-		       v1 =
-			  ((v1 >> 2) &
-			   ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4))) +
+		       v1 = ((v1 >> 2) &
+			     ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4))) +
 			  ((v2 >> 2) &
 			   ((0x70 << 7) | (0x78 << 2) | (0x70 >> 4))) +
 			  ((v3 >> 2) &
@@ -517,9 +518,9 @@ CreatePager(void)
       return NULL;
    if ((!did_dialog) && (SNAP))
      {
-	if (id->x.shm)
+	if (pImlibData->x.shm)
 	  {
-	     if (!id->x.shmp)
+	     if (!pImlibData->x.shmp)
 	       {
 		  if (XShmPixmapFormat(disp) != ZPixmap)
 		    {
@@ -578,8 +579,9 @@ CreatePager(void)
    p->dw = ((48 * root.w) / root.h);
    p->dh = 48;
    p->win = ECreateWindow(root.win, 0, 0, p->w, p->h, 0);
-   p->pmap = ECreatePixmap(disp, p->win, p->w, p->h, id->x.depth);
-   p->bgpmap = ECreatePixmap(disp, p->win, p->w / ax, p->h / ay, id->x.depth);
+   p->pmap = ECreatePixmap(disp, p->win, p->w, p->h, pImlibData->x.depth);
+   p->bgpmap =
+      ECreatePixmap(disp, p->win, p->w / ax, p->h / ay, pImlibData->x.depth);
    ESetWindowBackgroundPixmap(disp, p->win, p->pmap);
    XSelectInput(disp, p->win,
 		ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
@@ -622,8 +624,9 @@ PagerResize(Pager * p, int w, int h)
    p->h = h;
    p->dw = w / ax;
    p->dh = h / ay;
-   p->pmap = ECreatePixmap(disp, p->win, p->w, p->h, id->x.depth);
-   p->bgpmap = ECreatePixmap(disp, p->win, p->w / ax, p->h / ay, id->x.depth);
+   p->pmap = ECreatePixmap(disp, p->win, p->w, p->h, pImlibData->x.depth);
+   p->bgpmap =
+      ECreatePixmap(disp, p->win, p->w / ax, p->h / ay, pImlibData->x.depth);
    if (p->visible)
       PagerRedraw(p, 1);
    ESetWindowBackgroundPixmap(disp, p->win, p->pmap);
@@ -678,10 +681,10 @@ PagerShow(Pager * p)
    pq = queue_up;
    queue_up = 0;
    MatchToSnapInfoPager(p);
-   if (p->border_name)
-      ewin = AddInternalToFamily(p->win, 1, p->border_name, 1, p);
-   else
-      ewin = AddInternalToFamily(p->win, 1, "PAGER", 1, p);
+   ewin =
+      AddInternalToFamily(p->win, 1,
+			  (p->border_name) ? p->border_name : "PAGER",
+			  EWIN_TYPE_PAGER, p);
    if (ewin)
      {
 	char                s[4096];
@@ -734,9 +737,10 @@ PagerShow(Pager * p)
 		DoIn(s, 1 / ((double)mode.pager_scanspeed), PagerUpdateTimeout,
 		     0, p);
 	  }
-	queue_up = pq;
 	AddItem(p, "PAGER", p->win, LIST_TYPE_PAGER);
      }
+
+   queue_up = pq;
 }
 
 void
@@ -874,10 +878,10 @@ PagerEwinUpdateMini(Pager * p, EWin * ewin)
 	ImlibImage         *im;
 
 	im =
-	   Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
-					    ewin->mini_w, ewin->mini_h);
-	Imlib_apply_image(id, im, p->hi_win);
-	Imlib_kill_image(id, im);
+	   Imlib_create_image_from_drawable(pImlibData, ewin->mini_pmap, 0, 0,
+					    0, ewin->mini_w, ewin->mini_h);
+	Imlib_apply_image(pImlibData, im, p->hi_win);
+	Imlib_kill_image(pImlibData, im);
      }
 }
 
@@ -925,10 +929,10 @@ PagerEwinUpdateFromPager(Pager * p, EWin * ewin)
 	ImlibImage         *im;
 
 	im =
-	   Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
-					    ewin->mini_w, ewin->mini_h);
-	Imlib_apply_image(id, im, p->hi_win);
-	Imlib_kill_image(id, im);
+	   Imlib_create_image_from_drawable(pImlibData, ewin->mini_pmap, 0, 0,
+					    0, ewin->mini_w, ewin->mini_h);
+	Imlib_apply_image(pImlibData, im, p->hi_win);
+	Imlib_kill_image(pImlibData, im);
      }
 }
 
@@ -942,6 +946,7 @@ PagerRedraw(Pager * p, char newbg)
 
    if (!mode.show_pagers)
       return;
+
    if (queue_up)
      {
 	DrawQueue          *dq;
@@ -975,11 +980,11 @@ PagerRedraw(Pager * p, char newbg)
    r = 0;
    g = 0;
    b = 0;
-   c1 = Imlib_best_color_match(id, &r, &g, &b);
+   c1 = Imlib_best_color_match(pImlibData, &r, &g, &b);
    r = 255;
    g = 255;
    b = 255;
-   c2 = Imlib_best_color_match(id, &r, &g, &b);
+   c2 = Imlib_best_color_match(pImlibData, &r, &g, &b);
    gc = XCreateGC(disp, p->pmap, 0, &gcv);
    if (gc)
      {
@@ -990,9 +995,8 @@ PagerRedraw(Pager * p, char newbg)
 		  ImageClass         *ic = NULL;
 
 		  EFreePixmap(disp, p->bgpmap);
-		  ic =
-		     FindItem("PAGER_BACKGROUND", 0, LIST_FINDBY_NAME,
-			      LIST_TYPE_ICLASS);
+		  ic = FindItem("PAGER_BACKGROUND", 0, LIST_FINDBY_NAME,
+				LIST_TYPE_ICLASS);
 		  if (ic)
 		     IclassApplyCopy(ic, p->win, p->w / ax, p->h / ay, 0, 0,
 				     STATE_NORMAL, &(p->bgpmap), NULL);
@@ -1012,26 +1016,27 @@ PagerRedraw(Pager * p, char newbg)
 				 (p->h / ay), uniq);
 		       Efree(uniq);
 
-		       im = Imlib_load_image(id, s);
+		       im = Imlib_load_image(pImlibData, s);
 		       if (im)
 			 {
 			    EFreePixmap(disp, p->bgpmap);
-			    Imlib_render(id, im, (p->w / ax), (p->h / ay));
-			    p->bgpmap = Imlib_copy_image(id, im);
-			    Imlib_destroy_image(id, im);
+			    Imlib_render(pImlibData, im, (p->w / ax),
+					 (p->h / ay));
+			    p->bgpmap = Imlib_copy_image(pImlibData, im);
+			    Imlib_destroy_image(pImlibData, im);
 			 }
 		       else
 			 {
-			    SetBackgroundTo(id, p->bgpmap,
+			    SetBackgroundTo(pImlibData, p->bgpmap,
 					    desks.desk[p->desktop].bg, 0);
 			    im =
-			       Imlib_create_image_from_drawable(id, p->bgpmap,
-								0, 0, 0,
-								(p->w / ax),
+			       Imlib_create_image_from_drawable(pImlibData,
+								p->bgpmap, 0, 0,
+								0, (p->w / ax),
 								(p->h / ay));
-			    Imlib_save_image_to_ppm(id, im, s);
-			    Imlib_changed_image(id, im);
-			    Imlib_kill_image(id, im);
+			    Imlib_save_image_to_ppm(pImlibData, im, s);
+			    Imlib_changed_image(pImlibData, im);
+			    Imlib_kill_image(pImlibData, im);
 			 }
 		    }
 		  else
@@ -1101,6 +1106,7 @@ PagerForceUpdate(Pager * p)
 
    if (!mode.show_pagers)
       return;
+
    if (queue_up)
      {
 	DrawQueue          *dq;
@@ -1297,31 +1303,26 @@ PagerShowMenu(Pager * p, int x, int y)
    p_menu->style =
       FindItem("DEFAULT", 0, LIST_FINDBY_NAME, LIST_TYPE_MENU_STYLE);
 
-   mi =
-      CreateMenuItem(_("Pager Settings..."), NULL, ACTION_CONFIG, "pager",
-		     NULL);
+   mi = CreateMenuItem(_("Pager Settings..."), NULL, ACTION_CONFIG, "pager",
+		       NULL);
    AddItemToMenu(p_menu, mi);
 
-   mi =
-      CreateMenuItem(_("Snapshotting On"), NULL, ACTION_SET_PAGER_SNAP, "1",
-		     NULL);
+   mi = CreateMenuItem(_("Snapshotting On"), NULL, ACTION_SET_PAGER_SNAP, "1",
+		       NULL);
    AddItemToMenu(p_menu, mi);
 
-   mi =
-      CreateMenuItem(_("Snapshotting Off"), NULL, ACTION_SET_PAGER_SNAP, "0",
-		     NULL);
+   mi = CreateMenuItem(_("Snapshotting Off"), NULL, ACTION_SET_PAGER_SNAP, "0",
+		       NULL);
    AddItemToMenu(p_menu, mi);
 
    if (SNAP)
      {
-	mi =
-	   CreateMenuItem(_("High Quality On"), NULL, ACTION_SET_PAGER_HIQ,
-			  "1", NULL);
+	mi = CreateMenuItem(_("High Quality On"), NULL, ACTION_SET_PAGER_HIQ,
+			    "1", NULL);
 	AddItemToMenu(p_menu, mi);
 
-	mi =
-	   CreateMenuItem(_("High Quality Off"), NULL, ACTION_SET_PAGER_HIQ,
-			  "0", NULL);
+	mi = CreateMenuItem(_("High Quality Off"), NULL, ACTION_SET_PAGER_HIQ,
+			    "0", NULL);
 	AddItemToMenu(p_menu, mi);
      }
    AddItem(p_menu, p_menu->name, 0, LIST_TYPE_MENU);
@@ -1374,9 +1375,8 @@ UpdatePagerSel(void)
 		  cy = desks.desk[p->desktop].current_area_y;
 		  EMoveWindow(disp, p->sel_win, cx * p->dw, cy * p->dh);
 		  EMapWindow(disp, p->sel_win);
-		  ic =
-		     FindItem("PAGER_SEL", 0, LIST_FINDBY_NAME,
-			      LIST_TYPE_ICLASS);
+		  ic = FindItem("PAGER_SEL", 0, LIST_FINDBY_NAME,
+				LIST_TYPE_ICLASS);
 		  if (ic)
 		     IclassApply(ic, p->sel_win, p->dw, p->dh, 0, 0,
 				 STATE_NORMAL, 0);
@@ -1422,8 +1422,11 @@ PagerHideHi(Pager * p)
 void
 PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 {
+   char                pq;
    ImageClass         *ic = NULL;
 
+   pq = queue_up;
+
    if (mode.pager_zoom)
      {
 	ic = FindItem("PAGER_WIN", 0, LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
@@ -1435,8 +1438,9 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 	     int                 xx, yy, ww, hh, i;
 
 	     im =
-		Imlib_create_image_from_drawable(id, ewin->mini_pmap, 0, 0, 0,
-						 ewin->mini_w, ewin->mini_h);
+		Imlib_create_image_from_drawable(pImlibData, ewin->mini_pmap, 0,
+						 0, 0, ewin->mini_w,
+						 ewin->mini_h);
 	     if (w > h)
 	       {
 		  for (i = w; i < (w * 2); i++)
@@ -1447,10 +1451,10 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 		       hh = (i * h) / w;
 		       xx = x + ((w - ww) / 2);
 		       yy = y + ((h - hh) / 2);
-		       Imlib_render(id, im, ww, hh);
-		       pmap = Imlib_move_image(id, im);
+		       Imlib_render(pImlibData, im, ww, hh);
+		       pmap = Imlib_move_image(pImlibData, im);
 		       ESetWindowBackgroundPixmap(disp, p->hi_win, pmap);
-		       Imlib_free_pixmap(id, pmap);
+		       Imlib_free_pixmap(pImlibData, pmap);
 		       EMoveResizeWindow(disp, p->hi_win, xx, yy, ww, hh);
 		       XClearWindow(disp, p->hi_win);
 		       {
@@ -1460,9 +1464,9 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 			  if ((px < x) || (py < y) || (px >= (x + w))
 			      || (py >= (y + h)))
 			    {
-			       Imlib_kill_image(id, im);
+			       Imlib_kill_image(pImlibData, im);
 			       EUnmapWindow(disp, p->hi_win);
-			       return;
+			       goto exit;
 			    }
 		       }
 		    }
@@ -1477,10 +1481,10 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 		       hh = i;
 		       xx = x + ((w - ww) / 2);
 		       yy = y + ((h - hh) / 2);
-		       Imlib_render(id, im, ww, hh);
-		       pmap = Imlib_move_image(id, im);
+		       Imlib_render(pImlibData, im, ww, hh);
+		       pmap = Imlib_move_image(pImlibData, im);
 		       ESetWindowBackgroundPixmap(disp, p->hi_win, pmap);
-		       Imlib_free_pixmap(id, pmap);
+		       Imlib_free_pixmap(pImlibData, pmap);
 		       EMoveResizeWindow(disp, p->hi_win, xx, yy, ww, hh);
 		       XClearWindow(disp, p->hi_win);
 		       {
@@ -1490,24 +1494,22 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 			  if ((px < x) || (py < y) || (px >= (x + w))
 			      || (py >= (y + h)))
 			    {
-			       Imlib_kill_image(id, im);
+			       Imlib_kill_image(pImlibData, im);
 			       EUnmapWindow(disp, p->hi_win);
-			       return;
+			       goto exit;
 			    }
 		       }
 		    }
 	       }
 	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2), w * 2,
 			       h * 2);
-	     Imlib_apply_image(id, im, p->hi_win);
-	     Imlib_kill_image(id, im);
+	     Imlib_apply_image(pImlibData, im, p->hi_win);
+	     Imlib_kill_image(pImlibData, im);
 	  }
 	else if (ic)
 	  {
-	     char                pq;
 	     int                 xx, yy, ww, hh, i;
 
-	     pq = queue_up;
 	     queue_up = 0;
 	     if (w > h)
 	       {
@@ -1529,7 +1531,7 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 			      || (py >= (y + h)))
 			    {
 			       EUnmapWindow(disp, p->hi_win);
-			       return;
+			       goto exit;
 			    }
 		       }
 		    }
@@ -1554,14 +1556,13 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 			      || (py >= (y + h)))
 			    {
 			       EUnmapWindow(disp, p->hi_win);
-			       return;
+			       goto exit;
 			    }
 		       }
 		    }
 	       }
 	     EMoveResizeWindow(disp, p->hi_win, x - (w / 2), y - (h / 2), w * 2,
 			       h * 2);
-	     queue_up = pq;
 	  }
 	else
 	  {
@@ -1574,11 +1575,11 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 	     r = 0;
 	     g = 0;
 	     b = 0;
-	     c1 = Imlib_best_color_match(id, &r, &g, &b);
+	     c1 = Imlib_best_color_match(pImlibData, &r, &g, &b);
 	     r = 255;
 	     g = 255;
 	     b = 255;
-	     c2 = Imlib_best_color_match(id, &r, &g, &b);
+	     c2 = Imlib_best_color_match(pImlibData, &r, &g, &b);
 	     pmap = ECreatePixmap(disp, p->hi_win, w * 2, h * 2, root.depth);
 	     ESetWindowBackgroundPixmap(disp, p->hi_win, pmap);
 	     if (!gc)
@@ -1606,7 +1607,7 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 			    {
 			       EFreePixmap(disp, pmap);
 			       EUnmapWindow(disp, p->hi_win);
-			       return;
+			       goto exit;
 			    }
 		       }
 		    }
@@ -1634,7 +1635,7 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 			    {
 			       EFreePixmap(disp, pmap);
 			       EUnmapWindow(disp, p->hi_win);
-			       return;
+			       goto exit;
 			    }
 		       }
 		    }
@@ -1645,6 +1646,7 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 	  }
 	p->hi_visible = 1;
      }
+
    if (mode.pager_title)
      {
 	ToolTip            *tt = NULL;
@@ -1656,6 +1658,9 @@ PagerShowHi(Pager * p, EWin * ewin, int x, int y, int w, int h)
 	     p->hi_visible = 1;
 	  }
      }
+
+ exit:
+   queue_up = pq;
 }
 
 void
