@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -214,11 +214,9 @@ SaveWindowStates(void)
 		       y = 0;
 		       if (!ewin->sticky)
 			 {
-			    x =
-			       desks.desk[ewin->desktop].current_area_x *
+			    x = desks.desk[ewin->desktop].current_area_x *
 			       root.w;
-			    y =
-			       desks.desk[ewin->desktop].current_area_y *
+			    y = desks.desk[ewin->desktop].current_area_y *
 			       root.h;
 			 }
 		       fprintf(f, "[CLIENT] %i %i %i %i %i %i %i %i %i\n",
@@ -239,7 +237,6 @@ SaveWindowStates(void)
 	       }
 	     fclose(f);
 	     Esnprintf(ss, sizeof(ss), "%s.clients.%i", GetSMFile(), root.scr);
-	     rm(ss);
 	     mv(s, ss);
 	     if (!isfile(ss))
 		Alert(_
@@ -327,6 +324,7 @@ MatchEwinToSM(EWin * ewin)
 
    if (GetSMfd() < 0)
       return;
+
    for (i = 0; i < num_match; i++)
      {
 	if ((!matches[i].used))
@@ -388,31 +386,26 @@ MatchEwinToSM(EWin * ewin)
 		   * This seems a bit kludgy to me. (: */
 	       }
 
-	     if (!ICCCM_GetEInfo(ewin))
+	     matches[i].used = 1;
+	     ewin->client.already_placed = 1;
+	     ewin->iconified = matches[i].iconified;
+	     ewin->sticky = matches[i].sticky;
+	     ewin->shaded = matches[i].shaded;
+	     ewin->layer = matches[i].layer;
+	     if (!ewin->sticky)
+		ewin->desktop = matches[i].desktop;
+	     /* if it's NOT (X11R6 and already placed by the client) */
+	     if (!((ewin->client.already_placed) && (ewin->session_id)))
 	       {
-		  matches[i].used = 1;
-		  ewin->client.already_placed = 1;
-		  ewin->iconified = matches[i].iconified;
-		  ewin->sticky = matches[i].sticky;
-		  ewin->shaded = matches[i].shaded;
-		  ewin->layer = matches[i].layer;
-		  if (!ewin->sticky)
-		     ewin->desktop = matches[i].desktop;
-		  /* if it's NOT (X11R6 and already placed by the client) */
-		  if (!((ewin->client.already_placed) && (ewin->session_id)))
-		    {
-		       ewin->client.x =
-			  matches[i].x -
-			  (desks.desk[ewin->desktop].current_area_x * root.w);
-		       ewin->client.y =
-			  matches[i].y -
-			  (desks.desk[ewin->desktop].current_area_y * root.h);
-		       ewin->client.w = matches[i].w;
-		       ewin->client.h = matches[i].h;
-		       EMoveResizeWindow(disp, ewin->client.win, ewin->client.x,
-					 ewin->client.y, ewin->client.w,
-					 ewin->client.h);
-		    }
+		  ewin->client.x = matches[i].x -
+		     (desks.desk[ewin->desktop].current_area_x * root.w);
+		  ewin->client.y = matches[i].y -
+		     (desks.desk[ewin->desktop].current_area_y * root.h);
+		  ewin->client.w = matches[i].w;
+		  ewin->client.h = matches[i].h;
+		  EMoveResizeWindow(disp, ewin->client.win, ewin->client.x,
+				    ewin->client.y, ewin->client.w,
+				    ewin->client.h);
 	       }
 	     break;
 	  }
@@ -432,7 +425,6 @@ autosave(void)
 	Real_SaveSnapInfo(0, NULL);
 	Etmp(s);
 	SaveUserControlConfig(fopen(s, "w"));
-	rm(GetGenericSMFile());
 	mv(s, GetGenericSMFile());
 	if (!isfile(GetGenericSMFile()))
 	   Alert(_
@@ -458,8 +450,7 @@ autosave(void)
      }
 }
 
-#ifndef HAVE_SM
-static void         LogoutCB(int val, void *data);
+#ifndef HAVE_X11_SM_SMLIB_H
 
 void
 SessionInit(void)
@@ -505,7 +496,6 @@ LogoutCB(int val, void *data)
    data = NULL;
 }
 
-static void         CB_SettingsEscape(int val, void *data);
 static void
 CB_SettingsEscape(int val, void *data)
 {
@@ -591,9 +581,11 @@ doSMExit(void *params)
 	  }
 	else if (!strcmp(s, "restart_wm"))
 	  {
+#if ENABLE_KDE
 	     /* kill off kde */
 	     if (mode.kde_support)
 		KDE_Shutdown();
+#endif
 	     AUDIO_PLAY("SOUND_EXIT");
 	     if (sound_fd >= 0)
 		close(sound_fd);
@@ -634,72 +626,29 @@ doSMExit(void *params)
 	     ewin = FindEwinByDialog(d);
 	     if (ewin)
 	       {
-#ifdef HAS_XINERAMA
-		  if (xinerama_active)
-		    {
-		       Window              rt, ch;
-		       XineramaScreenInfo *screens;
-		       int                 pointer_x, pointer_y;
-		       int                 num;
-		       int                 d;
-		       unsigned int        ud;
-		       int                 i;
-
-		       XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
-				     &pointer_y, &d, &d, &ud);
-		       screens = XineramaQueryScreens(disp, &num);
-		       for (i = 0; i < num; i++)
-			 {
-			    if (pointer_x >= screens[i].x_org)
-			      {
-				 if (pointer_x <=
-				     (screens[i].width + screens[i].x_org))
-				   {
-				      if (pointer_y >= screens[i].y_org)
-					{
-					   if (pointer_y <=
-					       (screens[i].height +
-						screens[i].y_org))
-					     {
-						ewin->x =
-						   ((screens[i].width - ewin->w)
-						    / 2) + screens[i].x_org;
-						ewin->y =
-						   ((screens
-						     [i].height -
-						     ewin->h) / 2) +
-						   screens[i].y_org;
-					     }
-					}
-				   }
-			      }
-			 }
-		       XFree(screens);
-		       MoveEwin(ewin, ewin->x, ewin->y);
-		       FocusToEWin(ewin);
-		    }
-		  else
-		    {
-#endif
-		       MoveEwin(ewin, ((root.w - (ewin->w)) / 2),
-				((root.h - (ewin->h)) / 2));
-		       FocusToEWin(ewin);
-#ifdef HAS_XINERAMA
-		    }
-#endif
+		  ArrangeEwinCentered(ewin, 1);
 	       }
 	     return;
 	  }
      }
+#if ENABLE_KDE
    /* kill off kde */
    if (mode.kde_support)
       KDE_Shutdown();
+#endif
    AUDIO_PLAY("SOUND_EXIT");
    EExit(0);
 }
-#else /* HAVE_SM */
+
+#else /* HAVE_X11_SM_SMLIB_H */
+
 #include <X11/SM/SMlib.h>
 
+/*
+ * NB! If the discard property is revived, the dual use of buf must be fixed.
+ */
+#define USE_DISCARD_PROPERTY 0
+
 static char        *sm_client_id = NULL;
 static SmcConn      sm_conn = NULL;
 static int          sm_fd = -1;
@@ -707,23 +656,6 @@ static int          sm_fd = -1;
 /* True if we are saving state for a doExit("restart") */
 static int          restarting = False;
 
-static void         LogoutCB(int val, void *data);
-static void         set_save_props(SmcConn smc_conn, int master_flag);
-static void         callback_save_yourself2(SmcConn smc_conn,
-
-					    SmPointer client_data);
-static void         callback_save_yourself(SmcConn smc_conn,
-					   SmPointer client_data,
-					   int save_style, Bool shutdown,
-					   int interact_style, Bool fast);
-static void         callback_die(SmcConn smc_conn, SmPointer client_data);
-static void         callback_save_complete(SmcConn smc_conn,
-
-					   SmPointer client_data);
-static void         callback_shutdown_cancelled(SmcConn smc_conn,
-
-						SmPointer client_data);
-
 static void
 set_save_props(SmcConn smc_conn, int master_flag)
 {
@@ -738,19 +670,22 @@ set_save_props(SmcConn smc_conn, int master_flag)
    char               *ecachedir = "-ecachedir";
    char               *e_cache_dir;
    char               *extinitwin = "-ext_init_win";
-   char               *sh = "sh";
-   char               *c = "-c";
    char                buf[512];
    char                priority = 10;
    char                style;
-   int                 n = 0;
+   int                 n;
    SmPropValue         programVal = { 0, NULL };
    SmPropValue         userIDVal = { 0, NULL };
+#if USE_DISCARD_PROPERTY
+   char               *sh = "sh";
+   char               *c = "-c";
    SmPropValue         discardVal[] = {
       {0, NULL},
       {0, NULL},
       {0, NULL}
    };
+   SmProp              discardProp;
+#endif
    SmPropValue         restartVal[] = {
       {0, NULL},
       {0, NULL},
@@ -767,7 +702,6 @@ set_save_props(SmcConn smc_conn, int master_flag)
    SmPropValue         priorityVal = { 0, NULL };
    SmProp              programProp;
    SmProp              userIDProp;
-   SmProp              discardProp;
    SmProp              restartProp;
    SmProp              cloneProp;
    SmProp              styleProp;
@@ -784,10 +718,12 @@ set_save_props(SmcConn smc_conn, int master_flag)
    userIDProp.num_vals = 1;
    userIDProp.vals = &userIDVal;
 
+#if USE_DISCARD_PROPERTY
    discardProp.name = (char *)SmDiscardCommand;
    discardProp.type = (char *)SmLISTofARRAY8;
    discardProp.num_vals = 3;
    discardProp.vals = (SmPropValue *) & discardVal;
+#endif
 
    restartProp.name = (char *)SmRestartCommand;
    restartProp.type = (char *)SmLISTofARRAY8;
@@ -807,14 +743,6 @@ set_save_props(SmcConn smc_conn, int master_flag)
    priorityProp.num_vals = 1;
    priorityProp.vals = (SmPropValue *) & priorityVal;
 
-   props[0] = &programProp;
-   props[1] = &userIDProp;
-   props[2] = &discardProp;
-   props[3] = &restartProp;
-   props[4] = &cloneProp;
-   props[5] = &styleProp;
-   props[6] = &priorityProp;
-
    if (master_flag)
       /* Master WM restarts immediately for a doExit("restart") */
       style = restarting ? SmRestartImmediately : SmRestartIfRunning;
@@ -838,6 +766,7 @@ set_save_props(SmcConn smc_conn, int master_flag)
    priorityVal.length = 1;
    priorityVal.value = &priority;
 
+#if USE_DISCARD_PROPERTY
    /* Tell session manager how to clean up our old data */
    Esnprintf(buf, sizeof(buf) / sizeof(char), "rm %s*.clients.*", sm_file);
 
@@ -846,8 +775,10 @@ set_save_props(SmcConn smc_conn, int master_flag)
    discardVal[1].length = strlen(c);
    discardVal[1].value = c;
    discardVal[2].length = strlen(buf);
-   discardVal[2].value = buf;
+   discardVal[2].value = buf;	/* ??? Also used in restartVal ??? */
+#endif
 
+   n = 0;
    restartVal[n].length = strlen(command);
    restartVal[n++].value = command;
    if (single_screen_mode)
@@ -886,7 +817,18 @@ set_save_props(SmcConn smc_conn, int master_flag)
    /* SM specs require SmCloneCommand excludes "-smid" option */
    cloneProp.num_vals = restartProp.num_vals - 2;
 
-   SmcSetProperties(smc_conn, sizeof(props) / sizeof(props[0]), props);
+   n = 0;
+   props[n++] = &programProp;
+   props[n++] = &userIDProp;
+#if USE_DISCARD_PROPERTY
+   props[n++] = &discardProp;
+#endif
+   props[n++] = &restartProp;
+   props[n++] = &cloneProp;
+   props[n++] = &styleProp;
+   props[n++] = &priorityProp;
+
+   SmcSetProperties(smc_conn, n, props);
    if (user)
       Efree(user);
 }
@@ -1175,7 +1117,6 @@ SaveSession(int shutdown)
      }
 }
 
-static void         CB_SettingsEscape(int val, void *data);
 static void
 CB_SettingsEscape(int val, void *data)
 {
@@ -1207,6 +1148,7 @@ doSMExit(void *params)
    if (params)
       sscanf(params, "%1000s", s);
 
+   SaveWindowStates();
    if (!params)
       SaveSession(1);
    if ((disp) && ((!params) || ((params) && strcmp((char *)params, "logout"))))
@@ -1240,68 +1182,18 @@ doSMExit(void *params)
 	ewin = FindEwinByDialog(d);
 	if (ewin)
 	  {
-#ifdef HAS_XINERAMA
-	     if (xinerama_active)
-	       {
-		  Window              rt, ch;
-		  XineramaScreenInfo *screens;
-		  int                 pointer_x, pointer_y;
-		  int                 num;
-		  int                 d;
-		  int                 i;
-		  unsigned int        ud;
-
-		  XQueryPointer(disp, root.win, &rt, &ch, &pointer_x,
-				&pointer_y, &d, &d, &ud);
-		  screens = XineramaQueryScreens(disp, &num);
-		  for (i = 0; i < num; i++)
-		    {
-		       if (pointer_x >= screens[i].x_org)
-			 {
-			    if (pointer_x <=
-				(screens[i].width + screens[i].x_org))
-			      {
-				 if (pointer_y >= screens[i].y_org)
-				   {
-				      if (pointer_y <=
-					  (screens[i].height +
-					   screens[i].y_org))
-					{
-					   ewin->x =
-					      ((screens[i].width - ewin->w) /
-					       2) + screens[i].x_org;
-					   ewin->y =
-					      ((screens[i].height - ewin->h) /
-					       2) + screens[i].y_org;
-					}
-				   }
-			      }
-			 }
-		    }
-		  XFree(screens);
-		  MoveEwin(ewin, ewin->x, ewin->y);
-		  FocusToEWin(ewin);
-	       }
-	     else
-	       {
-#endif
-
-		  MoveEwin(ewin, ((root.w - (ewin->w)) / 2),
-			   ((root.h - (ewin->h)) / 2));
-		  FocusToEWin(ewin);
-#ifdef HAS_XINERAMA
-	       }
-#endif
-
+	     ArrangeEwinCentered(ewin, 1);
 	  }
 	return;
      }
    else if (!strcmp(s, "restart_wm"))
      {
 	AUDIO_PLAY("SOUND_WAIT");
+#if ENABLE_KDE
 	/* kill off kde */
 	if (mode.kde_support)
 	   KDE_Shutdown();
+#endif
 	XCloseDisplay(disp);
 	disp = NULL;
 	Esnprintf(s, sizeof(s), "exec %s -display %s", atword(params, 2), dstr);
@@ -1385,13 +1277,15 @@ doSMExit(void *params)
    else if (!strcmp((char *)s, "error"))
       EExit(0);
 
+#if ENABLE_KDE
    /* kill off kde */
    if (mode.kde_support)
       KDE_Shutdown();
+#endif
    restarting = False;
    SaveSession(1);
    AUDIO_PLAY("SOUND_EXIT");
    EExit(0);
 }
 
-#endif /* HAVE_SM */
+#endif /* HAVE_X11_SM_SMLIB_H */
