@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -109,93 +109,6 @@ MapUnmap(int start)
    EDBUG_RETURN_;
 }
 
-void
-SetupSignals()
-{
-
-   /* This function will set up all the signal handlers for E */
-
-   struct sigaction    sa;
-
-   EDBUG(6, "SetupSignals");
-
-   sa.sa_handler = HandleSigHup;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGHUP, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigInt;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGINT, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigQuit;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGQUIT, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigIll;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGILL, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigAbrt;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGABRT, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigFpe;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGFPE, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigSegv;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGSEGV, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigPipe;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGPIPE, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigAlrm;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGALRM, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigTerm;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGTERM, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigUsr1;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGUSR1, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigUsr2;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGUSR2, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigChild;
-#ifndef __EMX__
-   sa.sa_flags = SA_RESTART;
-#else
-   sa.sa_flags = 0;
-#endif
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGCHLD, &sa, (struct sigaction *)0);
-
-   sa.sa_handler = HandleSigBus;
-   sa.sa_flags = 0;
-   sigemptyset(&sa.sa_mask);
-   sigaction(SIGBUS, &sa, (struct sigaction *)0);
-
-   EDBUG_RETURN_;
-}
-
 void
 SetupX()
 {
@@ -272,8 +185,7 @@ SetupX()
 			    if (NULL != dispstr)
 			       *dispstr = '\0';
 			 }
-		       Esnprintf(subdisplay + strlen(subdisplay), 10, ".%d",
-				 i);
+		       Esnprintf(subdisplay + strlen(subdisplay), 10, ".%d", i);
 		       dstr = duplicate(subdisplay);
 		       disp = XOpenDisplay(dstr);
 		       root.scr = i;
@@ -320,8 +232,8 @@ SetupX()
    /* record the event base for shape change events */
    event_base_shape = shape_event_base;
    /* initialise imlib */
-   id = Imlib_init(disp);
-   if (!id)
+   pImlibData = Imlib_init(disp);
+   if (!pImlibData)
      {
 	ASSIGN_ALERT(_("Imlib initialisation error"), "", "",
 		     _("Quit Enlightenment"));
@@ -332,8 +244,9 @@ SetupX()
 	RESET_ALERT;
 	EExit((void *)1);
      }
-   fd = Fnlib_init(id);
-   if (!fd)
+#if USE_FNLIB
+   pFnlibData = Fnlib_init(pImlibData);
+   if (!pFnlibData)
      {
 	ASSIGN_ALERT(_("X server setup error"), "", "",
 		     _("Quit Enlightenment"));
@@ -344,10 +257,11 @@ SetupX()
 	RESET_ALERT;
 	EExit((void *)1);
      }
-   root.win = id->x.root;
-   root.vis = Imlib_get_visual(id);
-   root.depth = id->x.depth;
-   root.cmap = Imlib_get_colormap(id);
+#endif
+   root.win = pImlibData->x.root;
+   root.vis = Imlib_get_visual(pImlibData);
+   root.depth = pImlibData->x.depth;
+   root.cmap = Imlib_get_colormap(pImlibData);
    root.w = DisplayWidth(disp, root.scr);
    root.h = DisplayHeight(disp, root.scr);
    root.focuswin = ECreateFocusWindow(root.win, -100, -100, 5, 5);
@@ -358,10 +272,12 @@ SetupX()
 
 	p.flags = PARAMS_VISUALID;
 	p.visualid = XVisualIDFromVisual(DefaultVisual(disp, root.scr));
-	ird = Imlib_init_with_params(disp, &p);
+	prImlibData = Imlib_init_with_params(disp, &p);
      }
    else
-      ird = NULL;
+     {
+	prImlibData = NULL;
+     }
    /* just in case - set them up again */
    /* set up an error handler for then E would normally have fatal X errors */
    XSetErrorHandler((XErrorHandler) EHandleXError);
@@ -377,22 +293,6 @@ SetupX()
 		SubstructureNotifyMask);
    XSync(disp, False);
    mode.xselect = 0;
-   /* Init XKB to pick up release of alt modifier */
-   WarpFocusInitEvents();
-   {
-      Atom                atom_set;
-      CARD32              val;
-
-      atom_set = XInternAtom(disp, "_WIN_DESKTOP_BUTTON_PROXY", False);
-      bpress_win = ECreateWindow(root.win, -80, -80, 24, 24, 0);
-      val = bpress_win;
-      XChangeProperty(disp, root.win, atom_set, XA_CARDINAL, 32,
-		      PropModeReplace, (unsigned char *)&val, 1);
-      XChangeProperty(disp, bpress_win, atom_set, XA_CARDINAL, 32,
-		      PropModeReplace, (unsigned char *)&val, 1);
-   }
-
-   XSync(disp, False);
 
    /* warn, if necessary about X version problems */
    if (ProtocolVersion(disp) != 11)
@@ -460,7 +360,7 @@ SetupX()
       mask_mod_combos[7] = LockMask | numlock_mask | scrollock_mask;
 
       if (mod)
-	 XFree(mod);
+	 XFreeModifiermap(mod);
    }
    /* Now we're going to set a bunch of default settings in E - in case we
     * don't ever get to load a config file for some odd reason.
@@ -537,7 +437,6 @@ SetupX()
    mode.numdesktops = 2;
    mode.transientsfollowleader = 1;
    mode.switchfortransientmap = 1;
-   mode.showicons = 1;
    mode.snap = 1;
    mode.edge_snap_dist = 8;
    mode.screen_snap_dist = 32;
@@ -548,11 +447,13 @@ SetupX()
    mode.manual_placement = 0;
    mode.raise_on_next_focus = 1;
    mode.raise_after_next_focus = 1;
+#if ENABLE_KDE
    mode.kde_support = 0;
    mode.kde_x1 = 0;
    mode.kde_y1 = 0;
    mode.kde_x2 = root.w;
    mode.kde_y2 = root.h;
+#endif
 #ifdef WITH_TARTY_WARP
    mode.display_warp = 1;
 #else
@@ -615,10 +516,7 @@ SetupX()
    desks.hiqualitybg = 1;
    SetAreaSize(2, 1);
 
-#ifdef HAS_XINERAMA
-   xinerama_active = XineramaIsActive(disp);
-   mode.extra_head = 0;
-#endif
+   ScreenInit();
 
    for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; task_menu[i++] = NULL);
 
@@ -741,7 +639,6 @@ SetupEnv()
 #else
    Esetenv("EROOT", __XOS2RedirRoot(ENLIGHTENMENT_ROOT), 1);
 #endif
-   Esetenv("EROOT", ENLIGHTENMENT_ROOT, 1);
    Esetenv("EBIN", ENLIGHTENMENT_BIN, 1);
    Esnprintf(s, sizeof(s), "%i", getpid());
    Esetenv("EPID", s, 1);
@@ -755,7 +652,8 @@ SetupEnv()
    return;
 }
 
-Window MakeExtInitWin(void)
+Window
+MakeExtInitWin(void)
 {
    Display            *d2;
    Window              win;
@@ -792,26 +690,12 @@ Window MakeExtInitWin(void)
 
 	return win;
      }
+
    /* on solairs connection stays up - close */
    XSetErrorHandler((XErrorHandler) NULL);
    XSetIOErrorHandler((XIOErrorHandler) NULL);
-   signal(SIGHUP, SIG_DFL);
-   signal(SIGINT, SIG_DFL);
-   signal(SIGQUIT, SIG_DFL);
-   signal(SIGILL, SIG_DFL);
-   signal(SIGABRT, SIG_DFL);
-   signal(SIGFPE, SIG_IGN);
-   signal(SIGSEGV, SIG_IGN);
-   signal(SIGPIPE, SIG_IGN);
-   signal(SIGALRM, SIG_DFL);
-   signal(SIGTERM, SIG_DFL);
-   signal(SIGUSR1, SIG_DFL);
-   signal(SIGUSR2, SIG_DFL);
-   signal(SIGCHLD, SIG_DFL);
-#ifdef SIGTSTP
-   signal(SIGTSTP, SIG_DFL);
-#endif
-   signal(SIGBUS, SIG_IGN);
+
+   SignalsRestore();
 
    d2 = XOpenDisplay(DisplayString(disp));
    close(ConnectionNumber(disp));
@@ -878,11 +762,10 @@ Window MakeExtInitWin(void)
 	GC                  gc;
 	XGCValues           gcv;
 
-	w2 =
-	   XCreateWindow(d2, win, 0, 0, 32, 32, 0, root.depth, InputOutput,
-			 root.vis,
-			 CWOverrideRedirect | CWBackingStore | CWColormap |
-			 CWBackPixel | CWBorderPixel, &attr);
+	w2 = XCreateWindow(d2, win, 0, 0, 32, 32, 0, root.depth, InputOutput,
+			   root.vis,
+			   CWOverrideRedirect | CWBackingStore | CWColormap |
+			   CWBackPixel | CWBorderPixel, &attr);
 	pmap = ECreatePixmap(d2, w2, 16, 16, 1);
 	gc = XCreateGC(d2, pmap, 0, &gcv);
 	XSetForeground(d2, gc, 0);
@@ -972,7 +855,8 @@ SetupUserInitialization(void)
 	fclose(f);
 	if (fork())
 	   EDBUG_RETURN_;
-	Esnprintf(file, sizeof(file), "exec %s/e_gen_menu", ENLIGHTENMENT_BIN);
+	Esnprintf(file, sizeof(file), "exec %s/scripts/e_gen_menu",
+		  ENLIGHTENMENT_ROOT);
 	execl(usershell(getuid()), usershell(getuid()), "-c", (char *)file,
 	      NULL);
 	exit(0);
