@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -291,12 +291,12 @@ CalcSlideoutSize(Slideout * s)
 	  {
 	  case 2:
 	     y += s->button[i]->h;
-	     EMoveWindow(disp, s->button[i]->win, (s->w - s->button[i]->w) >> 1,
-			 s->h - y);
+	     EMoveWindow(disp, s->button[i]->win,
+			 (s->w - s->button[i]->w) >> 1, s->h - y);
 	     break;
 	  case 3:
-	     EMoveWindow(disp, s->button[i]->win, (s->w - s->button[i]->w) >> 1,
-			 y);
+	     EMoveWindow(disp, s->button[i]->win,
+			 (s->w - s->button[i]->w) >> 1, y);
 	     y += s->button[i]->h;
 	     break;
 	  case 0:
@@ -336,7 +336,7 @@ AddButtonToSlideout(Slideout * s, Button * b)
    b->default_show = 0;
    b->flags |= FLAG_FIXED;
    b->used = 1;
-   SimpleShowButton(b);
+   ShowButton(b);
    CalcSlideoutSize(s);
 
    EDBUG_RETURN_;
