@@ -1,6 +1,6 @@
 
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -826,9 +826,8 @@ UnsnapshotEwin(EWin * ewin)
      {
 	ListChangeItemID(LIST_TYPE_SNAPSHOT, ewin->snap, 0);
 	ewin->snap->used = 0;
-	sn =
-	   RemoveItem((char *)ewin->snap, 0, LIST_FINDBY_POINTER,
-		      LIST_TYPE_SNAPSHOT);
+	sn = RemoveItem((char *)ewin->snap, 0, LIST_FINDBY_POINTER,
+			LIST_TYPE_SNAPSHOT);
 	ewin->snap = NULL;
      }
    else
@@ -871,6 +870,7 @@ Real_SaveSnapInfo(int dumval, void *dumdat)
    f = fopen(s, "w");
    if (!f)
       return;
+
    lst = (Snapshot **) ListItemType(&num, LIST_TYPE_SNAPSHOT);
    if (lst)
      {
@@ -921,12 +921,14 @@ Real_SaveSnapInfo(int dumval, void *dumdat)
 	  }
 	Efree(lst);
      }
+
    fclose(f);
+
    Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetGenericSMFile(), root.scr);
-   rm(buf);
    mv(s, buf);
    if (!isfile(buf))
       Alert(_("Error saving snaps file\n"));
+
    SaveGroups();
 }
 
@@ -943,7 +945,7 @@ SpawnSnappedCmds(void)
 	for (i = 0; i < num; i++)
 	  {
 	     sn = lst[i];
-	     if ((sn->use_cmd) && (sn->cmd))
+	     if ((sn->use_cmd) && (sn->cmd) && !sn->used)
 		execApplication(sn->cmd);
 	  }
 	Efree(lst);
@@ -962,7 +964,7 @@ LoadSnapInfo(void)
    Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetSMFile(), root.scr);
    if (!exists(buf))
       Esnprintf(buf, sizeof(buf), "%s.snapshots.%i", GetGenericSMFile(),
-                root.scr);
+		root.scr);
 #ifndef __EMX__
    f = fopen(buf, "r");
 #else
@@ -1113,7 +1115,6 @@ LoadSnapInfo(void)
 		  word(buf, 2, s);
 		  sn->num_groups++;
 		  sn->groups =
-
 		     Erealloc(sn->groups, sizeof(int) * sn->num_groups);
 
 		  sn->groups[sn->num_groups - 1] = atoi(s);
@@ -1196,9 +1197,8 @@ MatchEwinToSnapInfo(EWin * ewin)
      }
    if (sn->border_name)
      {
-	b =
-	   (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_BORDER);
+	b = (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
+				LIST_TYPE_BORDER);
 	if (b)
 	  {
 	     ewin->border_new = 1;
@@ -1212,9 +1212,8 @@ MatchEwinToSnapInfo(EWin * ewin)
 	  {
 	     Group              *g;
 
-	     g =
-		(Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
-				   LIST_TYPE_GROUP);
+	     g = (Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
+				    LIST_TYPE_GROUP);
 	     if (!g)
 	       {
 		  BuildWindowGroup(&ewin, 1);
@@ -1369,9 +1368,8 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
      }
    if (sn->border_name)
      {
-	b =
-	   (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
-			       LIST_TYPE_BORDER);
+	b = (Border *) FindItem(sn->border_name, 0, LIST_FINDBY_NAME,
+				LIST_TYPE_BORDER);
 	if (b)
 	  {
 	     ewin->border_new = 1;
@@ -1387,9 +1385,8 @@ MatchEwinToSnapInfoAfter(EWin * ewin)
 	  {
 	     Group              *g;
 
-	     g =
-		(Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
-				   LIST_TYPE_GROUP);
+	     g = (Group *) FindItem(NULL, sn->groups[i], LIST_FINDBY_ID,
+				    LIST_TYPE_GROUP);
 	     if (!g)
 	       {
 		  BuildWindowGroup(&ewin, 1);
