@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -57,7 +57,6 @@
 
 static void         dopr(char *buffer, const char *format, va_list args);
 static void         fmtstr(char *value, int ljust, int len, int zpad,
-
 			   int precision);
 static void         fmtnum(long value, int base, int dosign, int ljust, int len,
 			   int zpad, int precision);
@@ -82,7 +81,7 @@ Evsnprintf(char *str, size_t count, const char *fmt, va_list args)
    return (strlen(str));
 }
 
-#ifdef HAVE_STDARGS
+#ifdef HAVE_STDARG_H
 int
 Esnprintf(char *str, size_t count, const char *fmt, ...)
 #else
@@ -91,7 +90,7 @@ Esnprintf(va_alist)
      va_dcl
 #endif
 {
-#ifndef HAVE_STDARGS
+#ifndef HAVE_STDARG_H
    char               *str;
    size_t              count;
    char               *fmt;
