@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -180,16 +180,13 @@ CreateStartupDisplay(char start)
 	bg_sideways =
 	   (Background *) FindItem("STARTUP_BACKGROUND_SIDEWAYS", 0,
 				   LIST_FINDBY_NAME, LIST_TYPE_BACKGROUND);
-	ic =
-	   (ImageClass *) FindItem("STARTUP_BAR", 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_ICLASS);
+	ic = (ImageClass *) FindItem("STARTUP_BAR", 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_ICLASS);
 	if (!ic)
-	   ic =
-	      (ImageClass *) FindItem("DESKTOP_DRAGBUTTON_HORIZ", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
-	bg =
-	   (Background *) FindItem("STARTUP_BACKGROUND", 0, LIST_FINDBY_NAME,
-				   LIST_TYPE_BACKGROUND);
+	   ic = (ImageClass *) FindItem("DESKTOP_DRAGBUTTON_HORIZ", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+	bg = (Background *) FindItem("STARTUP_BACKGROUND", 0, LIST_FINDBY_NAME,
+				     LIST_TYPE_BACKGROUND);
 	if ((!ic) || (!bg))
 	   EDBUG_RETURN_;
 
@@ -211,9 +208,8 @@ CreateStartupDisplay(char start)
 	EMapWindow(disp, win1);
 	EMapWindow(disp, win2);
 
-	b1 =
-	   ECreateWindow(w1, 0, root.h - desks.dragbar_width, root.w,
-			 desks.dragbar_width, 0);
+	b1 = ECreateWindow(w1, 0, root.h - desks.dragbar_width, root.w,
+			   desks.dragbar_width, 0);
 	b2 = ECreateWindow(w2, 0, 0, root.w, desks.dragbar_width, 0);
 	EMapRaised(disp, b1);
 	EMapRaised(disp, b2);
@@ -223,16 +219,15 @@ CreateStartupDisplay(char start)
 	IclassApply(ic, b1, root.w, desks.dragbar_width, 0, 0, 0, 0);
 	IclassApply(ic, b2, root.w, desks.dragbar_width, 0, 0, 0, 0);
 	queue_up = pq;
-	SetBackgroundTo(id, win1, bg, 1);
-	SetBackgroundTo(id, win2, bg, 1);
+	SetBackgroundTo(pImlibData, win1, bg, 1);
+	SetBackgroundTo(pImlibData, win2, bg, 1);
 	if (bg->pmap)
-	   Imlib_free_pixmap(id, bg->pmap);
+	   Imlib_free_pixmap(pImlibData, bg->pmap);
 	bg->pmap = 0;
 	init_win1 = w1;
 	init_win2 = w2;
-	StackDesktops();
-	EMapWindow(disp, w1);
-	EMapWindow(disp, w2);
+	EMapRaised(disp, w1);
+	EMapRaised(disp, w2);
      }
    else
      {
