@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -139,13 +139,23 @@ void
 TextStateLoadFont(TextState * ts)
 {
    EDBUG(5, "TextStateLoadFont");
+#if USE_FNLIB
    if ((ts->font) || (ts->efont) || (ts->xfont) || (ts->xfontset))
+#else
+   if ((ts->efont) || (ts->xfont) || (ts->xfontset))
+#endif
       EDBUG_RETURN_;
    if (!ts->fontname)
       EDBUG_RETURN_;
+#if USE_FNLIB
    if ((!ts->font) && (!ts->efont))
-      ts->font = Fnlib_load_font(fd, ts->fontname);
+      ts->font = Fnlib_load_font(pFnlibData, ts->fontname);
+#endif
+#if USE_FNLIB
    if ((!ts->font) && (!ts->efont))
+#else
+   if (!ts->efont)
+#endif
      {
 	char                s[4096], w[4046], *dup, *ss;
 
@@ -168,7 +178,11 @@ TextStateLoadFont(TextState * ts)
 	if (dup)
 	   Efree(dup);
      }
+#if USE_FNLIB
    if ((!ts->font) && (!ts->efont))
+#else
+   if (!ts->efont)
+#endif
      {
 	if ((!ts->xfont) && (strchr(ts->fontname, ',') == NULL))
 	  {
@@ -218,21 +232,25 @@ TextSize(TextClass * tclass, int active, int sticky, int state, char *text,
    if (!ts)
       EDBUG_RETURN_;
    TextStateLoadFont(ts);
+#if USE_FNLIB
    if (ts->font)
      {
 	for (i = 0; i < num_lines; i++)
 	  {
 	     int                 high, wid, dummy;
 
-	     Fnlib_measure(fd, ts->font, 0, 0, 999999, 999999, 0, 0, fsize,
-			   &ts->style, (unsigned char *)lines[i], 0, 0, &dummy,
-			   &dummy, &wid, &high, &dummy, &dummy, &dummy, &dummy);
+	     Fnlib_measure(pFnlibData, ts->font, 0, 0, 999999, 999999, 0, 0,
+			   fsize, &ts->style, (unsigned char *)lines[i], 0, 0,
+			   &dummy, &dummy, &wid, &high, &dummy, &dummy, &dummy,
+			   &dummy);
 	     *height += high;
 	     if (wid > *width)
 		*width = wid;
 	  }
      }
-   else if (ts->efont)
+   else
+#endif
+   if (ts->efont)
      {
 	for (i = 0; i < num_lines; i++)
 	  {
@@ -318,29 +336,34 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
       gc = XCreateGC(disp, win, 0, &gcv);
 
    if (ts->style.orientation == FONT_TO_RIGHT
-       || ts->style.orientation == FONT_TO_LEFT) textwidth_limit = w;
+       || ts->style.orientation == FONT_TO_LEFT)
+      textwidth_limit = w;
    else
       textwidth_limit = h;
 
+#if USE_FNLIB
    if (ts->font)
      {
 	for (i = 0; i < num_lines; i++)
 	  {
 	     int                 high, wid, dummy;
 
-	     Fnlib_measure(fd, ts->font, 0, 0, 999999, 999999, 0, 0, fsize,
-			   &ts->style, (unsigned char *)lines[i], 0, 0, &dummy,
-			   &dummy, &wid, &high, &dummy, &dummy, &dummy, &dummy);
+	     Fnlib_measure(pFnlibData, ts->font, 0, 0, 999999, 999999, 0, 0,
+			   fsize, &ts->style, (unsigned char *)lines[i], 0, 0,
+			   &dummy, &dummy, &wid, &high, &dummy, &dummy, &dummy,
+			   &dummy);
 	     if ((ts->style.orientation == FONT_TO_UP)
 		 || (ts->style.orientation == FONT_TO_DOWN))
 		fsize = w;
 	     xx = x + (((w - wid) * justification) >> 10);
-	     Fnlib_draw(fd, ts->font, win, 0, xx, yy, w, h, 0, 0, fsize,
+	     Fnlib_draw(pFnlibData, ts->font, win, 0, xx, yy, w, h, 0, 0, fsize,
 			&ts->style, (unsigned char *)lines[i]);
 	     yy += high;
 	  }
      }
-   else if (ts->efont)
+   else
+#endif
+   if (ts->efont)
      {
 	for (i = 0; i < num_lines; i++)
 	  {
@@ -406,11 +429,12 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  EFont_draw_string(disp, drawable, gc, offset_x + 1,
 				    offset_y + 1, lines[i], ts->efont,
-				    Imlib_get_visual(id),
-				    Imlib_get_colormap(id));
+				    Imlib_get_visual(pImlibData),
+				    Imlib_get_colormap(pImlibData));
 	       }
 	     else if (ts->effect == 2)
 	       {
@@ -418,27 +442,33 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  EFont_draw_string(disp, drawable, gc, offset_x - 1, offset_y,
-				    lines[i], ts->efont, Imlib_get_visual(id),
-				    Imlib_get_colormap(id));
+				    lines[i], ts->efont,
+				    Imlib_get_visual(pImlibData),
+				    Imlib_get_colormap(pImlibData));
 		  EFont_draw_string(disp, drawable, gc, offset_x + 1, offset_y,
-				    lines[i], ts->efont, Imlib_get_visual(id),
-				    Imlib_get_colormap(id));
+				    lines[i], ts->efont,
+				    Imlib_get_visual(pImlibData),
+				    Imlib_get_colormap(pImlibData));
 		  EFont_draw_string(disp, drawable, gc, offset_x, offset_y - 1,
-				    lines[i], ts->efont, Imlib_get_visual(id),
-				    Imlib_get_colormap(id));
+				    lines[i], ts->efont,
+				    Imlib_get_visual(pImlibData),
+				    Imlib_get_colormap(pImlibData));
 		  EFont_draw_string(disp, drawable, gc, offset_x, offset_y + 1,
-				    lines[i], ts->efont, Imlib_get_visual(id),
-				    Imlib_get_colormap(id));
+				    lines[i], ts->efont,
+				    Imlib_get_visual(pImlibData),
+				    Imlib_get_colormap(pImlibData));
 	       }
 	     r = ts->fg_col.r;
 	     g = ts->fg_col.g;
 	     b = ts->fg_col.b;
-	     XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
+	     XSetForeground(disp, gc,
+			    Imlib_best_color_match(pImlibData, &r, &g, &b));
 	     EFont_draw_string(disp, drawable, gc, offset_x, offset_y, lines[i],
-			       ts->efont, Imlib_get_visual(id),
-			       Imlib_get_colormap(id));
+			       ts->efont, Imlib_get_visual(pImlibData),
+			       Imlib_get_colormap(pImlibData));
 
 	     TextDrawRotBack(win, drawable, xx - 1, yy - 1 - ascent, wid + 2,
 			     ascent + descent + 2, ts);
@@ -563,7 +593,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  XmbDrawString(disp, drawable, ts->xfontset, gc, offset_x + 1,
 				offset_y + 1, lines[i], strlen(lines[i]));
 	       }
@@ -573,7 +604,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  XmbDrawString(disp, drawable, ts->xfontset, gc, offset_x - 1,
 				offset_y, lines[i], strlen(lines[i]));
 		  XmbDrawString(disp, drawable, ts->xfontset, gc, offset_x + 1,
@@ -586,7 +618,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	     r = ts->fg_col.r;
 	     g = ts->fg_col.g;
 	     b = ts->fg_col.b;
-	     XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
+	     XSetForeground(disp, gc,
+			    Imlib_best_color_match(pImlibData, &r, &g, &b));
 	     XmbDrawString(disp, drawable, ts->xfontset, gc, offset_x, offset_y,
 			   lines[i], strlen(lines[i]));
 
@@ -666,7 +699,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  XDrawString(disp, drawable, gc, offset_x + 1, offset_y + 1,
 			      lines[i], strlen(lines[i]));
 	       }
@@ -676,7 +710,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  XDrawString(disp, drawable, gc, offset_x - 1, offset_y,
 			      lines[i], strlen(lines[i]));
 		  XDrawString(disp, drawable, gc, offset_x + 1, offset_y,
@@ -689,7 +724,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	     r = ts->fg_col.r;
 	     g = ts->fg_col.g;
 	     b = ts->fg_col.b;
-	     XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
+	     XSetForeground(disp, gc,
+			    Imlib_best_color_match(pImlibData, &r, &g, &b));
 	     XDrawString(disp, drawable, gc, offset_x, offset_y, lines[i],
 			 strlen(lines[i]));
 
@@ -771,7 +807,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  XDrawString16(disp, drawable, gc, offset_x + 1, offset_y + 1,
 				(XChar2b *) lines[i], strlen(lines[i]) / 2);
 	       }
@@ -781,7 +818,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 		  g = ts->bg_col.g;
 		  b = ts->bg_col.b;
 		  XSetForeground(disp, gc,
-				 Imlib_best_color_match(id, &r, &g, &b));
+				 Imlib_best_color_match(pImlibData, &r, &g,
+							&b));
 		  XDrawString16(disp, drawable, gc, offset_x - 1, offset_y,
 				(XChar2b *) lines[i], strlen(lines[i]) / 2);
 		  XDrawString16(disp, drawable, gc, offset_y + 1, offset_y,
@@ -794,7 +832,8 @@ TextDraw(TextClass * tclass, Window win, int active, int sticky, int state,
 	     r = ts->fg_col.r;
 	     g = ts->fg_col.g;
 	     b = ts->fg_col.b;
-	     XSetForeground(disp, gc, Imlib_best_color_match(id, &r, &g, &b));
+	     XSetForeground(disp, gc,
+			    Imlib_best_color_match(pImlibData, &r, &g, &b));
 	     XDrawString16(disp, drawable, gc, offset_x, offset_y,
 			   (XChar2b *) lines[i], strlen(lines[i]) / 2);
 
@@ -820,31 +859,32 @@ TextDrawRotTo(Window win, Drawable * drawable, int x, int y, int w, int h,
    switch (ts->style.orientation)
      {
      case FONT_TO_UP:
-	ii = Imlib_create_image_from_drawable(id, win, 0, y, x, h, w);
-	Imlib_rotate_image(id, ii, 1);
-	Imlib_flip_image_horizontal(id, ii);
-	Imlib_paste_image(id, ii, *drawable, 0, 0, w, h);
+	ii = Imlib_create_image_from_drawable(pImlibData, win, 0, y, x, h, w);
+	Imlib_rotate_image(pImlibData, ii, 1);
+	Imlib_flip_image_horizontal(pImlibData, ii);
+	Imlib_paste_image(pImlibData, ii, *drawable, 0, 0, w, h);
 	break;
      case FONT_TO_DOWN:
 	EGetGeometry(disp, win, &(root.win), &win_x, &win_y, &win_w, &win_h,
 		     &win_b, &win_d);
 	ii =
-	   Imlib_create_image_from_drawable(id, win, 0, win_w - y - h, x, h, w);
-	Imlib_rotate_image(id, ii, -1);
-	Imlib_flip_image_vertical(id, ii);
-	Imlib_paste_image(id, ii, *drawable, 0, 0, w, h);
+	   Imlib_create_image_from_drawable(pImlibData, win, 0, win_w - y - h,
+					    x, h, w);
+	Imlib_rotate_image(pImlibData, ii, -1);
+	Imlib_flip_image_vertical(pImlibData, ii);
+	Imlib_paste_image(pImlibData, ii, *drawable, 0, 0, w, h);
 	break;
      case FONT_TO_LEFT:	/* Holy carumba! That's for yoga addicts, maybe .... */
-	ii = Imlib_create_image_from_drawable(id, win, 0, x, y, w, h);
-	Imlib_flip_image_vertical(id, ii);
-	Imlib_flip_image_horizontal(id, ii);
-	Imlib_paste_image(id, ii, *drawable, 0, 0, w, h);
+	ii = Imlib_create_image_from_drawable(pImlibData, win, 0, x, y, w, h);
+	Imlib_flip_image_vertical(pImlibData, ii);
+	Imlib_flip_image_horizontal(pImlibData, ii);
+	Imlib_paste_image(pImlibData, ii, *drawable, 0, 0, w, h);
 	break;
      default:
 	break;
      }
    if (ii)
-      Imlib_destroy_image(id, ii);
+      Imlib_destroy_image(pImlibData, ii);
 }
 
 void
@@ -858,28 +898,34 @@ TextDrawRotBack(Window win, Pixmap drawable, int x, int y, int w, int h,
    switch (ts->style.orientation)
      {
      case FONT_TO_UP:
-	ii = Imlib_create_image_from_drawable(id, drawable, 0, 0, 0, w, h);
-	Imlib_rotate_image(id, ii, -1);
-	Imlib_flip_image_vertical(id, ii);
-	Imlib_paste_image(id, ii, win, y, x, h, w);
+	ii =
+	   Imlib_create_image_from_drawable(pImlibData, drawable, 0, 0, 0, w,
+					    h);
+	Imlib_rotate_image(pImlibData, ii, -1);
+	Imlib_flip_image_vertical(pImlibData, ii);
+	Imlib_paste_image(pImlibData, ii, win, y, x, h, w);
 	break;
      case FONT_TO_DOWN:
 	EGetGeometry(disp, win, &(root.win), &win_x, &win_y, &win_w, &win_h,
 		     &win_b, &win_d);
-	ii = Imlib_create_image_from_drawable(id, drawable, 0, 0, 0, w, h);
-	Imlib_rotate_image(id, ii, 1);
-	Imlib_flip_image_horizontal(id, ii);
-	Imlib_paste_image(id, ii, win, win_w - y - h, x, h, w);
+	ii =
+	   Imlib_create_image_from_drawable(pImlibData, drawable, 0, 0, 0, w,
+					    h);
+	Imlib_rotate_image(pImlibData, ii, 1);
+	Imlib_flip_image_horizontal(pImlibData, ii);
+	Imlib_paste_image(pImlibData, ii, win, win_w - y - h, x, h, w);
 	break;
      case FONT_TO_LEFT:	/* Holy carumba! That's for yoga addicts, maybe .... */
-	ii = Imlib_create_image_from_drawable(id, drawable, 0, 0, 0, w, h);
-	Imlib_flip_image_vertical(id, ii);
-	Imlib_flip_image_horizontal(id, ii);
-	Imlib_paste_image(id, ii, win, x, y, w, h);
+	ii =
+	   Imlib_create_image_from_drawable(pImlibData, drawable, 0, 0, 0, w,
+					    h);
+	Imlib_flip_image_vertical(pImlibData, ii);
+	Imlib_flip_image_horizontal(pImlibData, ii);
+	Imlib_paste_image(pImlibData, ii, win, x, y, w, h);
 	break;
      default:
 	break;
      }
    if (ii)
-      Imlib_destroy_image(id, ii);
+      Imlib_destroy_image(pImlibData, ii);
 }
