@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -28,102 +28,51 @@ CreateToolTip(char *name, ImageClass * ic0, ImageClass * ic1,
 	      ImageClass * ic2, ImageClass * ic3, ImageClass * ic4,
 	      TextClass * tclass, int dist, ImageClass * tooltippic)
 {
+   int                 i;
    ToolTip            *tt;
 
    EDBUG(5, "CreateToolTip");
 
+   if (ic0 == NULL || ic1 == NULL || ic2 == NULL || ic3 == NULL || ic4 == NULL
+       || tclass == NULL)
+      EDBUG_RETURN((ToolTip *) NULL);
+
    tt = Emalloc(sizeof(ToolTip));
    tt->name = duplicate(name);
    tt->iclass = ic0;
-   tt->tooltippic = NULL;
-
-   if (!tt->iclass)
-     {
-	if (tt->name)
-	   Efree(tt->name);
-	if (tt)
-	   Efree(tt);
-	EDBUG_RETURN((ToolTip *) NULL);
-     }
-
+   if (ic0)
+      ic0->ref_count++;
    tt->s_iclass[0] = ic1;
-   if (!tt->s_iclass[0])
-     {
-	if (tt->name)
-	   Efree(tt->name);
-	if (tt)
-	   Efree(tt);
-	EDBUG_RETURN((ToolTip *) NULL);
-     }
-
    tt->s_iclass[1] = ic2;
-   if (!tt->s_iclass[1])
-     {
-	if (tt->name)
-	   Efree(tt->name);
-	if (tt)
-	   Efree(tt);
-	EDBUG_RETURN((ToolTip *) NULL);
-     }
-
    tt->s_iclass[2] = ic3;
-   if (!tt->s_iclass[2])
-     {
-	if (tt->name)
-	   Efree(tt->name);
-	if (tt)
-	   Efree(tt);
-	EDBUG_RETURN((ToolTip *) NULL);
-     }
-
    tt->s_iclass[3] = ic4;
-   if (!tt->s_iclass[3])
-     {
-	if (tt->name)
-	   Efree(tt->name);
-	if (tt)
-	   Efree(tt);
-	EDBUG_RETURN((ToolTip *) NULL);
-     }
-
    tt->tclass = tclass;
-   if (!tt->tclass)
-     {
-	if (tt->name)
-	   Efree(tt->name);
-	if (tt)
-	   Efree(tt);
-	EDBUG_RETURN((ToolTip *) NULL);
-     }
-
+   if (tclass)
+      tclass->ref_count++;
+   tt->tooltippic = tooltippic;
    if (tooltippic)
-     {
-	tt->tooltippic = tooltippic;
-	tooltippic->ref_count++;
-     }
+      tooltippic->ref_count++;
 
    tt->dist = dist;
    tt->win = ECreateWindow(root.win, -10, -100, 1, 1, 1);
    tt->iwin = ECreateWindow(tt->win, -10, -100, 1, 1, 1);
-   tt->s_win[0] = ECreateWindow(root.win, -10, -100, 8, 8, 1);
-   tt->s_win[1] = ECreateWindow(root.win, -10, -100, 16, 16, 1);
-   tt->s_win[2] = ECreateWindow(root.win, -10, -100, 24, 24, 1);
-   tt->s_win[3] = ECreateWindow(root.win, -10, -100, 32, 32, 1);
+
+   for (i = 0; i < 4; i++)
+     {
+	Window              win;
+
+	win = 0;
+	if (tt->s_iclass[i])
+	  {
+	     int                 wh = (i + 1) * 8;
+
+	     win = ECreateWindow(root.win, -10, -100, wh, wh, 1);
+	     tt->s_iclass[i]->ref_count++;
+	  }
+	tt->s_win[i] = win;
+     }
+
    tt->visible = 0;
-
-   if (ic0)
-      ic0->ref_count++;
-   if (ic1)
-      ic1->ref_count++;
-   if (ic2)
-      ic2->ref_count++;
-   if (ic3)
-      ic3->ref_count++;
-   if (ic4)
-      ic4->ref_count++;
-   if (tclass)
-      tclass->ref_count++;
-
    tt->ref_count = 0;
 
    EDBUG_RETURN(tt);
@@ -177,9 +126,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 
 		  if (ac->list[i]->anybutton)
 		    {
-		       ic =
-			  FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0,
-				   LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+		       ic = FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0,
+				     LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 		       if (!ic)
 			 {
 			    ic = CreateIclass();
@@ -196,9 +144,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		     switch (ac->list[i]->button)
 		       {
 		       case 1:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_1", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_1", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
@@ -212,9 +159,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 2:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_2", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_2", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
@@ -228,9 +174,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 3:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_3", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_3", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
@@ -244,9 +189,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 4:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_4", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_4", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
@@ -260,9 +204,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			     ImageStateRealize(ic->norm.normal);
 			  break;
 		       case 5:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_5", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_5", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (!ic)
 			    {
 			       ic = CreateIclass();
@@ -294,9 +237,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		    {
 		       if (ac->list[i]->modifiers & ShiftMask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_SHIFT", 0,
-					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_SHIFT", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -318,9 +260,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & LockMask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_LOCK", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_LOCK", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -342,9 +283,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & ControlMask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_CTRL", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_CTRL", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -366,9 +306,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod1Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD1", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD1", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -390,9 +329,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod2Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD2", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD2", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -414,9 +352,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod3Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD3", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD3", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -438,9 +375,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod4Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD4", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD4", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -462,9 +398,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			 }
 		       if (ac->list[i]->modifiers & Mod5Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD5", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD5", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (!ic)
 			      {
 				 ic = CreateIclass();
@@ -487,8 +422,8 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		    }
 
 		  temp_w =
-		     cols[0] + cols[1] + cols[2] + cols[3] + cols[4] + cols[5] +
-		     cols[6] + cols[7] + cols[8] + cols[9];
+		     cols[0] + cols[1] + cols[2] + cols[3] + cols[4] +
+		     cols[5] + cols[6] + cols[7] + cols[8] + cols[9];
 
 		  if (temp_w > icons_width)
 		     icons_width = temp_w;
@@ -515,7 +450,7 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 	  {
 	     iw = im->rgb_width;
 	     ih = im->rgb_height;
-	     Imlib_destroy_image(id, im);
+	     Imlib_destroy_image(pImlibData, im);
 	  }
 	w += iw;
 	if (h < ih)
@@ -669,20 +604,19 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		    }
 		  if (ac->list[i]->anybutton)
 		    {
-		       ic =
-			  FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0,
-				   LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+		       ic = FindItem("TOOLTIP_MOUSEBUTTON_ANY", 0,
+				     LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 		       if (ic)
 			  if (ic->norm.normal->im)
 			    {
-			       Imlib_render(id, ic->norm.normal->im,
+			       Imlib_render(pImlibData, ic->norm.normal->im,
 					    ic->norm.normal->im->rgb_width,
 					    ic->norm.normal->im->rgb_height);
 			       PastePixmap(disp, tt->win,
-					   Imlib_copy_image(id,
+					   Imlib_copy_image(pImlibData,
 							    ic->norm.
 							    normal->im),
-					   Imlib_copy_mask(id,
+					   Imlib_copy_mask(pImlibData,
 							   ic->norm.normal->im),
 					   x, y);
 			       x += ic->norm.normal->im->rgb_width;
@@ -692,20 +626,19 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		     switch (ac->list[i]->button)
 		       {
 		       case 1:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_1", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_1", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
-				  Imlib_render(id, ic->norm.normal->im,
+				  Imlib_render(pImlibData, ic->norm.normal->im,
 					       ic->norm.normal->im->rgb_width,
 					       ic->norm.normal->im->rgb_height);
 				  PastePixmap(disp, tt->win,
-					      Imlib_copy_image(id,
+					      Imlib_copy_image(pImlibData,
 							       ic->norm.
 							       normal->im),
-					      Imlib_copy_mask(id,
+					      Imlib_copy_mask(pImlibData,
 							      ic->norm.
 							      normal->im), x,
 					      y);
@@ -713,20 +646,19 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			       }
 			  break;
 		       case 2:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_2", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_2", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
-				  Imlib_render(id, ic->norm.normal->im,
+				  Imlib_render(pImlibData, ic->norm.normal->im,
 					       ic->norm.normal->im->rgb_width,
 					       ic->norm.normal->im->rgb_height);
 				  PastePixmap(disp, tt->win,
-					      Imlib_copy_image(id,
+					      Imlib_copy_image(pImlibData,
 							       ic->norm.
 							       normal->im),
-					      Imlib_copy_mask(id,
+					      Imlib_copy_mask(pImlibData,
 							      ic->norm.
 							      normal->im), x,
 					      y);
@@ -734,20 +666,19 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			       }
 			  break;
 		       case 3:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_3", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_3", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
-				  Imlib_render(id, ic->norm.normal->im,
+				  Imlib_render(pImlibData, ic->norm.normal->im,
 					       ic->norm.normal->im->rgb_width,
 					       ic->norm.normal->im->rgb_height);
 				  PastePixmap(disp, tt->win,
-					      Imlib_copy_image(id,
+					      Imlib_copy_image(pImlibData,
 							       ic->norm.
 							       normal->im),
-					      Imlib_copy_mask(id,
+					      Imlib_copy_mask(pImlibData,
 							      ic->norm.
 							      normal->im), x,
 					      y);
@@ -755,20 +686,19 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			       }
 			  break;
 		       case 4:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_4", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_4", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
-				  Imlib_render(id, ic->norm.normal->im,
+				  Imlib_render(pImlibData, ic->norm.normal->im,
 					       ic->norm.normal->im->rgb_width,
 					       ic->norm.normal->im->rgb_height);
 				  PastePixmap(disp, tt->win,
-					      Imlib_copy_image(id,
+					      Imlib_copy_image(pImlibData,
 							       ic->norm.
 							       normal->im),
-					      Imlib_copy_mask(id,
+					      Imlib_copy_mask(pImlibData,
 							      ic->norm.
 							      normal->im), x,
 					      y);
@@ -776,20 +706,19 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 			       }
 			  break;
 		       case 5:
-			  ic =
-			     FindItem("TOOLTIP_MOUSEBUTTON_5", 0,
-				      LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			  ic = FindItem("TOOLTIP_MOUSEBUTTON_5", 0,
+					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			  if (ic)
 			     if (ic->norm.normal->im)
 			       {
-				  Imlib_render(id, ic->norm.normal->im,
+				  Imlib_render(pImlibData, ic->norm.normal->im,
 					       ic->norm.normal->im->rgb_width,
 					       ic->norm.normal->im->rgb_height);
 				  PastePixmap(disp, tt->win,
-					      Imlib_copy_image(id,
+					      Imlib_copy_image(pImlibData,
 							       ic->norm.
 							       normal->im),
-					      Imlib_copy_mask(id,
+					      Imlib_copy_mask(pImlibData,
 							      ic->norm.
 							      normal->im), x,
 					      y);
@@ -804,193 +733,185 @@ ShowToolTip(ToolTip * tt, char *text, ActionClass * ac, int x, int y)
 		    {
 		       if (ac->list[i]->modifiers & ShiftMask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_SHIFT", 0,
-					LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_SHIFT", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & LockMask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_LOCK", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_LOCK", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & ControlMask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_CTRL", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_CTRL", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod1Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD1", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD1", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod2Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD2", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD2", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod3Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD3", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD3", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod4Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD4", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD4", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
 		       if (ac->list[i]->modifiers & Mod5Mask)
 			 {
-			    ic =
-			       FindItem("TOOLTIP_KEY_MOD5", 0, LIST_FINDBY_NAME,
-					LIST_TYPE_ICLASS);
+			    ic = FindItem("TOOLTIP_KEY_MOD5", 0,
+					  LIST_FINDBY_NAME, LIST_TYPE_ICLASS);
 			    if (ic)
 			       if (ic->norm.normal->im)
 				 {
-				    Imlib_render(id, ic->norm.normal->im,
+				    Imlib_render(pImlibData,
+						 ic->norm.normal->im,
 						 ic->norm.normal->im->rgb_width,
-						 ic->norm.normal->
-						 im->rgb_height);
+						 ic->norm.normal->im->
+						 rgb_height);
 				    PastePixmap(disp, tt->win,
-						Imlib_copy_image(id,
-								 ic->
-								 norm.normal->
-								 im),
-						Imlib_copy_mask(id,
-								ic->
-								norm.normal->
-								im), x, y);
+						Imlib_copy_image(pImlibData,
+								 ic->norm.
+								 normal->im),
+						Imlib_copy_mask(pImlibData,
+								ic->norm.
+								normal->im), x,
+						y);
 				    x += ic->norm.normal->im->rgb_width;
 				 }
 			 }
