@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Carsten Haitzler, Geoff Harrison and various contributors
+ * Copyright (C) 2000-2003 Carsten Haitzler, Geoff Harrison and various contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -24,6 +24,100 @@
 #include <X11/Xutil.h>
 #include <X11/Xresource.h>
 
+typedef struct _exid
+{
+   Window              parent;
+   Window              win;
+   int                 x, y, w, h;
+   char                mapped;
+   int                 num_rect;
+   int                 ord;
+   XRectangle         *rects;
+   int                 depth;
+   Pixmap              bgpmap;
+   int                 bgcol;
+}
+EXID;
+
+static XContext     xid_context = 0;
+
+static EXID        *
+NewXID(void)
+{
+   EXID               *xid;
+
+   xid = Emalloc(sizeof(EXID));
+   xid->parent = 0;
+   xid->win = 0;
+   xid->x = 0;
+   xid->y = 0;
+   xid->w = 0;
+   xid->h = 0;
+   xid->num_rect = 0;
+   xid->ord = 0;
+   xid->rects = NULL;
+   xid->depth = 0;
+   xid->mapped = 0;
+   xid->bgpmap = 0;
+   xid->bgcol = 0;
+
+   return xid;
+}
+
+static void
+AddXID(EXID * xid)
+{
+   if (!xid_context)
+      xid_context = XUniqueContext();
+   XSaveContext(disp, xid->win, xid_context, (XPointer) xid);
+   AddItem(xid, "", xid->win, LIST_TYPE_XID);
+}
+
+static EXID        *
+FindXID(Window win)
+{
+   EXID               *xid = NULL;
+
+   if (xid_context == 0)
+      xid_context = XUniqueContext();
+   if (XFindContext(disp, win, xid_context, (XPointer *) & xid) == XCNOENT)
+      xid = NULL;
+   return xid;
+}
+
+static void
+DelXID(Window win)
+{
+   EXID               *xid;
+
+   if (xid_context == 0)
+      xid_context = XUniqueContext();
+   xid = RemoveItem("", win, LIST_FINDBY_ID, LIST_TYPE_XID);
+   if (xid)
+     {
+	XDeleteContext(disp, win, xid_context);
+	if (xid->rects)
+	   XFree(xid->rects);
+	Efree(xid);
+     }
+}
+
+static void
+SetXID(Window win, Window parent, int x, int y, int w, int h, int depth)
+{
+   EXID               *xid;
+
+   xid = NewXID();
+   xid->parent = parent;
+   xid->win = win;
+   xid->x = x;
+   xid->y = y;
+   xid->w = w;
+   xid->h = h;
+   xid->depth = root.depth;
+   AddXID(xid);
+}
+
 Pixmap
 ECreatePixmap(Display * display, Drawable d, unsigned int width,
 	      unsigned int height, unsigned depth)
@@ -40,9 +134,9 @@ EFreePixmap(Display * display, Pixmap pixmap)
    XFreePixmap(display, pixmap);
 }
 
-Window ECreateWindow(Window parent, int x, int y, int w, int h, int saveunder)
+Window
+ECreateWindow(Window parent, int x, int y, int w, int h, int saveunder)
 {
-   EXID               *xid;
    Window              win;
    XSetWindowAttributes attr;
 
@@ -64,15 +158,8 @@ Window ECreateWindow(Window parent, int x, int y, int w, int h, int saveunder)
 		    root.vis,
 		    CWOverrideRedirect | CWSaveUnder | CWBackingStore |
 		    CWColormap | CWBackPixmap | CWBorderPixel, &attr);
-   xid = NewXID();
-   xid->parent = parent;
-   xid->win = win;
-   xid->x = x;
-   xid->y = y;
-   xid->w = w;
-   xid->h = h;
-   xid->depth = root.depth;
-   AddXID(xid);
+   SetXID(win, parent, x, y, w, h, root.depth);
+
    EDBUG_RETURN(win);
 }
 
@@ -165,6 +252,12 @@ EDestroyWindow(Display * d, Window win)
       XDestroyWindow(d, win);
 }
 
+void
+EForgetWindow(Display * d, Window win)
+{
+   DelXID(win);
+}
+
 void
 EMapWindow(Display * d, Window win)
 {
@@ -419,6 +512,7 @@ EGetGeometry(Display * d, Window win, Window * root_return, int *x, int *y,
 	     unsigned int *w, unsigned int *h, unsigned int *bw,
 	     unsigned int *depth)
 {
+   int                 ok;
    EXID               *xid;
 
    xid = FindXID(win);
@@ -438,9 +532,17 @@ EGetGeometry(Display * d, Window win, Window * root_return, int *x, int *y,
 	   *depth = xid->depth;
 	if (root_return)
 	   *root_return = root.win;
-	return 1;
+	ok = 1;
      }
-   return XGetGeometry(d, win, root_return, x, y, w, h, bw, depth);
+   else
+     {
+	ok = XGetGeometry(d, win, root_return, x, y, w, h, bw, depth);
+     }
+#if 0
+   if (!ok)
+      printf("EGetGeometry win=%#x, error %d\n", (unsigned)win, ok);
+#endif
+   return ok;
 }
 
 void
@@ -522,69 +624,8 @@ ESetWindowBackground(Display * d, Window win, int col)
       XSetWindowBackground(d, win, col);
 }
 
-EXID               *
-NewXID(void)
-{
-   EXID               *xid;
-
-   xid = Emalloc(sizeof(EXID));
-   xid->parent = 0;
-   xid->win = 0;
-   xid->x = 0;
-   xid->y = 0;
-   xid->w = 0;
-   xid->h = 0;
-   xid->num_rect = 0;
-   xid->ord = 0;
-   xid->rects = NULL;
-   xid->depth = 0;
-   xid->mapped = 0;
-   xid->bgpmap = 0;
-   xid->bgcol = 0;
-   return xid;
-}
-
-static XContext     xid_context = 0;
-
-void
-AddXID(EXID * xid)
-{
-   if (!xid_context)
-      xid_context = XUniqueContext();
-   XSaveContext(disp, xid->win, xid_context, (XPointer) xid);
-   AddItem(xid, "", xid->win, LIST_TYPE_XID);
-}
-
-EXID               *
-FindXID(Window win)
-{
-   EXID               *xid = NULL;
-
-   if (xid_context == 0)
-      xid_context = XUniqueContext();
-   if (XFindContext(disp, win, xid_context, (XPointer *) & xid) == XCNOENT)
-      xid = NULL;
-   return xid;
-}
-
-void
-DelXID(Window win)
-{
-   EXID               *xid;
-
-   if (xid_context == 0)
-      xid_context = XUniqueContext();
-   xid = RemoveItem("", win, LIST_FINDBY_ID, LIST_TYPE_XID);
-   if (xid)
-     {
-	XDeleteContext(disp, win, xid_context);
-	if (xid->rects)
-	   XFree(xid->rects);
-	Efree(xid);
-     }
-}
-
-Window ECreateEventWindow(Window parent, int x, int y, int w, int h)
+Window
+ECreateEventWindow(Window parent, int x, int y, int w, int h)
 {
    Window              win;
    XSetWindowAttributes attr;
@@ -594,6 +635,10 @@ Window ECreateEventWindow(Window parent, int x, int y, int w, int h)
    win =
       XCreateWindow(disp, parent, x, y, w, h, 0, 0, InputOnly, root.vis,
 		    CWOverrideRedirect, &attr);
+#if 0				/* Not yet */
+   SetXID(win, parent, x, y, w, h, root.depth);
+#endif
+
    EDBUG_RETURN(win);
 }
 
@@ -601,7 +646,8 @@ Window ECreateEventWindow(Window parent, int x, int y, int w, int h)
  * create a window which will accept the keyboard focus when no other 
  * windows have it
  */
-Window ECreateFocusWindow(Window parent, int x, int y, int w, int h)
+Window
+ECreateFocusWindow(Window parent, int x, int y, int w, int h)
 {
    Window              win;
    XSetWindowAttributes attr;
@@ -736,7 +782,8 @@ WinExists(Window win)
    EDBUG_RETURN(0);
 }
 
-Window WindowAtXY_0(Window base, int bx, int by, int x, int y)
+Window
+WindowAtXY_0(Window base, int bx, int by, int x, int y)
 {
    Window             *list = NULL;
    XWindowAttributes   att;
@@ -783,7 +830,8 @@ Window WindowAtXY_0(Window base, int bx, int by, int x, int y)
    EDBUG_RETURN(base);
 }
 
-Window WindowAtXY(int x, int y)
+Window
+WindowAtXY(int x, int y)
 {
    Window             *list = NULL;
    Window              child = 0, parent_win = 0, root_win = 0;
